@@ -40,6 +40,7 @@
 #include <chemistry/molecule/molrender.h>
 
 using namespace std;
+using namespace sc;
 
 #undef DEBUG
 
@@ -51,7 +52,7 @@ MolecularFrequencies::MolecularFrequencies(const Ref<KeyVal>& keyval)
 {
   mol_ << keyval->describedclassvalue("molecule");
   if (mol_.null()) {
-      ExEnv::err() << node0 << "MolecularFrequencies: KeyVal CTOR requires molecule"
+      ExEnv::err0() << "MolecularFrequencies: KeyVal CTOR requires molecule"
            << endl;
       abort();
     }
@@ -80,7 +81,7 @@ MolecularFrequencies::MolecularFrequencies(StateIn& si):
   int i;
 
   if (si.version(::class_desc<MolecularFrequencies>()) < 3) {
-      ExEnv::err() << "MolecularFrequencies: cannot restore from old version" << endl;
+      ExEnv::errn() << "MolecularFrequencies: cannot restore from old version" << endl;
       abort();
     }
 
@@ -120,8 +121,9 @@ MolecularFrequencies::compute_frequencies(const RefSymmSCMatrix &xhessian)
   bd3natom_ = symmbasis->coldim();
   disym_ = symmbasis->rowdim();
 
-  ExEnv::out() << node0 << endl
-       << indent << "Frequencies (cm-1; negative is imaginary):";
+  ExEnv::out0() << endl
+               << indent << "Frequencies (cm-1; negative is imaginary):"
+               << endl;
 
   // initialize the frequency tables
   if (nfreq_) delete[] nfreq_;
@@ -179,7 +181,7 @@ MolecularFrequencies::do_freq_for_irrep(
   ncbasis.svd(basU, bassigma, basV);
   for (i=0; i<ddim.n(); i++) {
       if (bassigma(i) < 1.e0-3) {
-          ExEnv::err() << node0 << indent
+          ExEnv::err0() << indent
                << "MolecularFrequencies: displacements don't span"
                << " normal coordinates"
                << endl;
@@ -207,7 +209,19 @@ MolecularFrequencies::do_freq_for_irrep(
       freq_[irrep][i] = freqs(i);
       freqs(i) = freqs->get_element(i) * 219474.63;
     }
-  freqs.print(pg_->char_table().gamma(irrep).symbol());
+
+  ExEnv::out0() << indent
+               << pg_->char_table().gamma(irrep).symbol() << endl;
+  int ifreqoff = 1;
+  for (i=0; i<irrep; i++) ifreqoff += nfreq_[i];
+  for (i=0; i<freqs.n(); i++) {
+      double freq = freqs(freqs.n()-i-1);
+      ExEnv::out0() << indent
+                   << scprintf("%4d % 8.2f",i+ifreqoff,freq)
+                   << endl;
+    }
+  ExEnv::out0() << endl;
+
   if (debug_) {
       eigvecs.print("eigenvectors");
       ncbasis.print("ncbasis");
@@ -279,7 +293,7 @@ MolecularFrequencies::thermochemistry(int degeneracy, double T, double P)
       else if (ct.symbol()[0] == 'C' ||
                ct.symbol()[0] == 'c') sigma = 1;
       else {
-          ExEnv::err() << "MolecularFrequencies: For linear molecules"
+          ExEnv::errn() << "MolecularFrequencies: For linear molecules"
                << " the specified point group must be Cnv or Dnh"
                << endl;
           abort();
@@ -394,7 +408,7 @@ MolecularFrequencies::thermochemistry(int degeneracy, double T, double P)
       Erot = 1.5 * EPV;
     }
   else {
-      ExEnv::err() << "Strange number of external coordinates: " << nexternal
+      ExEnv::errn() << "Strange number of external coordinates: " << nexternal
            << ".  Setting Erot to 0.0" << endl;
       Erot = 0.0;
     }
@@ -405,7 +419,7 @@ MolecularFrequencies::thermochemistry(int degeneracy, double T, double P)
   // Print out results of thermodynamic analysis
   ////////////////////////////////////////////////
 
-  ExEnv::out() << node0 << indent << "THERMODYNAMIC ANALYSIS:" << endl << endl
+  ExEnv::out0() << indent << "THERMODYNAMIC ANALYSIS:" << endl << endl
        << indent << scprintf("Contributions to the nonelectronic enthalpy at %.2lf K:\n",T)
        << indent << "                   kJ/mol       kcal/mol"<< endl
        << indent << scprintf("  E0vib        = %9.4lf    %9.4lf\n",
@@ -443,10 +457,10 @@ MolecularFrequencies::thermochemistry(int degeneracy, double T, double P)
        << indent << "Various data used for thermodynamic analysis:" << endl
        << indent << endl;
 
-  if (linear) ExEnv::out() << node0 << indent << "Linear molecule" << endl;
-  else ExEnv::out() << node0 << indent << "Nonlinear molecule" << endl;
+  if (linear) ExEnv::out0() << indent << "Linear molecule" << endl;
+  else ExEnv::out0() << indent << "Nonlinear molecule" << endl;
 
-  ExEnv::out() << node0 << indent
+  ExEnv::out0() << indent
        << scprintf("Principal moments of inertia (amu*angstrom^2):"
           " %.5lf, %.5lf, %.5lf\n", pmi[0], pmi[1], pmi[2])
        << indent << "Point group: " << ct.symbol()
@@ -455,16 +469,16 @@ MolecularFrequencies::thermochemistry(int degeneracy, double T, double P)
        << indent << "Rotational symmetry number: " << sigma << endl;
 
   if (linear) {
-      ExEnv::out() << node0 << indent
+      ExEnv::out0() << indent
            << scprintf("Rotational temperature (K): %.4lf\n", theta[1]);
     }
   else {
-      ExEnv::out() << node0 << indent
+      ExEnv::out0() << indent
            << scprintf("Rotational temperatures (K): %.4lf, %.4lf, %.4lf\n",
                        theta[0], theta[1], theta[2]);
     }
 
-  ExEnv::out() << node0 << indent << "Electronic degeneracy: " << degeneracy
+  ExEnv::out0() << indent << "Electronic degeneracy: " << degeneracy
        << endl << endl;
 }
 
@@ -472,16 +486,18 @@ void
 MolecularFrequencies::animate(const Ref<Render>& render,
                               const Ref<MolFreqAnimate>& anim)
 {
-  int i,j;
+  int i,j, symoff = 0;
   for (i=0; i<nirrep_; i++) {
-      for (j=0; j<disym_->blocks()->size(i); j++) {
+      int nfreq = disym_->blocks()->size(i);
+      for (j=0; j<nfreq; j++) {
           char name[128];
-          sprintf(name,"%s.%02d",
-                pg_->char_table().gamma(i).symbol(), j);
+          sprintf(name,"%02d.%s",
+                  nfreq-j+symoff, pg_->char_table().gamma(i).symbol_ns());
           anim->set_name(name);
           anim->set_mode(i,j);
           render->animate(anim.pointer());
         }
+      symoff += nfreq;
     }
 }
 
@@ -500,10 +516,10 @@ MolFreqAnimate::MolFreqAnimate(const Ref<KeyVal> &keyval):
   dependent_mole_ << keyval->describedclassvalue("dependent_mole");
   irrep_ = keyval->intvalue("irrep");
   mode_ = keyval->intvalue("mode");
-  nframe_ = keyval->intvalue("nframe");
-  if (keyval->error() != KeyVal::OK) {
-      nframe_ = 10;
-    }
+  KeyValValueint default_nframe(10);
+  nframe_ = keyval->intvalue("nframe",default_nframe);
+  KeyValValuedouble default_disp(0.2);
+  disp_ = keyval->doublevalue("displacement", default_disp);
 }
 
 MolFreqAnimate::~MolFreqAnimate()
@@ -524,7 +540,7 @@ MolFreqAnimate::object(int iobject)
   Ref<Molecule> mol = renmol_->molecule();
   Ref<Molecule> molcopy = new Molecule(*mol.pointer());
 
-  double scale = 0.2 * cos(M_PI*(iobject+0.5)/(double)nframe_);
+  double scale = disp_ * cos(M_PI*(iobject+0.5)/(double)nframe_);
 
   RefSCMatrix irrepblock = normco->block(irrep_);
   int ixyz, iatom, icoor=0;
