@@ -40,13 +40,16 @@
 #include <chemistry/qc/basis/basis.h>
 #include <chemistry/qc/basis/files.h>
 #include <chemistry/qc/basis/petite.h>
+#include <chemistry/qc/basis/gpetite.h>
 #include <chemistry/qc/basis/symmint.h>
 #include <chemistry/qc/intv3/intv3.h>
 #include <chemistry/qc/basis/sobasis.h>
 #include <chemistry/qc/basis/sointegral.h>
 #include <chemistry/qc/basis/extent.h>
+#include <chemistry/qc/basis/orthog.h>
 
 using namespace std;
+using namespace sc;
 
 static void
 do_so_shell_test(const Ref<SOBasis>& sobas, const Ref<TwoBodySOInt> &soer,
@@ -109,7 +112,7 @@ do_so_test(const Ref<KeyVal> &keyval,
   intgrl->set_basis(gbs);
 
   Ref<SOBasis> sobas = new SOBasis(gbs, intgrl);
-  sobas->print(cout << node0);
+  sobas->print(cout);
 
   Ref<TwoBodyInt> aoer = intgrl->electron_repulsion();
   Ref<TwoBodySOInt> soer = new TwoBodySOInt(aoer);
@@ -118,7 +121,7 @@ do_so_test(const Ref<KeyVal> &keyval,
   Ref<OneBodySOInt> soov = new OneBodySOInt(aoov);
 
   sobas = soer->basis();
-  sobas->print(cout << node0);
+  sobas->print(cout);
 
   if (keyval->exists(":shell")) {
     do_so_shell_test(sobas, soer,
@@ -207,6 +210,36 @@ test_overlap(const Ref<GaussianBasisSet>& gbs, const Ref<GaussianBasisSet>& gbs2
   syms2.print("symm S2");
 }
 
+static void
+test_aoorthog(const Ref<GaussianBasisSet>& gbs,
+             const Ref<Integral>& intgrl)
+{
+  cout << "Beginning AO Orthog test" << endl;
+
+  intgrl->set_basis(gbs);
+
+  // first form AO basis overlap
+  RefSymmSCMatrix s(gbs->basisdim(), gbs->matrixkit());
+  Ref<SCElementOp> ov
+      = new OneBodyIntOp(new OneBodyIntIter(intgrl->overlap()));
+  s.assign(0.0);
+  s.element_op(ov);
+  ov=0;
+
+  Ref<OverlapOrthog> orthog;
+  orthog = new OverlapOrthog(OverlapOrthog::Symmetric,
+                             s,
+                             s.kit(),
+                             0.0001,
+                             1);
+  orthog->basis_to_orthog_basis().print("basis to orthog basis");
+
+  s = 0;
+  orthog = 0;
+
+  cout << "Ending AO Orthog test" << endl;
+}
+
 static void
 test_eigvals(const Ref<GaussianBasisSet>& gbs, const Ref<Integral>& intgrl)
 {
@@ -453,6 +486,30 @@ do_extent_test(const Ref<GaussianBasisSet> &gbs)
   extent->print();
 }
 
+void
+do_gpetite_test(const Ref<GaussianBasisSet> &b1,
+                const Ref<GaussianBasisSet> &b2)
+{
+  canonical_aabc c4(b1,b1,b1,b2);
+  Ref<GPetite4<canonical_aabc> > p4
+      = new GPetite4<canonical_aabc>(b1,b1,b1,b2,c4);
+  cout << "tesing GPetite4<canonical_aabc>" << endl;
+  for (int i=0; i<b1->nshell(); i++) {
+      for (int j=0; j<=i; j++) {
+          for (int k=0; k<b1->nshell(); k++) {
+              for (int l=0; l<b2->nshell(); l++) {
+                  cout << " " << i
+                       << " " << j
+                       << " " << k
+                       << " " << l
+                       << " in p4: " << p4->in_p4(i,j,k,l)
+                       << endl;
+                }
+            }
+        }
+    }
+}
+
 int
 main(int, char *argv[])
 {
@@ -477,8 +534,10 @@ main(int, char *argv[])
   int doso = keyval->booleanvalue("so");
   int doatoms = keyval->booleanvalue("atoms");
   int dopetite = keyval->booleanvalue("petite");
+  int dogpetite = keyval->booleanvalue("gpetite");
   int dovalues = keyval->booleanvalue("values");
   int doextent = keyval->booleanvalue("extent");
+  int doaoorthog = keyval->booleanvalue("aoorthog");
 
   for (i=0; i<keyval->count("test"); i++) {
       Ref<GaussianBasisSet> gbs;
@@ -488,6 +547,8 @@ main(int, char *argv[])
 
       if (dooverlap) test_overlap(gbs,gbs2,intgrl);
 
+      if (doaoorthog) test_aoorthog(gbs,intgrl);
+
       if (doeigvals) test_eigvals(gbs,intgrl);
 
       if (dostate) {
@@ -504,6 +565,10 @@ main(int, char *argv[])
           intgrl->petite_list()->print();
         }
 
+      if (dogpetite) {
+          do_gpetite_test(gbs,gbs2);
+        }
+
       if (doso) {
           do_so_test(keyval, intgrl, gbs);
         }
