@@ -52,16 +52,17 @@
 #include <chemistry/qc/basis/integral.h>
 
 using namespace std;
+using namespace sc;
 
 static ClassDesc GaussianBasisSet_cd(
-  typeid(GaussianBasisSet),"GaussianBasisSet",2,"public SavableState",
+  typeid(GaussianBasisSet),"GaussianBasisSet",3,"public SavableState",
   0, create<GaussianBasisSet>, create<GaussianBasisSet>);
 
 GaussianBasisSet::GaussianBasisSet(const Ref<KeyVal>&topkeyval)
 {
   molecule_ << topkeyval->describedclassvalue("molecule");
   if (molecule_.null()) {
-      ExEnv::err() << node0 << indent << "GaussianBasisSet: no \"molecule\"\n";
+      ExEnv::err0() << indent << "GaussianBasisSet: no \"molecule\"\n";
       abort();
     }
 
@@ -135,9 +136,9 @@ GaussianBasisSet::GaussianBasisSet(const GaussianBasisSet& gbs) :
   
   name_ = new_string(gbs.name_);
 
-  center_to_nshell_.set_length(ncenter_);
+  center_to_nshell_.resize(ncenter_);
   for (i=0; i < ncenter_; i++) {
-      center_to_nshell_(i) = gbs.center_to_nshell_(i);
+      center_to_nshell_[i] = gbs.center_to_nshell_[i];
     }
   
   shell_ = new GaussianShell*[nshell_];
@@ -171,21 +172,28 @@ GaussianBasisSet::GaussianBasisSet(const GaussianBasisSet& gbs) :
 }
 
 GaussianBasisSet::GaussianBasisSet(StateIn&s):
-  SavableState(s),
-  center_to_nshell_(s)
+  SavableState(s)
 {
   matrixkit_ = SCMatrixKit::default_matrixkit();
 
+  if (s.version(::class_desc<GaussianBasisSet>()) < 3) {
+      // read the duplicate length saved in older versions
+      int junk;
+      s.get(junk);
+    }
+  s.get(center_to_nshell_);
+
   molecule_ << SavableState::restore_state(s);
   basisdim_ << SavableState::restore_state(s);
 
+
   ncenter_ = center_to_nshell_.size();
   s.getstring(name_);
 
   nshell_ = 0;
   int i;
   for (i=0; i<ncenter_; i++) {
-      nshell_ += center_to_nshell_(i);
+      nshell_ += center_to_nshell_[i];
     }
   
   shell_ = new GaussianShell*[nshell_];
@@ -199,7 +207,7 @@ GaussianBasisSet::GaussianBasisSet(StateIn&s):
 void
 GaussianBasisSet::save_data_state(StateOut&s)
 {
-  center_to_nshell_.save_object_state(s);
+  s.put(center_to_nshell_);
 
   SavableState::save_state(molecule_.pointer(),s);
   SavableState::save_state(basisdim_.pointer(),s);
@@ -239,7 +247,7 @@ GaussianBasisSet::init(Ref<Molecule>&molecule,
       have_custom = 0;
       nelement = 0;
       if (!name_) {
-          ExEnv::err() << node0 << indent
+          ExEnv::err0() << indent
                << "GaussianBasisSet: No name given for basis set\n";
           abort();
         }
@@ -273,7 +281,7 @@ GaussianBasisSet::init(Ref<Molecule>&molecule,
         }
       if (!sbasisname) {
           if (!name_) {
-              ExEnv::err() << node0 << indent << "GaussianBasisSet: "
+              ExEnv::err0() << indent << "GaussianBasisSet: "
                    << scprintf("no basis name for atom %d (%s)\n",
                                iatom, AtomInfo::name(Z));
               abort();
@@ -288,7 +296,7 @@ GaussianBasisSet::init(Ref<Molecule>&molecule,
   nshell_ = ishell;
   shell_ = new GaussianShell*[nshell_];
   ishell = 0;
-  center_to_nshell_.set_length(ncenter_);
+  center_to_nshell_.resize(ncenter_);
   for (iatom=0; iatom<ncenter_; iatom++) {
       if (skip_ghosts && molecule->charge(iatom) == 0.0) {
           center_to_nshell_[iatom] = 0;
@@ -314,7 +322,7 @@ GaussianBasisSet::init(Ref<Molecule>&molecule,
         }
       if (!sbasisname) {
           if (!name_) {
-              ExEnv::err() << node0 << indent << "GaussianBasisSet: "
+              ExEnv::err0() << indent << "GaussianBasisSet: "
                    << scprintf("no basis name for atom %d (%s)\n",
                                iatom, AtomInfo::name(Z));
               abort();
@@ -353,9 +361,9 @@ void
 GaussianBasisSet::init2(int skip_ghosts)
 {
   // center_to_shell_ and shell_to_center_
-  shell_to_center_.set_length(nshell_);
-  center_to_shell_.set_length(ncenter_);
-  center_to_nbasis_.set_length(ncenter_);
+  shell_to_center_.resize(nshell_);
+  center_to_shell_.resize(ncenter_);
+  center_to_nbasis_.resize(ncenter_);
   int ishell = 0;
   for (int icenter=0; icenter<ncenter_; icenter++) {
       if (skip_ghosts && molecule()->charge(icenter) == 0.0) {
@@ -376,11 +384,13 @@ GaussianBasisSet::init2(int skip_ghosts)
      }
 
   // compute nbasis_ and shell_to_function_[]
-  shell_to_function_.set_length(nshell_);
+  shell_to_function_.resize(nshell_);
+  shell_to_primitive_.resize(nshell_);
   nbasis_ = 0;
   nprim_ = 0;
   for (ishell=0; ishell<nshell_; ishell++) {
       shell_to_function_[ishell] = nbasis_;
+      shell_to_primitive_[ishell] = nprim_;
       nbasis_ += shell_[ishell]->nfunction();
       nprim_ += shell_[ishell]->nprimitive();
     }
@@ -388,7 +398,7 @@ GaussianBasisSet::init2(int skip_ghosts)
   // would like to do this in function_to_shell(), but it is const
   int n = nbasis();
   int nsh = nshell();
-  function_to_shell_.set_length(n);
+  function_to_shell_.resize(n);
   int ifunc = 0;
   for (int i=0; i<nsh; i++) {
       int nfun = operator()(i).nfunction();
@@ -439,22 +449,22 @@ GaussianBasisSet::
     }
   count = keyval->count(keyword);
   if (keyval->error() != KeyVal::OK) {
-      ExEnv::err() << node0 << indent
+      ExEnv::err0() << indent
            << scprintf("GaussianBasisSet:: couldn't find \"%s\":\n", keyword);
-      keyval->errortrace(ExEnv::err());
+      keyval->errortrace(ExEnv::err0());
       exit(1);
     }
   if (!count) return;
   for (int j=0; j<count; j++) {
       sprintf(prefix,":basis:%s:%s",
 	      element,basisname);
-      Ref<KeyVal> prefixkeyval = new PrefixKeyVal(prefix,keyval,j);
+      Ref<KeyVal> prefixkeyval = new PrefixKeyVal(keyval,prefix,j);
       if (prefixkeyval->exists("get")) {
           char* newbasis = prefixkeyval->pcharvalue("get");
           if (!newbasis) {
-	      ExEnv::err() << node0 << indent << "GaussianBasisSet: "
+	      ExEnv::err0() << indent << "GaussianBasisSet: "
                    << scprintf("error processing get for \"%s\"\n", prefix);
-              keyval->errortrace(ExEnv::err());
+              keyval->errortrace(ExEnv::err0());
 	      exit(1);
 	    }
 	  recursively_get_shell(ishell,keyval,element,newbasis,bases,
@@ -540,6 +550,17 @@ GaussianBasisSet::max_ncartesian_in_shell(int aminc) const
   return max;
 }
 
+int
+GaussianBasisSet::max_nprimitive_in_shell() const
+{
+  int i;
+  int max = 0;
+  for (i=0; i<nshell_; i++) {
+      if (max < shell_[i]->nprimitive()) max = shell_[i]->nprimitive();
+    }
+  return max;
+}
+
 int
 GaussianBasisSet::max_am_for_contraction(int con) const
 {
@@ -580,19 +601,19 @@ GaussianBasisSet::nbasis_on_center(int icenter) const
 int
 GaussianBasisSet::shell_on_center(int icenter, int ishell) const
 {
-  return center_to_shell_(icenter) + ishell;
+  return center_to_shell_[icenter] + ishell;
 }
 
 const GaussianShell&
 GaussianBasisSet::operator()(int icenter,int ishell) const
 {
-  return *shell_[center_to_shell_(icenter) + ishell];
+  return *shell_[center_to_shell_[icenter] + ishell];
 }
 
 GaussianShell&
 GaussianBasisSet::operator()(int icenter,int ishell)
 {
-  return *shell_[center_to_shell_(icenter) + ishell];
+  return *shell_[center_to_shell_[icenter] + ishell];
 }
 
 int
@@ -608,13 +629,13 @@ GaussianBasisSet::equiv(const Ref<GaussianBasisSet> &b)
 void
 GaussianBasisSet::print_brief(ostream& os) const
 {
-  os << node0 << indent
+  os << indent
      << "GaussianBasisSet:" << endl << incindent
      << indent << "nbasis = " << nbasis_ << endl
      << indent << "nshell = " << nshell_ << endl
      << indent << "nprim  = " << nprim_ << endl;
   if (name_) {
-      os << node0 << indent
+      os << indent
          << "name = \"" << name_ << "\"" << endl;
     }
   os << decindent;
@@ -632,7 +653,7 @@ GaussianBasisSet::print(ostream& os) const
   int icenter = 0;
   int ioshell = 0;
   for (icenter=0; icenter < ncenter_; icenter++) {
-      os << node0 << endl << indent
+      os << endl << indent
          << scprintf(
              "center %d: %12.8f %12.8f %12.8f, nshell = %d, shellnum = %d\n",
              icenter,
@@ -642,17 +663,17 @@ GaussianBasisSet::print(ostream& os) const
              center_to_nshell_[icenter],
              center_to_shell_[icenter]);
       for (int ishell=0; ishell < center_to_nshell_[icenter]; ishell++) {
-	  os << node0 << indent
-             << scprintf("Shell %d: functionnum = %d\n",
-                         ishell,shell_to_function_[ioshell]);
-          os << node0 << incindent;
+	  os << indent
+             << scprintf("Shell %d: functionnum = %d, primnum = %d\n",
+                         ishell,shell_to_function_[ioshell],shell_to_primitive_[ioshell]);
+          os << incindent;
 	  operator()(icenter,ishell).print(os);
-          os << node0 << decindent;
+          os << decindent;
           ioshell++;
 	}
     }
 
-  os << node0 << decindent;
+  os << decindent;
 }
 
 /////////////////////////////////////////////////////////////////////////////
