@@ -32,15 +32,17 @@
 #pragma interface
 #endif
 
+#include <vector>
 #include <iostream>
 
 #include <util/state/state.h>
-#include <util/state/array.h>
 #include <util/keyval/keyval.h>
 #include <math/scmat/matrix.h>
 #include <math/scmat/vector3.h>
 #include <chemistry/molecule/molecule.h>
 
+namespace sc {
+
 class GaussianShell;
 class BasisFileSet;
 class Integral;
@@ -114,8 +116,8 @@ class GaussianBasisSet: public SavableState
   private:
     char* name_;
     GaussianShell** shell_;
-    Arrayint shell_to_function_;
-    Arrayint function_to_shell_;
+    std::vector<int> shell_to_function_;
+    std::vector<int> function_to_shell_;
 
     Ref<Molecule> molecule_;
 
@@ -124,10 +126,12 @@ class GaussianBasisSet: public SavableState
     RefSCDimension basisdim_;
 
     int ncenter_;
-    SSBArrayint shell_to_center_;
-    SSBArrayint center_to_shell_;
-    SSBArrayint center_to_nshell_;
-    SSBArrayint center_to_nbasis_;
+
+    std::vector<int> shell_to_center_;
+    std::vector<int> shell_to_primitive_;
+    std::vector<int> center_to_shell_;
+    std::vector<int> center_to_nshell_;
+    std::vector<int> center_to_nbasis_;
 
     int nshell_;
     int nbasis_;
@@ -299,7 +303,9 @@ class GaussianBasisSet: public SavableState
         on that center. */
     int shell_on_center(int icenter, int shell) const;
     /// Return the center on which the given shell is located.
-    int shell_to_center(int ishell) const { return shell_to_center_(ishell); }
+    int shell_to_center(int ishell) const { return shell_to_center_[ishell]; }
+    /// Return the overall index of the first primitive from the given shell
+    int shell_to_primitive(int ishell) const {return shell_to_primitive_[ishell]; }
     /// Return the number of basis functions.
     int nbasis() const { return nbasis_; }
     /// Return the number of basis functions on the given center.
@@ -312,6 +318,8 @@ class GaussianBasisSet: public SavableState
     /** Return the maximum number of Cartesian functions that any shell has.
         The optional argument is an angular momentum increment. */
     int max_ncartesian_in_shell(int aminc=0) const;
+    /// Return the maximum number of primitive Gaussian that any shell has.
+    int max_nprimitive_in_shell() const;
     /// Return the highest angular momentum in any shell.
     int max_angular_momentum() const;
     /// Return the maximum number of Gaussians in a contraction in any shell.
@@ -323,7 +331,7 @@ class GaussianBasisSet: public SavableState
     int max_cartesian() const;
 
     /// Return the number of the first function in the given shell.
-    int shell_to_function(int i) const { return shell_to_function_(i); }
+    int shell_to_function(int i) const { return shell_to_function_[i]; }
     /// Return the shell to which the given function belongs.
     int function_to_shell(int i) const;
 
@@ -389,12 +397,12 @@ class GaussianBasisSet: public SavableState
     int equiv(const Ref<GaussianBasisSet> &b);
 
     /// Print a brief description of the basis set.
-    void print_brief(std::ostream& =ExEnv::out()) const;
+    void print_brief(std::ostream& =ExEnv::out0()) const;
     /// Print a detailed description of the basis set.
-    void print(std::ostream& =ExEnv::out()) const;
+    void print(std::ostream& =ExEnv::out0()) const;
 };
 
-
+}
 
 #endif
 
