@@ -36,6 +36,8 @@
 #include <math/scmat/vector3.h>
 #include <chemistry/qc/wfn/wfn.h>
 
+namespace sc {
+
 /** Contains data needed at each point by a DenFunctional. */
 struct PointInputData {
     enum {X=0, Y=1, Z=2};
@@ -166,7 +168,7 @@ class SumDenFunctional: public DenFunctional {
 
     void point(const PointInputData&, PointOutputData&);
 
-    void print(std::ostream& =ExEnv::out()) const;
+    void print(std::ostream& =ExEnv::out0()) const;
 };
 
 /** The StdDenFunctional class is used to construct the standard density
@@ -255,7 +257,7 @@ class StdDenFunctional: public SumDenFunctional {
     ~StdDenFunctional();
     void save_data_state(StateOut &);
 
-    void print(std::ostream& =ExEnv::out()) const;
+    void print(std::ostream& =ExEnv::out0()) const;
 };
 
 /** An abstract base class for local correlation functionals. */
@@ -585,7 +587,7 @@ class XalphaFunctional: public DenFunctional {
 
     void point(const PointInputData&, PointOutputData&);
 
-    void print(std::ostream& =ExEnv::out()) const;
+    void print(std::ostream& =ExEnv::out0()) const;
 };
 
 /** Implements Becke's 1988 exchange functional.
@@ -797,6 +799,8 @@ class G96XFunctional: public DenFunctional {
     void point(const PointInputData&, PointOutputData&);
 };
 
+}
+
 #endif
 
 // Local Variables:
