@@ -38,6 +38,9 @@
 #include <chemistry/qc/dft/integrator.h>
 
 using namespace std;
+using namespace sc;
+
+namespace sc {
 
 #ifdef EXPLICIT_TEMPLATE_INSTANTIATION
 template void delete_c_array2<Ref<RadialIntegrator> >(Ref<RadialIntegrator>**);
@@ -55,7 +58,7 @@ template Ref<AngularIntegrator>***
   new_c_array3<Ref<AngularIntegrator> >(int,int,int,Ref<AngularIntegrator>);
 #endif
 
-//#define CHECK_ALIGN(v) if(int(&v)&7)ExEnv::out()<<"Bad Alignment: "<< ## v <<endl;
+//#define CHECK_ALIGN(v) if(int(&v)&7)ExEnv::outn()<<"Bad Alignment: "<< ## v <<endl;
 #define CHECK_ALIGN(v)
 
 ///////////////////////////////////////////////////////////////////////////
@@ -292,19 +295,19 @@ DenIntegrator::init(const Ref<Wavefunction> &wfn)
 {
   wfn_ = wfn;
   if (linear_scaling_) {
-      ExEnv::out() << node0 << indent << "Initializing ShellExtent" << endl;
+      ExEnv::out0() << indent << "Initializing ShellExtent" << endl;
       extent_ = new ShellExtent;
       extent_->init(wfn_->basis());
-      ExEnv::out() << node0 << indent
+      ExEnv::out0() << indent
            << "  nshell = " << wfn_->basis()->nshell() << endl;
       int ncell = extent_->n(0)*extent_->n(1)*extent_->n(2);
-      ExEnv::out() << node0 << indent << "  ncell = " << ncell << endl;
+      ExEnv::out0() << indent << "  ncell = " << ncell << endl;
       int maxval = 0;
       double ave = 0;
       for (int i=0; i<extent_->n(0); i++) {
           for (int j=0; j<extent_->n(1); j++) {
               for (int k=0; k<extent_->n(2); k++) {
-                  const ArrayExtentData &e
+                  const std::vector<ExtentData> &e
                       = extent_->contributing_shells(i,j,k);
                   int val = e.size();
                   if (val > maxval) maxval = val;
@@ -313,8 +316,8 @@ DenIntegrator::init(const Ref<Wavefunction> &wfn)
             }
         }
       ave /= ncell;
-      ExEnv::out() << node0 << indent << "  ave nsh/cell = " << ave << endl;
-      ExEnv::out() << node0 << indent << "  max nsh/cell = " << maxval << endl;
+      ExEnv::out0() << indent << "  ave nsh/cell = " << ave << endl;
+      ExEnv::out0() << indent << "  max nsh/cell = " << maxval << endl;
     }
 }
 
@@ -589,7 +592,7 @@ DenIntegratorThread::do_point(int acenter, const SCVector3 &r,
 
   // only consider those shells for which phi_i * (Max_j D_ij phi_j) > tol
   if (linear_scaling_ && use_dmat_bound_) {
-      const ArrayExtentData &cs = extent_->contributing_shells(r[0],r[1],r[2]);
+      const std::vector<ExtentData> &cs = extent_->contributing_shells(r[0],r[1],r[2]);
       ncontrib_ = 0;
       for (i=0; i<cs.size(); i++) {
           int ish = cs[i].shell;
@@ -608,7 +611,7 @@ DenIntegratorThread::do_point(int acenter, const SCVector3 &r,
         }
     }
   else if (linear_scaling_) {
-      const ArrayExtentData &cs = extent_->contributing_shells(r[0],r[1],r[2]);
+      const std::vector<ExtentData> &cs = extent_->contributing_shells(r[0],r[1],r[2]);
       ncontrib_ = cs.size();
       for (i=0; i<ncontrib_; i++) {
           contrib_[i] = cs[i].shell;
@@ -619,7 +622,7 @@ DenIntegratorThread::do_point(int acenter, const SCVector3 &r,
       for (i=0; i<nshell_; i++) contrib_[i] = i;
     }
   if (ncontrib_ > nshell_) {
-      ExEnv::out() << "DenIntegratorThread::do_point: ncontrib invalid"
+      ExEnv::outn() << "DenIntegratorThread::do_point: ncontrib invalid"
                    << endl;
       abort();
     }
@@ -833,7 +836,7 @@ IntegrationWeight::fd_w(int icenter, SCVector3 &point,
           dmol->r(i,j) += delta;
           if (icenter == i) point[j] += delta;
           fd_grad_w[i*3+j] = (w_plus-w_minus)/(2.0*delta);
-//            ExEnv::out() << scprintf("%d,%d %12.10f %12.10f %12.10f",
+//            ExEnv::outn() << scprintf("%d,%d %12.10f %12.10f %12.10f",
 //                             i,j,w_plus,w_minus,fd_grad_w[i*3+j])
 //                 << endl;
         }
@@ -855,8 +858,8 @@ IntegrationWeight::test(int icenter, SCVector3 &point)
       sum_weight += weight;
     }
   if (fabs(1.0 - sum_weight) > DBL_EPSILON) {
-      ExEnv::out() << "IntegrationWeight::test: failed on weight" << endl;
-          ExEnv::out() << "sum_w = " << sum_weight << endl;
+      ExEnv::out0() << "IntegrationWeight::test: failed on weight" << endl;
+      ExEnv::out0() << "sum_w = " << sum_weight << endl;
     }
 
   // finite displacement tests of weight gradients
@@ -871,10 +874,10 @@ IntegrationWeight::test(int icenter, SCVector3 &point)
       if (mag > 0.00001 && err/mag > 0.01) bad = 1;
       else if (err > 0.00001) bad = 1;
       if (bad) {
-          ExEnv::out() << "iatom = " << i/3
+          ExEnv::out0() << "iatom = " << i/3
                << " ixyx = " << i%3
                << " icenter = " << icenter << " point = " << point << endl;
-          ExEnv::out() << scprintf("dw/dx bad: fd_val=%16.13f an_val=%16.13f err=%16.13f",
+          ExEnv::out0() << scprintf("dw/dx bad: fd_val=%16.13f an_val=%16.13f err=%16.13f",
                            fd_grad_w[i], an_grad_w[i],
                            fd_grad_w[i]-an_grad_w[i])
                << endl;
@@ -1172,11 +1175,11 @@ BeckeIntegrationWeight::w(int acenter, SCVector3 &point,
       int i,j;
       for (i=0; i<ncenters*3; i++ ) w_gradient[i] = 0.0;
 //      fd_w(acenter, point, w_gradient);  // imbn commented out for debug
-//        ExEnv::out() << point << " ";
+//        ExEnv::outn() << point << " ";
 //        for (int i=0; i<ncenters*3; i++) {
-//            ExEnv::out() << scprintf(" %10.6f", w_gradient[i]);
+//            ExEnv::outn() << scprintf(" %10.6f", w_gradient[i]);
 //          }
-//        ExEnv::out() << endl;
+//        ExEnv::outn() << endl;
 //      return w_a;  // imbn commented out for debug
       for (int ccenter = 0; ccenter < ncenters; ccenter++) {
           // NB: for ccenter==acenter, use translational invariance
@@ -1329,7 +1332,7 @@ EulerMaclaurinRadialIntegrator::radial_value(int ir, int nr, double radii,
 void
 EulerMaclaurinRadialIntegrator::print(ostream &o) const
 {
-  o << node0 << indent
+  o << indent
     << scprintf("%s: nr = %d", class_name(), nr()) << endl;
 }
 
@@ -1395,19 +1398,19 @@ LebedevLaikovIntegrator::nw(void) const
 void
 LebedevLaikovIntegrator::init(int n)
 {
-  // ExEnv::out() << " LebedevLaikovIntegrator::init -> before x_, y_, z_, and w_ malloc's " << endl;
-  // ExEnv::out() << " n = " << n << endl;
+  // ExEnv::outn() << " LebedevLaikovIntegrator::init -> before x_, y_, z_, and w_ malloc's " << endl;
+  // ExEnv::outn() << " n = " << n << endl;
   
   x_ = new double[n];
   y_ = new double[n];
   z_ = new double[n];
   w_ = new double[n];
 
-  // ExEnv::out() << " LebedevLaikovIntegrator::init -> nw_points = " << n << endl;
+  // ExEnv::outn() << " LebedevLaikovIntegrator::init -> nw_points = " << n << endl;
   
   npoint_ = Lebedev_Laikov_sphere(n, x_, y_, z_, w_);
   if (npoint_ != n) {
-      ExEnv::out() << class_name() << ": bad number of points given: " << n << endl;
+      ExEnv::outn() << class_name() << ": bad number of points given: " << n << endl;
       abort();
     }
 }
@@ -1434,7 +1437,7 @@ LebedevLaikovIntegrator
 void
 LebedevLaikovIntegrator::print(ostream &o) const
 {
-  o << node0 << indent
+  o << indent
     << scprintf("%s:  n = %d", class_name(), npoint_) << endl;
 }
 
@@ -1656,11 +1659,11 @@ GaussLegendreAngularIntegrator
 void
 GaussLegendreAngularIntegrator::print(ostream &o) const
 {
-  o << node0 << indent << class_name() << ":" << endl;
+  o << indent << class_name() << ":" << endl;
   o << incindent;
-  o << node0 << indent << scprintf("ntheta   = %5d", get_ntheta()) << endl;
-  o << node0 << indent << scprintf("nphi     = %5d", get_nphi()) << endl;
-  o << node0 << indent << scprintf("Ktheta   = %5d", get_Ktheta()) << endl;
+  o << indent << scprintf("ntheta   = %5d", get_ntheta()) << endl;
+  o << indent << scprintf("nphi     = %5d", get_nphi()) << endl;
+  o << indent << scprintf("Ktheta   = %5d", get_Ktheta()) << endl;
   o << decindent;
 }
 
@@ -1716,6 +1719,7 @@ RadialAngularIntegratorThread
 {
   int icenter;
   ra_integrator_ = integrator;
+  int deriv_order = (need_nuclear_gradient==0?0:1);
 
   mol_ = integrator_->wavefunction()->molecule().pointer();
 
@@ -1724,7 +1728,8 @@ RadialAngularIntegratorThread
   nr_ = new int[natom_];
   
   for (icenter=0; icenter<natom_; icenter++)
-      nr_[icenter] = ra_integrator_->get_radial_grid(mol_->Z(icenter))->nr();
+      nr_[icenter]
+	= ra_integrator_->get_radial_grid(mol_->Z(icenter),deriv_order)->nr();
 
   centers_ = new SCVector3[natom_];
   for (icenter=0; icenter<natom_; icenter++) {
@@ -1763,6 +1768,7 @@ RadialAngularIntegratorThread::run()
   SCVector3 integration_point;
 
   double w,radial_multiplier,angular_multiplier;
+  int deriv_order = (nuclear_gradient_==0?0:1);
         
   int parallel_counter = 0;
 
@@ -1771,7 +1777,7 @@ RadialAngularIntegratorThread::run()
       center = centers_[icenter];
       // get current radial grid: depends on convergence threshold
       RadialIntegrator *radial
-          = ra_integrator_->get_radial_grid(mol_->Z(icenter));
+          = ra_integrator_->get_radial_grid(mol_->Z(icenter), deriv_order);
       nr = radial->nr();
       for (ir=0; ir < nr; ir++) {
           if (! (parallel_counter++%nthread_ == ithread_)) continue;
@@ -1780,7 +1786,8 @@ RadialAngularIntegratorThread::run()
           // get current angular grid: depends on radial point and threshold
           AngularIntegrator *angular
               = ra_integrator_->get_angular_grid(r, atomic_radius_[icenter],
-                                                 mol_->Z(icenter));
+                                                 mol_->Z(icenter),
+						 deriv_order);
           nangular = angular->num_angular_points(r/atomic_radius_[icenter],ir);
           for (iangular=0; iangular<nangular; iangular++) {
               angular_multiplier
@@ -1819,15 +1826,15 @@ RadialAngularIntegrator::RadialAngularIntegrator(StateIn& s):
   s.get(npruned_partitions_);
   s.get(dynamic_grids_);
 
-//  ExEnv::out() << "natomic_rows_ = " << natomic_rows_ << endl;
-//  ExEnv::out() << "max_gridtype_ = " << max_gridtype_ << endl;
-//  ExEnv::out() << "prune_grid_ = " << prune_grid_ << endl;
-//  ExEnv::out() << "gridtype_ = " << gridtype_ << endl;
-//  ExEnv::out() << "npruned_partitions_ = " << npruned_partitions_ << endl;
-//  ExEnv::out() << "dynamic_grids_ = " << dynamic_grids_ << endl;
+//  ExEnv::outn() << "natomic_rows_ = " << natomic_rows_ << endl;
+//  ExEnv::outn() << "max_gridtype_ = " << max_gridtype_ << endl;
+//  ExEnv::outn() << "prune_grid_ = " << prune_grid_ << endl;
+//  ExEnv::outn() << "gridtype_ = " << gridtype_ << endl;
+//  ExEnv::outn() << "npruned_partitions_ = " << npruned_partitions_ << endl;
+//  ExEnv::outn() << "dynamic_grids_ = " << dynamic_grids_ << endl;
   
 
-//  ExEnv::out() << "In StateIn Constructor!" << endl;
+//  ExEnv::outn() << "In StateIn Constructor!" << endl;
   weight_ = new BeckeIntegrationWeight;
 
   int i;
@@ -1866,7 +1873,7 @@ RadialAngularIntegrator::RadialAngularIntegrator(const Ref<KeyVal>& keyval):
 
   weight_ << keyval->describedclassvalue("weight");
   if (weight_.null()) weight_ = new BeckeIntegrationWeight;
-//  ExEnv::out() << "In Ref<KeyVal> Constructor" << endl;
+//  ExEnv::outn() << "In Ref<KeyVal> Constructor" << endl;
   
   init_parameters(keyval);
   init_default_grids();
@@ -1898,12 +1905,12 @@ RadialAngularIntegrator::save_data_state(StateOut& s)
   s.put(dynamic_grids_);
   s.put_array_double(Alpha_coeffs_[0],natomic_rows_*(npruned_partitions_-1));
   
-//  ExEnv::out() << "natomic_rows_ = " << natomic_rows_ << endl;
-//  ExEnv::out() << "max_gridtype_ = " << max_gridtype_ << endl;
-//  ExEnv::out() << "prune_grid_ = " << prune_grid_ << endl;
-//  ExEnv::out() << "gridtype_ = " << gridtype_ << endl;
-//  ExEnv::out() << "npruned_partitions_ = " << npruned_partitions_ << endl;
-//  ExEnv::out() << "dynamic_grids_ = " << dynamic_grids_ << endl;
+//  ExEnv::outn() << "natomic_rows_ = " << natomic_rows_ << endl;
+//  ExEnv::outn() << "max_gridtype_ = " << max_gridtype_ << endl;
+//  ExEnv::outn() << "prune_grid_ = " << prune_grid_ << endl;
+//  ExEnv::outn() << "gridtype_ = " << gridtype_ << endl;
+//  ExEnv::outn() << "npruned_partitions_ = " << npruned_partitions_ << endl;
+//  ExEnv::outn() << "dynamic_grids_ = " << dynamic_grids_ << endl;
   
   SavableState::save_state(radial_user_.pointer(),s);
   SavableState::save_state(angular_user_.pointer(),s);
@@ -1927,7 +1934,7 @@ RadialAngularIntegrator::init_parameters(void)
     
   init_pruning_coefficients();
 
-  // ExEnv::out() << "gridtype_ = " << gridtype_ << endl;
+  // ExEnv::outn() << "gridtype_ = " << gridtype_ << endl;
   
 }
 
@@ -1949,7 +1956,7 @@ RadialAngularIntegrator::init_parameters(const Ref<KeyVal>& keyval)
       else if (!strcmp(grid,"xfine"))     gridtype_ = 4;
       else if (!strcmp(grid,"ultrafine")) gridtype_ = 5;
       else {
-          ExEnv::out() << node0
+          ExEnv::out0()
                        << indent
                        << "ERROR: grid = \"" << grid << "\" not recognized."
                        << endl
@@ -1969,12 +1976,12 @@ RadialAngularIntegrator::init_parameters(const Ref<KeyVal>& keyval)
 
 
   
-  //ExEnv::out() << " gridtype = " << gridtype_ << endl;
-  //ExEnv::out() << " max_gridtype = " << max_gridtype_ << endl;
+  //ExEnv::outn() << " gridtype = " << gridtype_ << endl;
+  //ExEnv::outn() << " max_gridtype = " << max_gridtype_ << endl;
   dynamic_grids_ = keyval->intvalue("dynamic");
   if (keyval->error() != KeyVal::OK) dynamic_grids_ = 1;
   grid_accuracy_ = new double[max_gridtype_];
-  //ExEnv::out() << "init_parameters:: max_gridtype_ = " << max_gridtype_;
+  //ExEnv::outn() << "init_parameters:: max_gridtype_ = " << max_gridtype_;
   
   int i;
   grid_accuracy_[0] = 1e-4;
@@ -2007,7 +2014,7 @@ RadialAngularIntegrator::set_grids(void)
       prune_formula_2[0] = 0;
     }
   else if (npruned_partitions_ != 5) {
-      ExEnv::err() << "RadialAngularIntegrator::set_grids: "
+      ExEnv::errn() << "RadialAngularIntegrator::set_grids: "
                    << "npruned_partitations must be 1 or 5" << endl;
       abort();
     }
@@ -2037,7 +2044,7 @@ RadialAngularIntegrator::set_grids(void)
 
               angular_grid_[i][j][k]
                   = new LebedevLaikovIntegrator(Lebedev_Laikov_npoint(use_l));
-//                ExEnv::out() << " angular_grid_["
+//                ExEnv::outn() << " angular_grid_["
 //                             << i << "]["
 //                             << j << "]["
 //                             << k
@@ -2056,8 +2063,8 @@ void
 RadialAngularIntegrator::init_pruning_coefficients(void)
 {
   // Set up Alpha arrays for pruning
-  //ExEnv::out() << "npruned_partitions = " << npruned_partitions_ << endl;
-  //ExEnv::out() << "natomic_rows = " << natomic_rows_ << endl;
+  //ExEnv::outn() << "npruned_partitions = " << npruned_partitions_ << endl;
+  //ExEnv::outn() << "natomic_rows = " << natomic_rows_ << endl;
   int num_boundaries = npruned_partitions_-1;
   Alpha_coeffs_ = new_zero_c_array2(natomic_rows_, num_boundaries,
                                             double(0));
@@ -2075,7 +2082,7 @@ RadialAngularIntegrator::init_pruning_coefficients(const Ref<KeyVal>& keyval)
   prune_grid_ = keyval->booleanvalue("prune_grid");
   if (keyval->error() != KeyVal::OK) prune_grid_ = 1;
 
-  // ExEnv::out() << "prune_grid = " << prune_grid_ << endl;
+  // ExEnv::outn() << "prune_grid = " << prune_grid_ << endl;
   
   // Need to generalize this to parse input for any number of grids
   if (prune_grid_) {
@@ -2089,7 +2096,7 @@ RadialAngularIntegrator::init_pruning_coefficients(const Ref<KeyVal>& keyval)
       int alpha_rows = keyval->count("alpha_coeffs");
       if (keyval->error() != KeyVal::OK) {
           if (npruned_partitions_ != 5) {
-              ExEnv::out() << " RadialAngularIntegrator:: Need to supply alpha coefficients "
+              ExEnv::outn() << " RadialAngularIntegrator:: Need to supply alpha coefficients "
                    << "for the " << num_boundaries << " partition boundaries " << endl;
               abort();
             }
@@ -2100,7 +2107,7 @@ RadialAngularIntegrator::init_pruning_coefficients(const Ref<KeyVal>& keyval)
           for (i=0; i<alpha_rows; i++) {
               check = keyval->count("alpha_coeffs", i);
               if (check != num_boundaries) {
-                  ExEnv::out() << "RadialAngularIntegrator:: Number of alpha coefficients does "
+                  ExEnv::outn() << "RadialAngularIntegrator:: Number of alpha coefficients does "
                        << "not match the number of boundaries (" << check << " != "
                        << num_boundaries << ")" << endl;
                   abort();
@@ -2181,13 +2188,14 @@ RadialAngularIntegrator::angular_grid_offset(int gridtype)
 }
 
 RadialIntegrator *
-RadialAngularIntegrator::get_radial_grid(int charge)
+RadialAngularIntegrator::get_radial_grid(int charge, int deriv_order)
 {
   if (radial_user_.null()) {
 
       int select_grid;
       
-      if (dynamic_grids_) select_grid = select_dynamic_grid();
+      if (dynamic_grids_ && deriv_order == 0)
+	  select_grid = select_dynamic_grid();
       else select_grid = gridtype_;
       //ExEnv::out << "RAI::get_radial_grid -> select_grid = " << select_grid;
       
@@ -2197,7 +2205,7 @@ RadialAngularIntegrator::get_radial_grid(int charge)
       else if (charge<37) return radial_grid_[3][select_grid].pointer();
       else if (charge<55) return radial_grid_[4][select_grid].pointer();
       else {
-          ExEnv::out() << " No default radial grids for atomic charge " << charge << endl;
+          ExEnv::outn() << " No default radial grids for atomic charge " << charge << endl;
           abort();
         }
     }
@@ -2236,7 +2244,7 @@ RadialAngularIntegrator::get_atomic_row(int i)
   else if (i<55) return 4;
   else if (i<87) return 5;
 
-  ExEnv::out() << " RadialAngularIntegrator::get_atomic_row: Z too large: "
+  ExEnv::outn() << " RadialAngularIntegrator::get_atomic_row: Z too large: "
                << i << endl;
   abort();
   return 0;
@@ -2244,12 +2252,12 @@ RadialAngularIntegrator::get_atomic_row(int i)
 
 AngularIntegrator *
 RadialAngularIntegrator::get_angular_grid(double radius, double atomic_radius,
-                                          int Z)
+                                          int Z, int deriv_order)
 {
   int atomic_row, i;
 
   int select_grid;
-  if (dynamic_grids_) select_grid = select_dynamic_grid();
+  if (dynamic_grids_ && deriv_order == 0) select_grid = select_dynamic_grid();
   else select_grid = gridtype_;
 
   //ExEnv::out << "RAI::get_angular_grid -> select_grid = " << select_grid;
@@ -2317,7 +2325,7 @@ RadialAngularIntegrator::integrate(const Ref<DenFunctional> &denfunc,
     }
 
   //for (i=0; i<nthread; i++) {
-  //    ExEnv::out() << "Intial Thread " << i
+  //    ExEnv::outn() << "Intial Thread " << i
   //                 << ": point count = " << threads[i]->point_count()
   //                 << " total density = " << threads[i]->total_density()
   //                 << " value = " << threads[i]->value()
@@ -2337,7 +2345,7 @@ RadialAngularIntegrator::integrate(const Ref<DenFunctional> &denfunc,
   double total_density = 0.0;
   value_ = 0.0;
   for (i=0; i<nthread; i++) {
-      //ExEnv::out() << "Thread " << i
+      //ExEnv::outn() << "Thread " << i
       //             << ": point count = " << threads[i]->point_count()
       //             << " total density = " << threads[i]->total_density()
       //             << " value = " << threads[i]->value()
@@ -2371,9 +2379,9 @@ RadialAngularIntegrator::integrate(const Ref<DenFunctional> &denfunc,
   done_integration();
   weight_->done();
 
-  ExEnv::out() << node0 << indent
+  ExEnv::out0() << indent
        << "Total integration points = " << point_count_total << endl;
-  ExEnv::out() << node0 << indent
+  ExEnv::out0() << indent
                << "Integrated electron density error = "
                << scprintf("%14.12f", total_density-wfn_->nelectron())
                << endl;
@@ -2384,32 +2392,32 @@ RadialAngularIntegrator::integrate(const Ref<DenFunctional> &denfunc,
 void
 RadialAngularIntegrator::print(ostream &o) const
 {
-  o << node0 << indent << class_name() << ":" << endl;
+  o << indent << class_name() << ":" << endl;
   o << incindent;
   if (radial_user_.nonnull()) {
-      cout << node0 << indent << "User defined radial grid:" << endl;
+      o << indent << "User defined radial grid:" << endl;
       o << incindent;
       radial_user_->print(o);
       o << decindent;
     }
   if (angular_user_.nonnull()) {
-      cout << node0 << indent << "User defined angular grid:" << endl;
+      o << indent << "User defined angular grid:" << endl;
       o << incindent;
       angular_user_->print(o);
       o << decindent;
     }
   if (angular_user_.null() || radial_user_.null()) {
-      if (prune_grid_) o << node0 << indent << "Pruned ";
+      if (prune_grid_) o << indent << "Pruned ";
       switch (gridtype_) {
-      case 0: o << node0 << "xcoarse"; break;
-      case 1: o << node0 << "coarse"; break;
-      case 2: o << node0 << "medium"; break;
-      case 3: o << node0 << "fine"; break;
-      case 4: o << node0 << "xfine"; break;
-      case 5: o << node0 << "ultrafine"; break;
-      default: o << node0 << "unknown"; break;
+      case 0: o << "xcoarse"; break;
+      case 1: o << "coarse"; break;
+      case 2: o << "medium"; break;
+      case 3: o << "fine"; break;
+      case 4: o << "xfine"; break;
+      case 5: o << "ultrafine"; break;
+      default: o << "unknown"; break;
         }
-      o << node0 << " grid employed" << endl;
+      o << " grid employed" << endl;
     }
   
   o << decindent;
@@ -2417,6 +2425,8 @@ RadialAngularIntegrator::print(ostream &o) const
 
 /////////////////////////////////////////////////////////////////////////////
 
+}
+
 // Local Variables:
 // mode: c++
 // c-file-style: "CLJ"
