@@ -29,6 +29,7 @@
 #include <assert.h>
 #include <math.h>
 
+#include <scconfig.h>
 #include <util/misc/formio.h>
 #include <chemistry/qc/intv3/macros.h>
 #include <chemistry/qc/intv3/fjt.h>
@@ -36,13 +37,14 @@
 #include <chemistry/qc/intv3/int2e.h>
 
 using namespace std;
+using namespace sc;
 
 #define CHECK_STACK_ALIGNMENT 0
 #if CHECK_STACK_ALIGNMENT
 static void
 stack_alignment_error(void *ptr, const char *where)
 {
-  ExEnv::out() << "UNALIGNED STACK: " << where << ": " << ptr << endl;
+  ExEnv::outn() << "UNALIGNED STACK: " << where << ": " << ptr << endl;
 }
 static inline void
 stack_alignment_check(void *ptr, const char *where)
@@ -70,7 +72,7 @@ iswtch(int *i, int *j)
 static void
 fail()
 {
-  ExEnv::err() << scprintf("failing module:\n%s",__FILE__) << endl;
+  ExEnv::errn() << scprintf("failing module:\n%s",__FILE__) << endl;
   abort();
   }
 
@@ -152,8 +154,8 @@ Int2eV3::int_init_buildgc(int order,
   used_storage_build_ += contract_length.nbyte();
   used_storage_build_ += build.int_v_list.nbyte();
 #if CHECK_INTEGRAL_ALGORITHM
-  ExEnv::out() << "contract_length: " << contract_length.nbyte() << endl;
-  ExEnv::out() << "int_v_list: " << build.int_v_list.nbyte() << endl;
+  ExEnv::outn() << "contract_length: " << contract_length.nbyte() << endl;
+  ExEnv::outn() << "int_v_list: " << build.int_v_list.nbyte() << endl;
 #endif
 
   /* Set all slots to 0 */
@@ -191,7 +193,7 @@ Int2eV3::int_init_buildgc(int order,
   int_v0_buf = (double*) malloc(sizeof(double)*int_v_bufsize);
   used_storage_build_ += sizeof(double)*int_v_bufsize;
   if (!int_v0_buf) {
-    ExEnv::err() << scprintf("couldn't allocate all integral intermediates\n");
+    ExEnv::errn() << scprintf("couldn't allocate all integral intermediates\n");
     fail();
     }
   add_store(int_v0_buf);
@@ -239,14 +241,14 @@ Int2eV3::int_init_buildgc(int order,
     }
 
 #if CHECK_INTEGRAL_ALGORITHM
-  ExEnv::out() << "am12_for_con: " << am12_for_con << endl;
-  ExEnv::out() << "am34_for_con: " << am34_for_con << endl;
+  ExEnv::outn() << "am12_for_con: " << am12_for_con << endl;
+  ExEnv::outn() << "am34_for_con: " << am34_for_con << endl;
 #endif
 
   e0f0_con_ints_array[ci][cj][ck][cl].set_dim(am12+1,am34+1);
   used_storage_build_ += e0f0_con_ints_array[ci][cj][ck][cl].nbyte();
 #if CHECK_INTEGRAL_ALGORITHM
-  ExEnv::out() << "e0f0_con_ints_array: "
+  ExEnv::outn() << "e0f0_con_ints_array: "
        << e0f0_con_ints_array[ci][cj][ck][cl].nbyte()
        << endl;
 #endif
@@ -266,10 +268,10 @@ Int2eV3::int_init_buildgc(int order,
   e0f0_con_int_buf = (double*) malloc(sizeof(double)*e0f0_con_int_bufsize);
   used_storage_build_ += e0f0_con_int_bufsize * sizeof(double);
 #if CHECK_INTEGRAL_ALGORITHM
-  ExEnv::out() << "e0f0_int_buf: " << e0f0_con_int_bufsize * sizeof(double) << endl;
+  ExEnv::outn() << "e0f0_int_buf: " << e0f0_con_int_bufsize * sizeof(double) << endl;
 #endif
   if (!e0f0_con_int_buf) {
-    ExEnv::err() << scprintf("couldn't allocate contracted integral storage\n");
+    ExEnv::errn() << scprintf("couldn't allocate contracted integral storage\n");
     fail();
     }
   add_store(e0f0_con_int_buf);
@@ -399,7 +401,7 @@ Int2eV3::int_init_buildgc(int order,
 
   used_storage_ += used_storage_build_;
 #if CHECK_INTEGRAL_ALGORITHM
-  ExEnv::out() << "used_storage_build: " << used_storage_build_ << endl;
+  ExEnv::outn() << "used_storage_build: " << used_storage_build_ << endl;
 #endif
   }
 
@@ -505,6 +507,7 @@ Int2eV3::int_buildgcam(int minam1, int minam2, int minam3, int minam4,
    * will accumulate into. */
   for (m=minam1; m<=maxam12; m++) {
     for (n=minam3; n<=maxam34; n++) {
+  int nm_cart = INT_NCART(m)*INT_NCART(n);
   for (ci=0; ci<nc1; ci++) {
     if (m < int_shell1->am(ci)+dam1) continue;
     for (cj=0; cj<nc2; cj++) {
@@ -515,9 +518,8 @@ Int2eV3::int_buildgcam(int minam1, int minam2, int minam3, int minam4,
         for (cl=0; cl<nc4; cl++) {
           if (int_shell3->am(ck)+dam3 +int_shell4->am(cl)+dam4 < n)
             continue;
-      for (k=0; k<INT_NCART(m)*INT_NCART(n); k++) {
-        e0f0_con_ints_array[ci][cj][ck][cl](m,n)[k] = 0.0;
-        }
+          double *tmp = e0f0_con_ints_array[ci][cj][ck][cl](m,n);
+          for (int ii=0; ii<nm_cart; ii++) tmp[ii] = 0.0;
           }
         }
       }
@@ -547,10 +549,9 @@ Int2eV3::build_not_using_gcs(int nc1, int nc2, int nc3, int nc4,
   int i,j,k,l,m;
   int ci,cj,ck,cl;
   double *bufferprim;
-  double *con_ints;
 
 #if 0
-  ExEnv::out() << scprintf("not_gcs: %d%d%d%d\n",
+  ExEnv::outn() << scprintf("not_gcs: %d%d%d%d\n",
                    int_expweight1,
                    int_expweight2,
                    int_expweight3,
@@ -625,14 +626,14 @@ Int2eV3::build_not_using_gcs(int nc1, int nc2, int nc3, int nc4,
                              [maxam12]
                              [minam3]
                              [maxam34][eAB]==&BuildIntV3::impossible_integral){
-              ExEnv::err() << scprintf("trying to build with int2v%d%d%d%d (exact)\n",
+              ExEnv::errn() << scprintf("trying to build with int2v%d%d%d%d (exact)\n",
                       minam1,maxam12,minam3,maxam34);
               }
             if (!(build.*build_routine[minam1]
                                       [maxam12]
                                       [minam3]
                                       [maxam34][eAB])()) {
-              ExEnv::out() << "build2e.cc: did not succeed in building all integrals"
+              ExEnv::outn() << "build2e.cc: did not succeed in building all integrals"
                    << endl;
               abort();
               }
@@ -647,7 +648,7 @@ Int2eV3::build_not_using_gcs(int nc1, int nc2, int nc3, int nc4,
             for (m=mlower; m<=mupper; m++) {
               int o;
               int sizec = contract_length(m,nlower,nupper);
-              con_ints = e0f0_ijk[cl](m,nlower);
+              double *restrictxx con_ints = e0f0_ijk[cl](m,nlower);
               bufferprim = build.int_v_list(m,nlower,0);
 
               for (o=sizec; o!=0; o--) {
@@ -662,7 +663,7 @@ Int2eV3::build_not_using_gcs(int nc1, int nc2, int nc3, int nc4,
             for (m=mlower; m<=mupper; m++) {
               int o;
               int sizec = contract_length(m,nlower,nupper);
-              con_ints = e0f0_ijk[cl](m,nlower);
+              double *restrictxx con_ints = e0f0_ijk[cl](m,nlower);
               bufferprim = build.int_v_list(m,nlower,0);
 
               for (o=sizec; o!=0; o--) {
@@ -695,7 +696,6 @@ Int2eV3::build_using_gcs(int nc1, int nc2, int nc3, int nc4,
   double coef0,coef1,coef2,coef3;
   double ishl1expi=1.0, ishl2expj=1.0, ishl3expk=1.0;
   double *bufferprim;
-  double *con_ints;
   double c0scale;
 
   /* Loop over the primitives. */
@@ -728,11 +728,11 @@ Int2eV3::build_using_gcs(int nc1, int nc2, int nc3, int nc4,
           else if ((minam1<=MG)&&(minam3<=MG)&&(maxam12<=MG)&&(maxam34<=MG)) {
             intfunc brptr=build_routine[minam1][maxam12][minam3][maxam34][eAB];
             if (brptr == &BuildIntV3::impossible_integral) {
-              ExEnv::err() << scprintf("trying to build with int2v%d%d%d%d (exact)\n",
+              ExEnv::errn() << scprintf("trying to build with int2v%d%d%d%d (exact)\n",
                       minam1,maxam12,minam3,maxam34);
               }
             if (!(build.*brptr)()) {
-              ExEnv::out() << "build2e.cc: did not succeed in building all integrals"
+              ExEnv::outn() << "build2e.cc: did not succeed in building all integrals"
                    << endl;
               abort();
               }
@@ -773,7 +773,7 @@ Int2eV3::build_using_gcs(int nc1, int nc2, int nc3, int nc4,
             for (m=mlower; m<=mupper; m++) {
               int o;
               int sizec = contract_length(m,nlower,nupper);
-              con_ints = e0f0_ijk[cl](m,nlower);
+              double *restrictxx con_ints = e0f0_ijk[cl](m,nlower);
               bufferprim = build.int_v_list(m,nlower,0);
               /* Sum the integrals into the contracted integrals. */
 #ifdef SUNMOS
@@ -792,7 +792,7 @@ Int2eV3::build_using_gcs(int nc1, int nc2, int nc3, int nc4,
             for (m=mlower; m<=mupper; m++) {
               int o;
               int sizec = contract_length(m,nlower,nupper);
-              con_ints = e0f0_ijk[cl](m,nlower);
+              double *restrictxx con_ints = e0f0_ijk[cl](m,nlower);
               bufferprim = build.int_v_list(m,nlower,0);
               /* Write the integrals to the contracted integrals. */
 #ifdef SUNMOS
@@ -1118,10 +1118,18 @@ Int2eV3::blockbuildprim(int minam1,int maxam12,int minam3,int maxam34)
   // compute (a,b,m) integrals
   for (m=maxam12-1; m>=0; m--) {
     for (b=0; b<=maxam34; b++) {
-      int amin = minam1-m;
-      if (amin<1) amin=1;
+// This is how the code was for a long while,
+// but at some point it started giving the wrong
+// answers and seems wrong from inspection.  Valgrind
+// flags that uninitialized I10i integrals are being
+// used, which results from amin > 1.  I have switched
+// to the correctly behaving amin = 1.
+//       int amin = minam1-m;
+//       if (amin<1) amin=1;
+//       int amax = maxam12-m;
+//       blockbuildprim_1(amin,amax,b,m);
       int amax = maxam12-m;
-      blockbuildprim_1(amin,amax,b,m);
+      blockbuildprim_1(1,amax,b,m);
       }
     }
 }
@@ -1215,7 +1223,7 @@ Int2eV3::blockbuildprim_1(int amin,int amax,int am34,int m)
     int i12y1s34m1 = i12y1*size34m1;
     double *I10i = &I10[i12y1s34];
     double *I11i = &I11[i12y1s34];
-    double *I00i = &I00[cartindex1234];
+    double *restrictxx I00i = &I00[cartindex1234];
     if (j12==1) {
       for (cartindex34=0; cartindex34<size34; cartindex34++) {
         I00i[cartindex34]
@@ -1475,7 +1483,7 @@ Int2eV3::blockbuildprim_3(int bmin,int bmax,int m)
     stack_alignment_check(&p340_m_r30, "buildprim_3: p340_m_r30");
 
     /* Construct the new integrals. */
-    double *I00o = I00; // points the current target integral
+    double *restrictxx I00o = I00; // points the current target integral
     I10o = I10;
     I11o = I11;
     //int cartindex34 = 0;
