@@ -36,6 +36,7 @@
 #include <chemistry/qc/intv3/tformv3.h>
 
 using namespace std;
+using namespace sc;
 
 #define IN(i,j) ((i)==(j)?1:0)
 #define SELECT(x1,x2,x3,s) (((s)==0)?x1:(((s)==1)?(x2):(x3)))
@@ -78,7 +79,7 @@ Int1eV3::int_initialize_1e(int flags, int order)
     scratchsize = nshell2*3;
     }
   else {
-    ExEnv::err() << scprintf("int_initialize_1e: invalid order: %d\n",order);
+    ExEnv::errn() << scprintf("int_initialize_1e: invalid order: %d\n",order);
     exit(1);
     }
 
@@ -165,7 +166,7 @@ Int1eV3::overlap_1der(int ish, int jsh,
   int ni,nj;
 
   if (!(init_order >= 0)) {
-    ExEnv::err() << scprintf("int_shell_overlap: one electron routines are not init'ed\n");
+    ExEnv::errn() << scprintf("int_shell_overlap: one electron routines are not init'ed\n");
     exit(1);
     }
 
@@ -186,7 +187,7 @@ Int1eV3::overlap_1der(int ish, int jsh,
   nj = gshell2->nfunction();
 
 #if 0
-  ExEnv::out() << scprintf("zeroing %d*%d*3 elements of buff\n",ni,nj);
+  ExEnv::outn() << scprintf("zeroing %d*%d*3 elements of buff\n",ni,nj);
 #endif
   for (i=0; i<ni*nj*3; i++) {
     buff[i] = 0.0;
@@ -692,12 +693,12 @@ Int1eV3::accum_shell_block_1der(double *buff, int ish, int jsh,
   int index = 0;
   for (i=0; i<gcsize1; i++) {
       for (int j=0; j<gcsize2; j++, index++) {
-          ExEnv::out() << scprintf(" (%d %d): % 18.15f % 18.15f",
+          ExEnv::outn() << scprintf(" (%d %d): % 18.15f % 18.15f",
                            i,j,cartesianbuffer[index],fastbuff[index]);
           if (fabs(cartesianbuffer[index]-fastbuff[index])>1.0e-12) {
-              ExEnv::out() << " **";
+              ExEnv::outn() << " **";
             }
-          ExEnv::out() << endl;
+          ExEnv::outn() << endl;
         }
     }
   delete[] cartesianbuffer;
@@ -990,7 +991,7 @@ Int1eV3::accum_shell_efield(double *buff, int ish, int jsh)
   double *tmp = cartesianbuffer;
 
   if (!(init_order >= 1)) {
-    ExEnv::err() << scprintf("accum_shell_efield: one electron routines are not init'ed\n");
+    ExEnv::errn() << scprintf("accum_shell_efield: one electron routines are not init'ed\n");
     exit(1);
     }
 
@@ -1030,7 +1031,7 @@ Int1eV3::accum_shell_block_efield(double *buff, int ish, int jsh)
   int gc1,gc2;
 
   if (!(init_order >= 1)) {
-    ExEnv::err() << scprintf("accum_shell_efield: one electron routines are not init'ed\n");
+    ExEnv::errn() << scprintf("accum_shell_efield: one electron routines are not init'ed\n");
     exit(1);
     }
 
@@ -1092,7 +1093,7 @@ Int1eV3::efield(int ish, int jsh, double *position)
   double *tmp = cartesianbuffer;
 
   if (!(init_order >= 1)) {
-    ExEnv::err() << scprintf("Int1eV3::efield one electron routines are not ready\n");
+    ExEnv::errn() << scprintf("Int1eV3::efield one electron routines are not ready\n");
     exit(1);
     }
 
@@ -1132,7 +1133,7 @@ Int1eV3::nuclear_slow(int ish, int jsh)
   int cart1,cart2;
 
   if (!(init_order >= 0)) {
-    ExEnv::err() << scprintf("int_shell_nuclear: one electron routines are not init'ed\n");
+    ExEnv::errn() << scprintf("int_shell_nuclear: one electron routines are not init'ed\n");
     exit(1);
     }
 
@@ -1185,7 +1186,7 @@ Int1eV3::nuclear(int ish, int jsh)
   int gc1,gc2;
 
   if (!(init_order >= 0)) {
-    ExEnv::err() << scprintf("int_shell_nuclear: one electron routines are not init'ed\n");
+    ExEnv::errn() << scprintf("int_shell_nuclear: one electron routines are not init'ed\n");
     exit(1);
     }
 
@@ -1243,7 +1244,7 @@ Int1eV3::nuclear(int ish, int jsh)
       double fast = fastbuf[index];
       double slow = cartesianbuffer[index];
       if (fabs(fast-slow)>1.0e-12) {
-        ExEnv::out() << scprintf("NUC SHELL FINAL: %d (%d %d %d) %d (%d %d %d): ",
+        ExEnv::outn() << scprintf("NUC SHELL FINAL: %d (%d %d %d) %d (%d %d %d): ",
                          gc1, i1,j1,k1, gc2, i2,j2,k2)
              << scprintf(" % 20.15f % 20.15f",
                          fast, slow)
@@ -1278,7 +1279,7 @@ Int1eV3::int_accum_shell_point_charge(int ish, int jsh,
   double tmp;
 
   if (!(init_order >= 0)) {
-    ExEnv::err() << scprintf("int_shell_pointcharge: one electron routines are not init'ed\n");
+    ExEnv::errn() << scprintf("int_shell_pointcharge: one electron routines are not init'ed\n");
     exit(1);
     }
 
@@ -1328,7 +1329,7 @@ Int1eV3::point_charge(int ish, int jsh,
   int cart1,cart2;
 
   if (!(init_order >= 0)) {
-    ExEnv::err() << scprintf("Int1eV3::point_charge: one electron routines are not init'ed\n");
+    ExEnv::errn() << scprintf("Int1eV3::point_charge: one electron routines are not init'ed\n");
     exit(1);
     }
 
@@ -1375,7 +1376,7 @@ Int1eV3::hcore(int ish, int jsh)
   int gc1,gc2;
 
   if (!(init_order >= 0)) {
-    ExEnv::err() << scprintf("hcore: one electron routines are not init'ed\n");
+    ExEnv::errn() << scprintf("hcore: one electron routines are not init'ed\n");
     exit(1);
     }
 
@@ -1430,7 +1431,7 @@ Int1eV3::hcore_1der(int ish, int jsh,
   int ni,nj;
 
   if (!(init_order >= 0)) {
-    ExEnv::err() << scprintf("int_shell_hcore: one electron routines are not init'ed\n");
+    ExEnv::errn() << scprintf("int_shell_hcore: one electron routines are not init'ed\n");
     exit(1);
     }
 
@@ -1470,7 +1471,7 @@ Int1eV3::kinetic_1der(int ish, int jsh,
   int ni,nj;
 
   if (!(init_order >= 0)) {
-    ExEnv::err() << scprintf("int_shell_kinetic: one electron routines are not init'ed\n");
+    ExEnv::errn() << scprintf("int_shell_kinetic: one electron routines are not init'ed\n");
     exit(1);
     }
 
@@ -1508,7 +1509,7 @@ Int1eV3::nuclear_1der(int ish, int jsh, int idercs, int centernum)
   int ni,nj;
 
   if (!(init_order >= 0)) {
-    ExEnv::err() << scprintf("int_shell_nuclear: one electron routines are not init'ed\n");
+    ExEnv::errn() << scprintf("int_shell_nuclear: one electron routines are not init'ed\n");
     exit(1);
     }
 
@@ -1548,7 +1549,7 @@ Int1eV3::int_shell_nuclear_hf_1der(int ish, int jsh,
   int ni,nj;
 
   if (!(init_order >= 0)) {
-    ExEnv::err() << scprintf("int_shell_nuclear_hf_1der: one electron routines are not init'ed\n");
+    ExEnv::errn() << scprintf("int_shell_nuclear_hf_1der: one electron routines are not init'ed\n");
     exit(1);
     }
 
@@ -1584,7 +1585,7 @@ Int1eV3::int_shell_nuclear_nonhf_1der(int ish, int jsh,
   int ni,nj;
 
   if (!(init_order >= 0)) {
-    ExEnv::err() << scprintf("int_shell_nuclear_nonhf_1der: one electron routines are not init'ed\n");
+    ExEnv::errn() << scprintf("int_shell_nuclear_nonhf_1der: one electron routines are not init'ed\n");
     exit(1);
     }
 
@@ -1601,7 +1602,7 @@ Int1eV3::int_shell_nuclear_nonhf_1der(int ish, int jsh,
   nj = gshell2->nfunction();
 
 #if 0
-  ExEnv::out() << scprintf("int_shell_nuclear_nonhf_1der: zeroing %d doubles in buff\n",ni*nj*3);
+  ExEnv::outn() << scprintf("int_shell_nuclear_nonhf_1der: zeroing %d doubles in buff\n",ni*nj*3);
 #endif
   for (i=0; i<ni*nj*3; i++) {
     buff[i] = 0.0;
@@ -1766,7 +1767,7 @@ Int1eV3::comp_shell_block_nuclear(int gc1, int a, int gc2, int b,
       double *primbuffer = inter(a,b,0);
       for (int ip=0; ip<size1; ip++) {
         for (int jp=0; jp<size2; jp++) {
-          //ExEnv::out() << scprintf("buffer[%d] += %18.15f",
+          //ExEnv::outn() << scprintf("buffer[%d] += %18.15f",
           //                 (ip+gcoff1)*gcsize2+jp+gcoff2,
           //                 tmp * *primbuffer)
           //     << endl;
@@ -1778,7 +1779,7 @@ Int1eV3::comp_shell_block_nuclear(int gc1, int a, int gc2, int b,
 
 #if DEBUG_NUC_SHELL
 #  if DEBUG_NUC_SHELL > 1
-  ExEnv::out() << scprintf("GC = (%d %d), A = %d, B = %d", gc1, gc2, a, b)
+  ExEnv::outn() << scprintf("GC = (%d %d), A = %d, B = %d", gc1, gc2, a, b)
        << endl;
 #  endif
   int i1,j1,k1;
@@ -1793,16 +1794,16 @@ Int1eV3::comp_shell_block_nuclear(int gc1, int a, int gc2, int b,
                                        gc2, i2, j2, k2);
       int bad = fabs(fast-slow)>1.0e-12;
       if (DEBUG_NUC_SHELL > 1 || bad) {
-        ExEnv::out() << scprintf("NUC SHELL: (%d %d %d) (%d %d %d): ",
+        ExEnv::outn() << scprintf("NUC SHELL: (%d %d %d) (%d %d %d): ",
                          i1,j1,k1, i2,j2,k2)
              << scprintf(" % 20.15f % 20.15f",
                          fast, slow);
         }
       if (bad) {
-        ExEnv::out() << " ****" << endl;
+        ExEnv::outn() << " ****" << endl;
         }
       else if (DEBUG_NUC_SHELL > 1) {
-        ExEnv::out() << endl;
+        ExEnv::outn() << endl;
         }
       jp++;
       } END_FOR_CART;
@@ -1821,7 +1822,7 @@ Int1eV3::comp_prim_block_nuclear(int a, int b)
   // fill in the ia+ib=0 integrals
   for (im=0; im<=l; im++) {
 #if DEBUG_NUC_PRIM > 1
-    ExEnv::out() << "BUILD: M = " << im
+    ExEnv::outn() << "BUILD: M = " << im
          << " A = " << 0
          << " B = " << 0
          << endl;
@@ -1834,7 +1835,7 @@ Int1eV3::comp_prim_block_nuclear(int a, int b)
     // build the integrals for a = 0
     for (ib=1; ib<=lm && ib<=b; ib++) {
 #if DEBUG_NUC_PRIM > 1
-      ExEnv::out() << "BUILD: M = " << im
+      ExEnv::outn() << "BUILD: M = " << im
            << " A = " << 0
            << " B = " << ib
            << endl;
@@ -1844,7 +1845,7 @@ Int1eV3::comp_prim_block_nuclear(int a, int b)
     for (ia=1; ia<=lm && ia<=a; ia++) {
       for (ib=0; ib<=lm-ia && ib<=b; ib++) {
 #if DEBUG_NUC_PRIM > 1
-        ExEnv::out() << "BUILD: M = " << im
+        ExEnv::outn() << "BUILD: M = " << im
              << " A = " << ia
              << " B = " << ib
              << endl;
@@ -1862,7 +1863,7 @@ Int1eV3::comp_prim_block_nuclear(int a, int b)
       for (ib=0; ib<=lm-ia && ib<=b; ib++) {
         int nb = INT_NCART_NN(b);
 #if DEBUG_NUC_PRIM > 1
-        ExEnv::out() << "M = " << im
+        ExEnv::outn() << "M = " << im
              << " A = " << ia
              << " B = " << ib
              << endl;
@@ -1877,7 +1878,7 @@ Int1eV3::comp_prim_block_nuclear(int a, int b)
             if (fast > 999.0) fast = 999.0;
             if (fast < -999.0) fast = -999.0;
             if (fabs(fast-slow)>1.0e-12) {
-              ExEnv::out() << scprintf("(%d %d %d) (%d %d %d) (%d): ",
+              ExEnv::outn() << scprintf("(%d %d %d) (%d %d %d) (%d): ",
                                i1,j1,k1, i2,j2,k2, im)
                    << scprintf(" % 20.15f % 20.15f",
                                fast, slow)
@@ -2237,7 +2238,7 @@ Int1eV3::comp_prim_block_efield(int a, int b)
   // fill in the ia+ib=0 integrals, skipping m=0
   for (im=1; im<=l; im++) {
 #if DEBUG_EFIELD_PRIM > 1
-    ExEnv::out() << "BUILD NUC: M = " << im
+    ExEnv::outn() << "BUILD NUC: M = " << im
          << " A = " << 0
          << " B = " << 0
          << endl;
@@ -2251,7 +2252,7 @@ Int1eV3::comp_prim_block_efield(int a, int b)
     // build the integrals for a = 0
     for (ib=1; ib<=lm && ib<=b; ib++) {
 #if DEBUG_EFIELD_PRIM > 1
-      ExEnv::out() << "BUILD NUC: M = " << im
+      ExEnv::outn() << "BUILD NUC: M = " << im
            << " A = " << 0
            << " B = " << ib
            << endl;
@@ -2261,7 +2262,7 @@ Int1eV3::comp_prim_block_efield(int a, int b)
     for (ia=1; ia<=lm && ia<=a; ia++) {
       for (ib=0; ib<=lm-ia && ib<=b; ib++) {
 #if DEBUG_EFIELD_PRIM > 1
-        ExEnv::out() << "BUILD NUC: M = " << im
+        ExEnv::outn() << "BUILD NUC: M = " << im
              << " A = " << ia
              << " B = " << ib
              << endl;
@@ -2276,7 +2277,7 @@ Int1eV3::comp_prim_block_efield(int a, int b)
   // fill in the ia+ib=0 integrals
   for (im=0; im<=l; im++) {
 #if DEBUG_EFIELD_PRIM > 1
-    ExEnv::out() << "BUILD EFIELD: M = " << im
+    ExEnv::outn() << "BUILD EFIELD: M = " << im
          << " A = " << 0
          << " B = " << 0
          << endl;
@@ -2292,7 +2293,7 @@ Int1eV3::comp_prim_block_efield(int a, int b)
     // build the integrals for a = 0
     for (ib=1; ib<=lm && ib<=b; ib++) {
 #if DEBUG_EFIELD_PRIM > 1
-      ExEnv::out() << "BUILD EFIELD: M = " << im
+      ExEnv::outn() << "BUILD EFIELD: M = " << im
            << " A = " << 0
            << " B = " << ib
            << endl;
@@ -2302,7 +2303,7 @@ Int1eV3::comp_prim_block_efield(int a, int b)
     for (ia=1; ia<=lm && ia<=a; ia++) {
       for (ib=0; ib<=lm-ia && ib<=b; ib++) {
 #if DEBUG_EFIELD_PRIM > 1
-        ExEnv::out() << "BUILD EFIELD: M = " << im
+        ExEnv::outn() << "BUILD EFIELD: M = " << im
              << " A = " << ia
              << " B = " << ib
              << endl;
@@ -2320,7 +2321,7 @@ Int1eV3::comp_prim_block_efield(int a, int b)
       for (ib=0; ib<=lm-ia && ib<=b; ib++) {
         int nb = INT_NCART_NN(b);
 #if DEBUG_EFIELD_PRIM > 1
-        ExEnv::out() << "M = " << im
+        ExEnv::outn() << "M = " << im
              << " A = " << ia
              << " B = " << ib
              << endl;
@@ -2336,7 +2337,7 @@ Int1eV3::comp_prim_block_efield(int a, int b)
               if (fast > 999.0) fast = 999.0;
               if (fast < -999.0) fast = -999.0;
               if (fabs(fast-slow)>1.0e-12) {
-                ExEnv::out() << scprintf("(%d %d %d) (%d %d %d) (%d): ",
+                ExEnv::outn() << scprintf("(%d %d %d) (%d %d %d) (%d): ",
                                  i1,j1,k1, i2,j2,k2, im)
                      << scprintf(" % 20.15f % 20.15f",
                                  fast, slow)
@@ -2693,82 +2694,82 @@ Int1eV3::comp_shell_dipole(double* dipole,
         }
       ss =   pow(3.141592653589793/(exp1+exp2),1.5)
            * exp(- oozeta * exp1 * exp2 * AmB2);
-      sMus = ss * PmC[mu];
+      for (mu=0; mu<3; mu++) sMus[mu] = ss * PmC[mu];
       tmp     =  gshell1->coefficient_unnorm(gc1,i)
                * gshell2->coefficient_unnorm(gc2,j);
       if (exponent_weighted == 0) tmp *= exp1;
       else if (exponent_weighted == 1) tmp *= exp2;
-      dipole[0] += tmp * comp_prim_dipole(1,0,0,i1,j1,k1,i2,j2,k2);
-      dipole[1] += tmp * comp_prim_dipole(0,1,0,i1,j1,k1,i2,j2,k2);
-      dipole[2] += tmp * comp_prim_dipole(0,0,1,i1,j1,k1,i2,j2,k2);
+      dipole[0] += tmp * comp_prim_dipole(0,i1,j1,k1,i2,j2,k2);
+      dipole[1] += tmp * comp_prim_dipole(1,i1,j1,k1,i2,j2,k2);
+      dipole[2] += tmp * comp_prim_dipole(2,i1,j1,k1,i2,j2,k2);
       }
     }
 
   }
 
 double
-Int1eV3::comp_prim_dipole(int im, int jm, int km,
+Int1eV3::comp_prim_dipole(int axis,
                           int i1, int j1, int k1,
                           int i2, int j2, int k2)
 {
   double result;
 
   if (i1) {
-    result = PmA[0] * comp_prim_dipole(im,jm,km,i1-1,j1,k1,i2,j2,k2);
+    result = PmA[0] * comp_prim_dipole(axis,i1-1,j1,k1,i2,j2,k2);
     if (i2) 
-      result += oo2zeta*i2*comp_prim_dipole(im,jm,km,i1-1,j1,k1,i2-1,j2,k2);
+      result += oo2zeta*i2*comp_prim_dipole(axis,i1-1,j1,k1,i2-1,j2,k2);
     if (i1>1)
-      result += oo2zeta*(i1-1)*comp_prim_dipole(im,jm,km,i1-2,j1,k1,i2,j2,k2);
-    if(im) result += oo2zeta*comp_prim_overlap(i1-1,j1,k1,i2,j2,k2);
+      result += oo2zeta*(i1-1)*comp_prim_dipole(axis,i1-2,j1,k1,i2,j2,k2);
+    if(axis==0) result += oo2zeta*comp_prim_overlap(i1-1,j1,k1,i2,j2,k2);
     return result;
     }
   if (j1) {
-    result = PmA[1] * comp_prim_dipole(im,jm,km,i1,j1-1,k1,i2,j2,k2);
+    result = PmA[1] * comp_prim_dipole(axis,i1,j1-1,k1,i2,j2,k2);
     if (j2) 
-      result += oo2zeta*j2*comp_prim_dipole(im,jm,km,i1,j1-1,k1,i2,j2-1,k2);
+      result += oo2zeta*j2*comp_prim_dipole(axis,i1,j1-1,k1,i2,j2-1,k2);
     if (j1>1) 
-      result += oo2zeta*(j1-1)*comp_prim_dipole(im,jm,km,i1,j1-2,k1,i2,j2,k2);
-    if(jm) result += oo2zeta*comp_prim_overlap(i1,j1-1,k1,i2,j2,k2);
+      result += oo2zeta*(j1-1)*comp_prim_dipole(axis,i1,j1-2,k1,i2,j2,k2);
+    if(axis==1) result += oo2zeta*comp_prim_overlap(i1,j1-1,k1,i2,j2,k2);
     return result;
     }
   if (k1) {
-    result = PmA[2] * comp_prim_dipole(im,jm,km,i1,j1,k1-1,i2,j2,k2);
+    result = PmA[2] * comp_prim_dipole(axis,i1,j1,k1-1,i2,j2,k2);
     if (k2) 
-      result += oo2zeta*k2*comp_prim_dipole(im,jm,km,i1,j1,k1-1,i2,j2,k2-1);
+      result += oo2zeta*k2*comp_prim_dipole(axis,i1,j1,k1-1,i2,j2,k2-1);
     if (k1>1) 
-      result += oo2zeta*(k1-1)*comp_prim_dipole(im,jm,km,i1,j1,k1-2,i2,j2,k2);
-    if(km) result += oo2zeta*comp_prim_overlap(i1,j1,k1-1,i2,j2,k2);
+      result += oo2zeta*(k1-1)*comp_prim_dipole(axis,i1,j1,k1-2,i2,j2,k2);
+    if(axis==2) result += oo2zeta*comp_prim_overlap(i1,j1,k1-1,i2,j2,k2);
     return result;
     }
   if (i2) {
-    result = PmB[0] * comp_prim_dipole(im,jm,km,i1,j1,k1,i2-1,j2,k2);
+    result = PmB[0] * comp_prim_dipole(axis,i1,j1,k1,i2-1,j2,k2);
     if (i1) 
-      result += oo2zeta*i1*comp_prim_dipole(im,jm,km,i1-1,j1,k1,i2-1,j2,k2);
+      result += oo2zeta*i1*comp_prim_dipole(axis,i1-1,j1,k1,i2-1,j2,k2);
     if (i2>1) 
-      result += oo2zeta*(i2-1)*comp_prim_dipole(im,jm,km,i1,j1,k1,i2-2,j2,k2);
-    if(im) result += oo2zeta*comp_prim_overlap(i1,j1,k1,i2-1,j2,k2);
+      result += oo2zeta*(i2-1)*comp_prim_dipole(axis,i1,j1,k1,i2-2,j2,k2);
+    if(axis==0) result += oo2zeta*comp_prim_overlap(i1,j1,k1,i2-1,j2,k2);
     return result;
     }
   if (j2) {
-    result = PmB[1] * comp_prim_dipole(im,jm,km,i1,j1,k1,i2,j2-1,k2);
+    result = PmB[1] * comp_prim_dipole(axis,i1,j1,k1,i2,j2-1,k2);
     if (j1) 
-      result += oo2zeta*i1*comp_prim_dipole(im,jm,km,i1,j1-1,k1,i2,j2-1,k2);
+      result += oo2zeta*i1*comp_prim_dipole(axis,i1,j1-1,k1,i2,j2-1,k2);
     if (j2>1) 
-      result += oo2zeta*(j2-1)*comp_prim_dipole(im,jm,km,i1,j1,k1,i2,j2-2,k2);
-    if(jm) result += oo2zeta*comp_prim_overlap(i1,j1,k1,i2,j2-1,k2);
+      result += oo2zeta*(j2-1)*comp_prim_dipole(axis,i1,j1,k1,i2,j2-2,k2);
+    if(axis==1) result += oo2zeta*comp_prim_overlap(i1,j1,k1,i2,j2-1,k2);
     return result;
     }
   if (k2) {
-    result = PmB[2] * comp_prim_dipole(im,jm,km,i1,j1,k1,i2,j2,k2-1);
+    result = PmB[2] * comp_prim_dipole(axis,i1,j1,k1,i2,j2,k2-1);
     if (k1) 
-      result += oo2zeta*i1*comp_prim_dipole(im,jm,km,i1,j1,k1-1,i2,j2,k2-1);
+      result += oo2zeta*i1*comp_prim_dipole(axis,i1,j1,k1-1,i2,j2,k2-1);
     if (k2>1) 
-      result += oo2zeta*(k2-1)*comp_prim_dipole(im,jm,km,i1,j1,k1,i2,j2,k2-2);
-    if(km) result += oo2zeta*comp_prim_overlap(i1,j1,k1,i2,j2,k2-1);
+      result += oo2zeta*(k2-1)*comp_prim_dipole(axis,i1,j1,k1,i2,j2,k2-2);
+    if(axis==2) result += oo2zeta*comp_prim_overlap(i1,j1,k1,i2,j2,k2-1);
     return result;
     }
 
-  return sMus;
+  return sMus[axis];
   }
 
 /////////////////////////////////////////////////////////////////////////////
