@@ -36,6 +36,7 @@
 #include <chemistry/qc/intv3/tformv3.h>
 
 using namespace std;
+using namespace sc;
 
 #undef DER_TIMING
 #undef EREP_TIMING
@@ -54,9 +55,9 @@ swtch(GaussianBasisSet* &i,GaussianBasisSet* &j)
 }
 
 static inline void
-pswtch(void**i,void**j)
+sswtch(GaussianShell**i,GaussianShell**j)
 {
-  void*tmp;
+  GaussianShell*tmp;
   tmp = *i;
   *i = *j;
   *j = tmp;
@@ -74,7 +75,7 @@ iswtch(int *i,int *j)
 static void
 fail()
 {
-  ExEnv::err() << scprintf("failing module:\n%s",__FILE__) << endl;
+  ExEnv::errn() << scprintf("failing module:\n%s",__FILE__) << endl;
   abort();
 }
 
@@ -156,8 +157,8 @@ Int2eV3::compute_erep(int flags, int *psh1, int *psh2, int *psh3, int *psh4,
       ||( !int_unit2 && (sh2 < 0 || sh2 >= bs2_->nbasis()))
       || sh3 < 0 || sh3 >= bs3_->nbasis()
       ||( !int_unit4 && (sh4 < 0 || sh4 >= bs4_->nbasis()))) {
-    ExEnv::err() << scprintf("compute_erep has been incorrectly used\n");
-    ExEnv::err() << scprintf("shells (bounds): %d (%d), %d (%d), %d (%d), %d (%d)\n",
+    ExEnv::errn() << scprintf("compute_erep has been incorrectly used\n");
+    ExEnv::errn() << scprintf("shells (bounds): %d (%d), %d (%d), %d (%d), %d (%d)\n",
             sh1,bs1_->nbasis()-1,
             sh2,bs2_->nbasis()-1,
             sh3,bs3_->nbasis()-1,
@@ -215,7 +216,7 @@ Int2eV3::compute_erep(int flags, int *psh1, int *psh2, int *psh3, int *psh4,
     iswtch(&am1,&am2);iswtch(&sh1,&sh2);iswtch(psh1,psh2);iswtch(&osh1,&osh2);
     iswtch(&dam1,&dam2);
     iswtch(&minam1,&minam2);
-    pswtch((void**)&int_shell1,(void**)&int_shell2);
+    sswtch(&int_shell1,&int_shell2);
     swtch(pbs1,pbs2);
     }
   if (am4 > am3) {
@@ -223,7 +224,7 @@ Int2eV3::compute_erep(int flags, int *psh1, int *psh2, int *psh3, int *psh4,
     iswtch(&am3,&am4);iswtch(&sh3,&sh4);iswtch(psh3,psh4);iswtch(&osh3,&osh4);
     iswtch(&dam3,&dam4);
     iswtch(&minam3,&minam4);
-    pswtch((void**)&int_shell3,(void**)&int_shell4);
+    sswtch(&int_shell3,&int_shell4);
     swtch(pbs3,pbs4);
     }
   if (!(int_unit2||int_unit4) && (osh1 == osh4) && (osh2 == osh3) && (osh1 != osh2)) {
@@ -234,7 +235,7 @@ Int2eV3::compute_erep(int flags, int *psh1, int *psh2, int *psh3, int *psh4,
       iswtch(&am3,&am4);iswtch(&sh3,&sh4);iswtch(psh3,psh4);iswtch(&osh3,&osh4);
       iswtch(&dam3,&dam4);
       iswtch(&minam3,&minam4);
-      pswtch((void**)&int_shell3,(void**)&int_shell4);
+      sswtch(&int_shell3,&int_shell4);
       swtch(pbs3,pbs4);
       }
     }
@@ -246,11 +247,11 @@ Int2eV3::compute_erep(int flags, int *psh1, int *psh2, int *psh3, int *psh4,
     iswtch(&am12,&am34);
     iswtch(&dam1,&dam3);
     iswtch(&minam1,&minam3);
-    pswtch((void**)&int_shell1,(void**)&int_shell3);
+    sswtch(&int_shell1,&int_shell3);
     swtch(pbs1,pbs3);
     iswtch(&dam2,&dam4);
     iswtch(&minam2,&minam4);
-    pswtch((void**)&int_shell2,(void**)&int_shell4);
+    sswtch(&int_shell2,&int_shell4);
     swtch(pbs2,pbs4);
     }
   /* This tries to make centers A and B equivalent, if possible. */
@@ -269,11 +270,11 @@ Int2eV3::compute_erep(int flags, int *psh1, int *psh2, int *psh3, int *psh4,
     iswtch(&am12,&am34);
     iswtch(&dam1,&dam3);
     iswtch(&minam1,&minam3);
-    pswtch((void**)&int_shell1,(void**)&int_shell3);
+    sswtch(&int_shell1,&int_shell3);
     swtch(pbs1,pbs3);
     iswtch(&dam2,&dam4);
     iswtch(&minam2,&minam4);
-    pswtch((void**)&int_shell2,(void**)&int_shell4);
+    sswtch(&int_shell2,&int_shell4);
     swtch(pbs2,pbs4);
     }
 
@@ -299,14 +300,19 @@ Int2eV3::compute_erep(int flags, int *psh1, int *psh2, int *psh3, int *psh4,
     iswtch(&int_expweight2,&int_expweight4);
     }
 
+  int nc1 = int_shell1->ncontraction();
+  int nc2 = int_shell2->ncontraction();
+  int nc3 = int_shell3->ncontraction();
+  int nc4 = int_shell4->ncontraction();
+
   /* Compute the shell sizes. */
-  for (ii=size1=0; ii<int_shell1->ncontraction(); ii++)
+  for (ii=size1=0; ii<nc1; ii++)
     size1 += INT_NCART(int_shell1->am(ii)+dam1);
-  for (ii=size2=0; ii<int_shell2->ncontraction(); ii++)
+  for (ii=size2=0; ii<nc2; ii++)
     size2 += INT_NCART(int_shell2->am(ii)+dam2);
-  for (ii=size3=0; ii<int_shell3->ncontraction(); ii++)
+  for (ii=size3=0; ii<nc3; ii++)
     size3 += INT_NCART(int_shell3->am(ii)+dam3);
-  for (ii=size4=0; ii<int_shell4->ncontraction(); ii++)
+  for (ii=size4=0; ii<nc4; ii++)
     size4 += INT_NCART(int_shell4->am(ii)+dam4);
   size = size1*size2*size3*size4;
 
@@ -315,7 +321,7 @@ Int2eV3::compute_erep(int flags, int *psh1, int *psh2, int *psh3, int *psh4,
       tim_change("check storage");
 #endif
     if (dam1 || dam2 || dam3 || dam4) {
-      ExEnv::err() << scprintf("cannot use integral storage and dam\n");
+      ExEnv::errn() << scprintf("cannot use integral storage and dam\n");
       fail();
       }
     if (    !int_unit2
@@ -339,22 +345,22 @@ Int2eV3::compute_erep(int flags, int *psh1, int *psh2, int *psh3, int *psh4,
 
   /* Begin loop over generalized contractions. */
   ogc1 = 0;
-  for (i=0; i<int_shell1->ncontraction(); i++) {
+  for (i=0; i<nc1; i++) {
     tam1 = int_shell1->am(i) + dam1;
     if (tam1 < 0) continue;
     int tsize1 = INT_NCART_NN(tam1);
     ogc2 = 0;
-    for (j=0; j<int_shell2->ncontraction(); j++) {
+    for (j=0; j<nc2; j++) {
       tam2 = int_shell2->am(j) + dam2;
       if (tam2 < 0) continue;
       int tsize2 = INT_NCART_NN(tam2);
       ogc3 = 0;
-      for (k=0; k<int_shell3->ncontraction(); k++) {
+      for (k=0; k<nc3; k++) {
         tam3 = int_shell3->am(k) + dam3;
         if (tam3 < 0) continue;
         int tsize3 = INT_NCART_NN(tam3);
         ogc4 = 0;
-        for (l=0; l<int_shell4->ncontraction(); l++) {
+        for (l=0; l<nc4; l++) {
           tam4 = int_shell4->am(l) + dam4;
           if (tam4 < 0) continue;
           int tsize4 = INT_NCART_NN(tam4);
@@ -445,8 +451,27 @@ Int2eV3::compute_erep(int flags, int *psh1, int *psh2, int *psh3, int *psh4,
         newindex1 += stride1;
         }
       }
+    else if (nc3 == 1 && nc4 == 1) {
+      // this is the p12 only case w/o gen contractions on 3 & 4
+      // this special case collapses the 3rd and 4th indices together
+      for (int ci1=0; ci1<tsize1; ci1++) {
+        for (int ci2=0; ci2<tsize2; ci2++) {
+          int pci1=ci1;
+          int pci2=ci2;
+          if (p12) {
+            int tmp=pci1; pci1=pci2; pci2=tmp;
+            }
+          int newindex123 = newindexoffset + pci1*psize234 + pci2*psize34;
+          double *tmp_int_buffer = &int_buffer[newindex123];
+          double *tmp_shiftbuffer = &shiftbuffer[redundant_index];
+          for (int ci34=0; ci34<psize34; ci34++)
+            tmp_int_buffer[ci34] = tmp_shiftbuffer[ci34];
+          redundant_index += psize34;
+          }
+        }
+      }
     else {
-      // this is the p12 only case
+      // this is the p12 only case w/gen. contr. on 3 & 4
       for (int ci1=0; ci1<tsize1; ci1++) {
         for (int ci2=0; ci2<tsize2; ci2++) {
           int pci1=ci1;
@@ -468,6 +493,26 @@ Int2eV3::compute_erep(int flags, int *psh1, int *psh2, int *psh3, int *psh4,
         }
       }
     }
+  else if (nc3 == 1 && nc4 == 1) {
+    // this special case collapses the 3rd and 4th indices together
+    int size34 =  size3 * size4;
+    int size234 = size2 * size34;
+    double* redund_ints = shiftbuffer;
+    redundant_index = 0;
+    int newindex1 = ogc1*size234 + ogc2*size34 + ogc3*size4 + ogc4;
+    for (int ci1=0; ci1<tsize1; ci1++) {
+      int newindex12 = newindex1;
+      for (int ci2=0; ci2<tsize2; ci2++) {
+        double *tmp_int_buffer = &int_buffer[newindex12];
+        double *tmp_redund_ints = &redund_ints[redundant_index];
+        for (int ci34=0; ci34<size34; ci34++)
+          tmp_int_buffer[ci34] = tmp_redund_ints[ci34];
+        redundant_index += size34;
+        newindex12 += size34;
+        }
+      newindex1 += size234;
+      }
+    }
   else {
     int size34 =  size3 * size4;
     int size234 = size2 * size34;
@@ -529,9 +574,9 @@ Int2eV3::compute_erep(int flags, int *psh1, int *psh2, int *psh3, int *psh4,
       iswtch(&am1,&am3);
       iswtch(&am2,&am4);
       iswtch(&am12,&am34);
-      pswtch((void**)&int_shell1,(void**)&int_shell3);
+      sswtch(&int_shell1,&int_shell3);
       swtch(pbs1,pbs3);
-      pswtch((void**)&int_shell2,(void**)&int_shell4);
+      sswtch(&int_shell2,&int_shell4);
       swtch(pbs2,pbs4);
       iswtch(&int_expweight1,&int_expweight3);
       iswtch(&int_expweight2,&int_expweight4);
@@ -539,14 +584,14 @@ Int2eV3::compute_erep(int flags, int *psh1, int *psh2, int *psh3, int *psh4,
     if (p34) {
       iswtch(&sh3,&sh4);iswtch(psh3,psh4);iswtch(&osh3,&osh4);
       iswtch(&am3,&am4);
-      pswtch((void**)&int_shell3,(void**)&int_shell4);
+      sswtch(&int_shell3,&int_shell4);
       swtch(pbs3,pbs4);
       iswtch(&int_expweight3,&int_expweight4);
       }
     if (p12) {
       iswtch(&sh1,&sh2);iswtch(psh1,psh2);iswtch(&osh1,&osh2);
       iswtch(&am1,&am2);
-      pswtch((void**)&int_shell1,(void**)&int_shell2);
+      sswtch(&int_shell1,&int_shell2);
       swtch(pbs1,pbs2);
       iswtch(&int_expweight1,&int_expweight2);
       }
@@ -566,7 +611,7 @@ Int2eV3::compute_erep(int flags, int *psh1, int *psh2, int *psh3, int *psh4,
     int redundant_offset = 0;
     int nonredundant_offset = 0;
     if ((osh1 == osh4)&&(osh2 == osh3)&&(osh1 != osh2)) {
-      ExEnv::err() << scprintf("nonredundant integrals cannot be generated\n");
+      ExEnv::errn() << scprintf("nonredundant integrals cannot be generated\n");
       fail();
       }
     e12 = (int_unit2?0:(osh1 == osh2));
@@ -788,7 +833,7 @@ Int2eV3::erep_all1der(int &psh1, int &psh2, int &psh3, int &psh4,
     int i;
 
     if ((osh[0] == osh[3])&&(osh[1] == osh[2])&&(osh[0] != osh[1])) {
-      ExEnv::err() << scprintf("nonredundant integrals cannot be generated (1der)\n");
+      ExEnv::errn() << scprintf("nonredundant integrals cannot be generated (1der)\n");
       fail();
       }
 
@@ -847,7 +892,7 @@ Int2eV3::compute_erep_1der(int flags, double *buffer,
   shell4 = &bs4_->shell(*psh4);
 
   if ((dercenter<0) || (dercenter > 3)) {
-    ExEnv::err() << scprintf("illegal derivative center -- must be 0, 1, 2, or 3\n");
+    ExEnv::errn() << scprintf("illegal derivative center -- must be 0, 1, 2, or 3\n");
     fail();
     }
 
@@ -1820,7 +1865,7 @@ Int2eV3::int_erep_bound1der(int flags, int bsh1, int bsh2, int *size)
     int i;
 
     if ((osh[0] == osh[3])&&(osh[1] == osh[2])&&(osh[0] != osh[1])) {
-      ExEnv::err() << scprintf("nonredundant integrals cannot be generated (1der)\n");
+      ExEnv::errn() << scprintf("nonredundant integrals cannot be generated (1der)\n");
       fail();
       }
 
