@@ -38,6 +38,7 @@
 #include <math/scmat/matrix.h>
 #include <math/scmat/blocked.h>
 #include <chemistry/molecule/molecule.h>
+#include <chemistry/qc/basis/integral.h>
 #include <chemistry/qc/mbpt/bzerofast.h>
 #include <chemistry/qc/mbpt/mbpt.h>
 #include <chemistry/qc/mbpt/util.h>
@@ -46,11 +47,15 @@
 #include <chemistry/qc/mbpt/csgrads2pdm.h>
 
 using namespace std;
+using namespace sc;
 
 #define SINGLE_THREAD_E12   0
 #define SINGLE_THREAD_QBT34 0
 #define SINGLE_THREAD_S2PDM 0
 
+#define PRINT2Q 0
+#define PRINT3Q 0
+#define PRINT4Q 0
 #if PRINT_BIGGEST_INTS
 BiggestContribs biggest_ints_1(4,40);
 #endif
@@ -143,7 +148,7 @@ MBPT2::compute_cs_grad()
   int xyz;
   int natom = molecule()->natom();     // the number of atoms
   int int_index;
-  int mem_static;    // static memory in bytes
+  size_t mem_static;    // static memory in bytes
   int ij_proc;          // the processor which has ij pair
   int ij_index;         // of the ij pairs on a proc, this ij pair is number ij_index
                         // (i.e., ij_index < nij)
@@ -154,7 +159,6 @@ MBPT2::compute_cs_grad()
   int ni;
 
   double *evals;              // scf eigenvalues
-  const double *intbuf;       // 2-electron AO integral buffer
   double *iajb_ptr, *ibja_ptr, *iakb_ptr, *ibka_ptr;
   double *iajc_ptr, *ibjc_ptr, *icjb_ptr, *icja_ptr;
   double *ijkb_ptr, *ibkj_ptr;
@@ -233,13 +237,13 @@ MBPT2::compute_cs_grad()
   me = msg_->me();
 
   if (me == 0) {
-    ExEnv::out() << endl << indent
+    ExEnv::out0() << endl << indent
          << "Entered memgrp based MP2 routine" << endl;
     }
   
   nproc = msg_->n();
   if (me == 0)
-    ExEnv::out() << indent << scprintf("nproc = %i", nproc) << endl;
+    ExEnv::out0() << indent << scprintf("nproc = %i", nproc) << endl;
 
   tol = (int) (-10.0/log10(2.0));  // discard ereps smaller than 10^-10
 
@@ -257,28 +261,28 @@ MBPT2::compute_cs_grad()
 
   if (nocc_act <= 0) {
     if (me == 0) {
-      ExEnv::err() << "There are no active occupied orbitals; program exiting" << endl;
+      ExEnv::err0() << "There are no active occupied orbitals; program exiting" << endl;
       }
     abort();
     }
 
   if (nvir_act <= 0) {
     if (me == 0) {
-      ExEnv::err() << "There are no active virtual orbitals; program exiting" << endl;
+      ExEnv::err0() << "There are no active virtual orbitals; program exiting" << endl;
       }
     abort();
     }
     
   if (restart_orbital_memgrp_) {
     if (!dograd && !do_d1_ && !do_d2_) {
-      ExEnv::out() << node0 << indent
+      ExEnv::out0() << indent
            << scprintf("Restarting at orbital %d with partial energy %18.14f",
                        restart_orbital_memgrp_, restart_ecorr_)
            << endl;
       ecorr_mp2 = restart_ecorr_;
       }
     else {
-      ExEnv::out() << node0 << indent
+      ExEnv::out0() << indent
            << "Restart requested but not possible with gradients, D1, or D2"
            << endl;
       restart_ecorr_ = 0.0;
@@ -294,7 +298,8 @@ MBPT2::compute_cs_grad()
   //
   // The following arrays are kept throughout (all of type double):
   //   scf_vector, gradient, ginter, Pkj, Pab, Wkj, Wab, Waj, Laj
-  // and memory allocated for these arrays is called mem_static
+  // and memory allocated for these arrays  and integral evaluators
+  // is called mem_static
   //
   ////////////////////////////////////////////////////////
   if (me == 0) {
@@ -316,11 +321,13 @@ MBPT2::compute_cs_grad()
       mem_static += nocc*nvir; // partial Laj
       }
     mem_static *= sizeof(double);
+    int nthreads = thr_->nthread();
+    mem_static += nthreads * integral()->storage_required_eri(basis()); // integral evaluators
     ni = compute_cs_batchsize(mem_static, nocc_act-restart_orbital_memgrp_); 
     }
 
   if (max_norb_ > 0 && ni > max_norb_) {
-      ExEnv::out() << node0 << indent
+      ExEnv::out0() << indent
            << "\"max_norb\" set: could have done "
            << ni << " orbitals per pass otherwise."
            << endl;
@@ -329,45 +336,48 @@ MBPT2::compute_cs_grad()
 
   // Send value of ni and mem_static to other nodes
   msg_->bcast(ni);
-  msg_->bcast(mem_static);
+  double dmem_static = mem_static;
+  msg_->bcast(dmem_static);
+  mem_static = size_t(dmem_static);
 
-  // Compute the storage remaining for the integral routines
+  // Compute the storage to be used by the integral routines (required plus optional)
   size_t dyn_mem = distsize_to_size(compute_cs_dynamic_memory(ni,nocc_act));
   int mem_remaining;
   if (mem_alloc <= (dyn_mem + mem_static)) mem_remaining = 0;
-  else mem_remaining = mem_alloc - dyn_mem + mem_static;
+  else mem_remaining = mem_alloc - dyn_mem - mem_static;
+  mem_remaining += thr_->nthread() * integral()->storage_required_eri(basis());
 
-  ExEnv::out() << node0 << indent
+  ExEnv::out0() << indent
        << "Memory available per node:      " << mem_alloc << " Bytes"
        << endl;
-  ExEnv::out() << node0 << indent
+  ExEnv::out0() << indent
        << "Static memory used per node:    " << mem_static << " Bytes"
        << endl;
-  ExEnv::out() << node0 << indent
+  ExEnv::out0() << indent
        << "Total memory used per node:     " << dyn_mem+mem_static << " Bytes"
        << endl;
-  ExEnv::out() << node0 << indent
+  ExEnv::out0() << indent
        << "Memory required for one pass:   "
        << compute_cs_dynamic_memory(nocc_act,nocc_act)+mem_static
        << " Bytes"
        << endl;
-  ExEnv::out() << node0 << indent
+  ExEnv::out0() << indent
        << "Minimum memory required:        "
        << compute_cs_dynamic_memory(1,nocc_act)+mem_static
        << " Bytes"
        << endl;
-  ExEnv::out() << node0 << indent
+  ExEnv::out0() << indent
        << "Batch size:                     " << ni
        << endl;
 
   if (ni == 0) {
-    ExEnv::err() << node0 << "Batch size is 0: more memory or processors are needed"
+    ExEnv::err0() << "Batch size is 0: more memory or processors are needed"
          << endl;
     abort();
     }
 
   if (dynamic_) {
-    ExEnv::out() << node0 << indent << "Using dynamic load balancing." << endl;
+    ExEnv::out0() << indent << "Using dynamic load balancing." << endl;
     }
 
   if (ni == nocc_act-restart_orbital_memgrp_) {
@@ -381,15 +391,15 @@ MBPT2::compute_cs_grad()
     }
 
   if (me == 0) {
-    ExEnv::out() << indent
+    ExEnv::out0() << indent
          << scprintf(" npass  rest  nbasis  nshell  nfuncmax") << endl;
-    ExEnv::out() << indent
+    ExEnv::out0() << indent
          << scprintf("  %-4i   %-3i   %-5i    %-4i     %-3i",
                      npass,rest,nbasis,nshell,nfuncmax)
          << endl;
-    ExEnv::out() << indent
+    ExEnv::out0() << indent
          << scprintf(" nocc   nvir   nfzc   nfzv") << endl;
-    ExEnv::out() << indent
+    ExEnv::out0() << indent
          << scprintf("  %-4i   %-4i   %-4i   %-4i",
                      nocc,nvir,nfzc,nfzv)
          << endl;
@@ -501,13 +511,13 @@ MBPT2::compute_cs_grad()
 
   if (debug_ > 2 && me == 0) {
     for (j=0; j<noso; j++) {
-      ExEnv::out() << indent
+      ExEnv::out0() << indent
            << scprintf("eigenvalue[%3d] = %15.10lf", j, evals[j]);
-      if (j < nfzc) ExEnv::out() << " (frozen docc)";
-      else if (j < nocc_act + nfzc) ExEnv::out() << " (active docc)";
-      else if (j < nvir_act + nocc_act + nfzc) ExEnv::out() << " (active uocc)";
-      else ExEnv::out() << " (frozen uocc)";
-      ExEnv::out() << endl;
+      if (j < nfzc) ExEnv::out0() << " (frozen docc)";
+      else if (j < nocc_act + nfzc) ExEnv::out0() << " (active docc)";
+      else if (j < nvir_act + nocc_act + nfzc) ExEnv::out0() << " (active uocc)";
+      else ExEnv::out0() << " (frozen uocc)";
+      ExEnv::out0() << endl;
       }
     }
 
@@ -517,7 +527,7 @@ MBPT2::compute_cs_grad()
 
   // debug print
   if (debug_ && me == 0) {
-    ExEnv::out() << indent
+    ExEnv::out0() << indent
          << scprintf("node %i, begin loop over i-batches",me) << endl;
     }
   // end of debug print
@@ -528,8 +538,6 @@ MBPT2::compute_cs_grad()
   for (i=0; i<thr_->nthread(); i++) {
       tbints_[i] = integral()->electron_repulsion();
     }
-  tbint_ = tbints_[0];
-  intbuf = tbint_->buffer();
   if (dograd || do_d1_) {
     tbintder_ = new Ref<TwoBodyDerivInt>[thr_->nthread()];
     for (i=0; i<thr_->nthread(); i++) {
@@ -544,22 +552,22 @@ MBPT2::compute_cs_grad()
       tbints_[i]->set_integral_storage(mem_integral_storage);
     }
 
-  ExEnv::out() << node0 << endl << indent
+  ExEnv::out0() << endl << indent
        << scprintf("Memory used for integral intermediates: %i Bytes",
                    mem_integral_intermediates)
        << endl;
-  ExEnv::out() << node0 << indent
+  ExEnv::out0() << indent
        << scprintf("Memory used for integral storage:       %i Bytes",
                    mem_integral_storage)
        << endl;
 
   if (mem.null()) {
-      ExEnv::err() << "MBPT2: memory group not initialized" << endl;
+      ExEnv::errn() << "MBPT2: memory group not initialized" << endl;
       abort();
     }
 
   mem->set_localsize(nijmax*nbasis*nbasis*sizeof(double));
-  ExEnv::out() << node0 << indent
+  ExEnv::out0() << indent
        << "Size of global distributed array:       "
        << mem->totalsize()
        << " Bytes"
@@ -567,13 +575,15 @@ MBPT2::compute_cs_grad()
 
   MemoryGrpBuf<double> membuf_remote(mem);
 
+  int usep4 = !dograd;
+
   Ref<ThreadLock> lock = thr_->new_lock();
   CSGradErep12Qtr** e12thread = new CSGradErep12Qtr*[thr_->nthread()];
   for (i=0; i<thr_->nthread(); i++) {
     e12thread[i] = new CSGradErep12Qtr(i, thr_->nthread(), me, nproc,
                                        mem, msg_, lock, basis(), tbints_[i],
                                        nocc, scf_vector, tol, debug_,
-                                       dynamic_);
+                                       dynamic_, usep4);
     }
 
     CSGrad34Qbtr** qbt34thread;
@@ -591,7 +601,7 @@ MBPT2::compute_cs_grad()
   for (pass=0; pass<npass; pass++) {
 
     if (me == 0) {
-      ExEnv::out() << indent << "Beginning pass " << pass+1 << endl;
+      ExEnv::out0() << indent << "Beginning pass " << pass+1 << endl;
       }
 
     i_offset = restart_orbital_memgrp_ + pass*ni + nfzc;
@@ -609,7 +619,7 @@ MBPT2::compute_cs_grad()
 
     // debug print
     if (debug_)
-      ExEnv::out() << indent << "node " << me << ", nij = " << nij << endl;
+      ExEnv::outn() << indent << "node " << me << ", nij = " << nij << endl;
     // end of debug print
 
     mem->sync(); // This must be here or gamma non-sep will be wrong when running
@@ -634,7 +644,7 @@ MBPT2::compute_cs_grad()
     index = 0;
 
     if (me == 0) {
-      ExEnv::out() << indent
+      ExEnv::out0() << indent
            << scprintf("Begin loop over shells (erep, 1.+2. q.t.)") << endl;
       }
 
@@ -655,18 +665,43 @@ MBPT2::compute_cs_grad()
     tim_exit("erep+1.qt+2.qt");
 
     if (me == 0) {
-      ExEnv::out() << indent << "End of loop over shells" << endl;
+      ExEnv::out0() << indent << "End of loop over shells" << endl;
       }
 
     mem->sync();  // Make sure iqjs is complete on each node before continuing
 
     integral_iqjs = (double*) mem->localdata();
 
+#if PRINT2Q
+    if (me == 0) {
+      int index = 0;
+      int ij_index = 0;
+      for (int i = 0; i<ni; i++) {
+	for (int j = 0; j<nocc; j++) {
+	  if (index++ % nproc == me) {
+	    if (j >= nfzc) {
+	      double *integral_ij_offset = integral_iqjs + nbasis*nbasis*ij_index;
+	      for (int s = 0; s<nbasis; s++) {
+		double *integral_ijsq_ptr = integral_ij_offset + s*nbasis;
+		for (int q = 0; q<nbasis; q++) {
+		  printf("2Q: (%d %d|%d %d) = %12.8f\n",
+			 i,q,j,s,*integral_ijsq_ptr);
+		  *integral_ijsq_ptr++;
+		}
+	      }
+	    }
+	    ij_index++;
+	  }
+	}
+      }
+    }
+#endif
+
     // Allocate and initialize some arrays
     ixjs_tmp = new double[nbasis];
 
     if (me == 0) {
-      ExEnv::out() << indent << "Begin third q.t." << endl;
+      ExEnv::out0() << indent << "Begin third q.t." << endl;
       }
 
     tim_enter("3. q.t.");
@@ -720,7 +755,7 @@ MBPT2::compute_cs_grad()
     tim_exit("3. q.t.");
 
     if (me == 0) {
-      ExEnv::out() << indent << "End of third q.t." << endl;
+      ExEnv::out0() << indent << "End of third q.t." << endl;
       }
 
     delete[] ixjs_tmp;
@@ -730,13 +765,38 @@ MBPT2::compute_cs_grad()
     // rename the array integral_ixjs, where x = any MO
     integral_ixjs = integral_iqjs;
 
+#if PRINT3Q
+    if (me == 0) {
+      int index = 0;
+      int ij_index = 0;
+      for (int i = 0; i<ni; i++) {
+	for (int j = 0; j<nocc; j++) {
+	  if (index++ % nproc == me) {
+	    if (j >= nfzc) {
+	      double *integral_ij_offset = integral_ixjs + nbasis*nbasis*ij_index;
+	      for (int s = 0; s<nbasis; s++) {
+		double *integral_ijsx_ptr = integral_ij_offset + s*nbasis;
+		for (int x = 0; x<noso; x++) {
+		  printf("3Q: (%d %d|%d %d) = %12.8f\n",
+			 i,x,j,s,*integral_ijsx_ptr);
+		  *integral_ijsx_ptr++;
+		}
+	      }
+	    }
+	    ij_index++;
+	  }
+	}
+      }
+    }
+#endif
+
     integral_iajy = new double[noso];
     // in iajy: i act; a,j act or frz; y act or frz occ or virt.
     integral_ikja = new double[nvir_act];
     // in ikja: i,j act; k act or frz; a act.
 
     if (me == 0) {
-      ExEnv::out() << indent << "Begin fourth q.t." << endl;
+      ExEnv::out0() << indent << "Begin fourth q.t." << endl;
       }
 
     // Begin fourth quarter transformation
@@ -759,7 +819,7 @@ MBPT2::compute_cs_grad()
               biggest_ints_3.insert(tmpval,i+i_offset,j,s,a);
               if ((i+i_offset==105 && j == 2 && s == 170 && a == 3)
                   ||(i+i_offset==102 && j == 2 && s == 170 && a == 2)) {
-                ExEnv::out() << scprintf("3/4: %3d %3d %3d %3d: %16.10f",
+                ExEnv::outn() << scprintf("3/4: %3d %3d %3d %3d: %16.10f",
                                  i+i_offset, j, s, x-nocc)
                      << endl;
                 }
@@ -812,7 +872,7 @@ MBPT2::compute_cs_grad()
     tim_exit("4. q.t.");
 
     if (me == 0) {
-      ExEnv::out() << indent << "End of fourth q.t." << endl;
+      ExEnv::out0() << indent << "End of fourth q.t." << endl;
       }
 
     // The array integral_ixjs has now been overwritten by MO integrals
@@ -839,7 +899,19 @@ MBPT2::compute_cs_grad()
               iajb_ptr = &mo_int[nocc + nbasis*(b+nocc + nbasis*ij_index)];
               bb = b+nocc;
               for (a=0; a<nvir_act; a++) {
-               *iajb_ptr++ /= evals[ii]+evals[j]-evals[a+nocc]-evals[bb];
+#if PRINT4Q
+	      printf("4Q: (%d %d|%d %d) = %12.8f\n",
+		     i,a+nocc,j,b+nocc,*iajb_ptr);
+#endif
+		// Zero out nonsymmetric integral, else divide by denominators
+	        if (usep4 && ( symorb_irrep_[ii] ^
+		      symorb_irrep_[j] ^
+		      symorb_irrep_[a+nocc] ^
+		      symorb_irrep_[bb]) ) {
+		  *iajb_ptr++ = 0.0;
+		}
+		else
+		  *iajb_ptr++ /= evals[ii]+evals[j]-evals[a+nocc]-evals[bb];
                 } // exit a loop
               }   // exit b loop
             }     // endif
@@ -858,10 +930,10 @@ MBPT2::compute_cs_grad()
 
 #if WRITE_DOUBLES
     if (nproc > 1 || npass > 1) {
-      ExEnv::out() << "csgrad.cc: WRITE_DOUBLES set but case not allowed" << endl;
+      ExEnv::outn() << "csgrad.cc: WRITE_DOUBLES set but case not allowed" << endl;
       abort();
       }
-    ExEnv::out() << "csgrad.cc: WRITING DOUBLES: CHECK ORDER" << endl;
+    ExEnv::outn() << "csgrad.cc: WRITING DOUBLES: CHECK ORDER" << endl;
     char *doutname = SCFormIO::fileext_to_filename(".mp2");
     FILE *dout = fopen(doutname,"w");
     delete[] doutname;
@@ -875,7 +947,7 @@ MBPT2::compute_cs_grad()
           fwrite(iajb_ptr, sizeof(double), nvir_act, dout);
           for (a=0; a<nvir_act; a++) {
             if (fabs(iajb_ptr[a])>1.0e-8) {
-              ExEnv::out() << scprintf(" Djbia(%2d %2d %2d %2d) = %12.8f",
+              ExEnv::outn() << scprintf(" Djbia(%2d %2d %2d %2d) = %12.8f",
                                j+1-nfzc,b+1,i+1,a+1,iajb_ptr[a])
                    << endl;
               }
@@ -928,14 +1000,14 @@ MBPT2::compute_cs_grad()
         if (debug_) {
           msg_->sum(ecorr_ij);
           ecorr_i += ecorr_ij;
-          ExEnv::out() << node0 << indent
+          ExEnv::out0() << indent
                << scprintf("correlation energy for pair %3d %3d = %16.12f",
                            i+i_offset, j, ecorr_ij)
                << endl;
           }
         }         // exit j loop
       if (debug_) {
-        ExEnv::out() << node0 << indent
+        ExEnv::out0() << indent
              << scprintf("correlation energy for orbital %3d = %16.12f",
                          i+i_offset, ecorr_i)
              << endl;
@@ -945,19 +1017,19 @@ MBPT2::compute_cs_grad()
 
     // debug print
     if (debug_ && me == 0) {
-      ExEnv::out() << indent << "End of ecorr" << endl;
+      ExEnv::out0() << indent << "End of ecorr" << endl;
       }
     // end of debug print
 
     if (npass > 1 && pass < npass - 1) {
       double passe = ecorr_mp2;
       msg_->sum(passe);
-      ExEnv::out() << node0 << indent
+      ExEnv::out0() << indent
            << "Partial correlation energy for pass " << pass << ":" << endl;
-      ExEnv::out() << node0 << indent
+      ExEnv::out0() << indent
            << scprintf("  restart_ecorr          = %18.14f", passe)
            << endl;
-      ExEnv::out() << node0 << indent
+      ExEnv::out0() << indent
            << scprintf("  restart_orbital_memgrp = %d", ((pass+1) * ni))
            << endl;
       }
@@ -1033,7 +1105,7 @@ MBPT2::compute_cs_grad()
 
     // debug print
     if (debug_ && me == 0) {
-      ExEnv::out() << indent << "End of Pkj and Wkj" << endl;
+      ExEnv::out0() << indent << "End of Pkj and Wkj" << endl;
       }
     // end of debug print
 
@@ -1109,7 +1181,7 @@ MBPT2::compute_cs_grad()
 
     // debug print
     if (debug_ && me == 0) {
-      ExEnv::out() << indent << "End of Pab and Wab" << endl;
+      ExEnv::out0() << indent << "End of Pab and Wab" << endl;
       }
     // end of debug print
 
@@ -1186,7 +1258,7 @@ MBPT2::compute_cs_grad()
 
     // debug print
     if (debug_ && me == 0) {
-      ExEnv::out() << indent << "End of Paj and Waj" << endl;
+      ExEnv::out0() << indent << "End of Paj and Waj" << endl;
       }
     // end of debug print
 
@@ -1198,13 +1270,13 @@ MBPT2::compute_cs_grad()
 
     gamma_iajs_tmp = new double[nbasis*nvir_act];
     if (!gamma_iajs_tmp) {
-      ExEnv::out() << indent << "Could not allocate gamma_iajs_tmp" << endl;
+      ExEnv::outn() << indent << "Could not allocate gamma_iajs_tmp" << endl;
       abort();
       }
 
     // debug print
     if (debug_ && me == 0) {
-      ExEnv::out() << indent << "Begin first and second q.b.t." << endl;
+      ExEnv::out0() << indent << "Begin first and second q.b.t." << endl;
       }
     // end of debug print
 
@@ -1261,7 +1333,7 @@ MBPT2::compute_cs_grad()
 
     // debug print
     if (debug_ && me == 0) {
-      ExEnv::out() << indent << "End of first q.b.t." << endl;
+      ExEnv::out0() << indent << "End of first q.b.t." << endl;
       }
     // end of debug print
 
@@ -1277,12 +1349,12 @@ MBPT2::compute_cs_grad()
 
     gamma_iqjs_tmp = new double[nbasis];
     if (!gamma_iqjs_tmp) {
-      ExEnv::err() << "Could not allocate gamma_iqjs_tmp" << endl;
+      ExEnv::errn() << "Could not allocate gamma_iqjs_tmp" << endl;
       abort();
       }
 
     if (debug_ && me == 0) {
-      ExEnv::out() << indent << "Begin second q.b.t." << endl;
+      ExEnv::out0() << indent << "Begin second q.b.t." << endl;
       }
 
     // Begin second quarter back-transformation
@@ -1328,7 +1400,7 @@ MBPT2::compute_cs_grad()
     // end of second quarter back-transformation
 
     if (debug_ && me == 0) {
-      ExEnv::out() << indent << "End of second q.b.t." << endl;
+      ExEnv::out0() << indent << "End of second q.b.t." << endl;
       }
 
     gamma_iajs = 0;
@@ -1350,7 +1422,7 @@ MBPT2::compute_cs_grad()
     bzerofast(Lpi,nbasis*ni);
 
     if (me == 0) {
-      ExEnv::out() << indent << "Begin third and fourth q.b.t." << endl;
+      ExEnv::out0() << indent << "Begin third and fourth q.b.t." << endl;
       }
 
     //////////////////////////////////////////////////////////
@@ -1386,7 +1458,7 @@ MBPT2::compute_cs_grad()
       }
 
     if (me == 0) {
-      ExEnv::out() << indent << "End of third and fourth q.b.t." << endl;
+      ExEnv::out0() << indent << "End of third and fourth q.b.t." << endl;
       }
 
     mem->sync(); // Make sure all nodes are done before deleting arrays
@@ -1402,7 +1474,7 @@ MBPT2::compute_cs_grad()
       }
 
     if (debug_ && me == 0) {
-      ExEnv::out() << indent << "Back-transform Lpi" << endl;
+      ExEnv::out0() << indent << "Back-transform Lpi" << endl;
       }
 
     // Back-transform Lpi to MO basis
@@ -1423,7 +1495,7 @@ MBPT2::compute_cs_grad()
     delete[] Lpi;
 
     if (me == 0) {
-      ExEnv::out() << indent << "Done with pass " << pass+1 << endl;
+      ExEnv::out0() << indent << "Done with pass " << pass+1 << endl;
       }
     }           // exit loop over i-batches (pass)
   tim_exit("mp2 passes");
@@ -1439,7 +1511,7 @@ MBPT2::compute_cs_grad()
 
   // debug print
   if (debug_ && me == 0) {
-    ExEnv::out() << indent << "Exited loop over i-batches" << endl;
+    ExEnv::out0() << indent << "Exited loop over i-batches" << endl;
     }
   // end of debug print
 
@@ -1464,9 +1536,9 @@ MBPT2::compute_cs_grad()
     emp2 = escf + ecorr_mp2;
 
 #if PRINT_BIGGEST_INTS
-    ExEnv::out() << "biggest 1/4 transformed ints" << endl;
+    ExEnv::out0() << "biggest 1/4 transformed ints" << endl;
     for (i=0; i<biggest_ints_1.ncontrib(); i++) {
-      ExEnv::out() << scprintf("%3d %3d %3d %3d %16.12f",
+      ExEnv::outn() << scprintf("%3d %3d %3d %3d %16.12f",
                        biggest_ints_1.indices(i)[0],
                        biggest_ints_1.indices(i)[1],
                        biggest_ints_1.indices(i)[2],
@@ -1475,9 +1547,9 @@ MBPT2::compute_cs_grad()
                        )
            << endl;
       }
-    ExEnv::out() << "biggest 2/4 transformed ints" << endl;
+    ExEnv::outn() << "biggest 2/4 transformed ints" << endl;
     for (i=0; i<biggest_ints_2.ncontrib(); i++) {
-      ExEnv::out() << scprintf("%3d %3d %3d %3d %16.12f",
+      ExEnv::outn() << scprintf("%3d %3d %3d %3d %16.12f",
                        biggest_ints_2.indices(i)[0],
                        biggest_ints_2.indices(i)[1],
                        biggest_ints_2.indices(i)[2],
@@ -1486,9 +1558,9 @@ MBPT2::compute_cs_grad()
                        )
            << endl;
       }
-    ExEnv::out() << "restricted 2/4 transformed ints" << endl;
+    ExEnv::outn() << "restricted 2/4 transformed ints" << endl;
     for (i=0; i<biggest_ints_2s.ncontrib(); i++) {
-      ExEnv::out() << scprintf("%3d %3d %3d %3d %16.12f",
+      ExEnv::outn() << scprintf("%3d %3d %3d %3d %16.12f",
                        biggest_ints_2s.indices(i)[0],
                        biggest_ints_2s.indices(i)[1],
                        biggest_ints_2s.indices(i)[2],
@@ -1497,9 +1569,9 @@ MBPT2::compute_cs_grad()
                        )
            << endl;
       }
-    ExEnv::out() << "biggest 3/4 transformed ints (in 3.)" << endl;
+    ExEnv::outn() << "biggest 3/4 transformed ints (in 3.)" << endl;
     for (i=0; i<biggest_ints_3a.ncontrib(); i++) {
-      ExEnv::out() << scprintf("%3d %3d %3d %3d %16.12f",
+      ExEnv::outn() << scprintf("%3d %3d %3d %3d %16.12f",
                        biggest_ints_3a.indices(i)[0],
                        biggest_ints_3a.indices(i)[1],
                        biggest_ints_3a.indices(i)[2],
@@ -1508,9 +1580,9 @@ MBPT2::compute_cs_grad()
                        )
            << endl;
       }
-    ExEnv::out() << "biggest 3/4 transformed ints (in 4.)" << endl;
+    ExEnv::outn() << "biggest 3/4 transformed ints (in 4.)" << endl;
     for (i=0; i<biggest_ints_3.ncontrib(); i++) {
-      ExEnv::out() << scprintf("%3d %3d %3d %3d %16.12f",
+      ExEnv::outn() << scprintf("%3d %3d %3d %3d %16.12f",
                        biggest_ints_3.indices(i)[0],
                        biggest_ints_3.indices(i)[1],
                        biggest_ints_3.indices(i)[2],
@@ -1523,7 +1595,7 @@ MBPT2::compute_cs_grad()
 
     if (restart_orbital_memgrp_ == 0) {
       if (biggest_coefs.ncontrib()) {
-        ExEnv::out() << endl << indent
+        ExEnv::out0() << endl << indent
              << "Largest first order coefficients (unique):"
              << endl;
         }
@@ -1533,7 +1605,7 @@ MBPT2::compute_cs_grad()
         int i2 = biggest_coefs.indices(i)[2] + nocc;
         int i3 = biggest_coefs.indices(i)[3] + nocc;
         int spincase = biggest_coefs.indices(i)[4];
-        ExEnv::out() << indent
+        ExEnv::out0() << indent
              << scprintf("  %2d %12.8f %2d %3s %2d %3s -> %2d %3s %2d %3s (%s)",
                          i+1, biggest_coefs.val(i),
                          symorb_num_[i0]+1,
@@ -1553,34 +1625,34 @@ MBPT2::compute_cs_grad()
     // Print out various energies etc.
 
     if (debug_) {
-      ExEnv::out() << indent << "Number of shell quartets for which AO integrals\n"
+      ExEnv::out0() << indent << "Number of shell quartets for which AO integrals\n"
            << indent << "(or integral derivatives) would have been computed\n"
            << indent << "without bounds checking: "
            << npass*nshell*nshell*(nshell+1)*(nshell+1)/2
            << endl;
 
-      ExEnv::out() << indent << "Number of shell quartets for which AO integrals\n"
+      ExEnv::out0() << indent << "Number of shell quartets for which AO integrals\n"
            << indent << "were computed: " << aoint_computed
            << endl;
 
       if (dograd) {
-        ExEnv::out() << indent
+        ExEnv::out0() << indent
              << "Number of shell quartets for which AO integral derivatives\n"
              << indent << "were computed: " << aointder_computed
              << endl;
         }
       }
 
-    ExEnv::out()<<endl<<indent
+    ExEnv::out0()<<endl<<indent
         <<scprintf("RHF energy [au]:                   %17.12lf\n", escf);
-    ExEnv::out()<<indent
+    ExEnv::out0()<<indent
         <<scprintf("MP2 correlation energy [au]:       %17.12lf\n", ecorr_mp2);
-    ExEnv::out()<<indent
+    ExEnv::out0()<<indent
         <<scprintf("MP2 energy [au]:                   %17.12lf\n", emp2);
-    ExEnv::out().flush();
+    ExEnv::out0().flush();
     }
   if (method_ && strcmp(method_,"mp")) {
-    ExEnv::out() << node0 << indent
+    ExEnv::out0() << indent
          << "MBPT2: bad method for closed shell case: " << method_
          << ", using mp" << endl;
     }
@@ -1641,8 +1713,8 @@ MBPT2::compute_cs_grad()
     double d1_diag = sqrt(D1_mat.eigvals().get_element(nocc_act-1));
     D1_mat = 0;
     // print the norms
-    ExEnv::out() <<node0<<endl;
-    ExEnv::out() <<node0
+    ExEnv::out0()<<endl;
+    ExEnv::out0()
          <<indent<<scprintf("D1(MP2)                = %12.8f", d1_diag)
          <<endl
          <<indent<<scprintf("S2 matrix 1-norm       = %12.8f", t1onenorm)
@@ -1652,13 +1724,13 @@ MBPT2::compute_cs_grad()
          <<indent<<scprintf("S2 diagnostic          = %12.8f", s2_diag)
          <<endl;
     if (biggest_t1.ncontrib()) {
-      ExEnv::out() << node0 << endl
+      ExEnv::out0() << endl
            << indent << "Largest S2 values (unique determinants):" << endl;
       }
     for (i=0; i<biggest_t1.ncontrib(); i++) {
       int i0 = biggest_t1.indices(i)[0];
       int i1 = biggest_t1.indices(i)[1] + nocc;
-      ExEnv::out() << node0
+      ExEnv::out0()
            << indent << scprintf("  %2d %12.8f %2d %3s -> %2d %3s",
                                  i+1, biggest_t1.val(i),
                                  symorb_num_[i0]+1,
@@ -1724,7 +1796,7 @@ MBPT2::compute_cs_grad()
     d2o = sqrt(D2occ_mat.eigvals().get_element(nocc_act-1));
     d2v = sqrt(D2vir_mat.eigvals().get_element(nvir_act-1));
     d2_diag = (d2o > d2v ? d2o:d2v);
-    ExEnv::out() << node0 << endl
+    ExEnv::out0() << endl
          << indent <<  scprintf("D2(MP1) = %12.8f", d2_diag) << endl << endl;
     delete[] d2occ_mat;
     delete[] d2vir_mat;
@@ -1892,6 +1964,7 @@ MBPT2::compute_cs_grad()
   make_cs_gmat_new(Gmat, Dmat_matrix);
   tim_exit("make_gmat for Wkj");
   done_cs_gmat();
+  for (i=0; i<thr_->nthread(); i++) tbints_[i] = 0;
   delete[] tbints_; tbints_ = 0;
   RefSCMatrix Wkj_matrix(nocc_dim, nocc_dim, kit);
   Wkj_matrix->assign(Wkj);
@@ -2154,7 +2227,7 @@ MBPT2::compute_cs_grad()
   // print out the gradient
   ////////////////////////////////////////////////////////
   if (debug_) {
-    ExEnv::out() << node0 << "Obtaining HF gradient" << endl;
+    ExEnv::out0() << "Obtaining HF gradient" << endl;
     print_natom_3(ref()->gradient(),"HF gradient from HF");
     print_natom_3(hf_gradient,"Total HF gradient from MP2 [au]:");
     }
@@ -2408,9 +2481,9 @@ accum_gradients(double **g, double **f, int n1, int n2)
 // affect the batch size.
 /////////////////////////////////////
 int
-MBPT2::compute_cs_batchsize(int mem_static, int nocc_act)
+MBPT2::compute_cs_batchsize(size_t mem_static, int nocc_act)
 {
-  unsigned int mem_dyn;   // dynamic memory available
+  size_t mem_dyn;   // dynamic memory available
   distsize_t maxdyn;
   int ni;
 
@@ -2421,7 +2494,12 @@ MBPT2::compute_cs_batchsize(int mem_static, int nocc_act)
   // the end of the i-batch loop (mem2)
   ///////////////////////////////////////
 
-  mem_dyn = mem_alloc - mem_static;
+  if (mem_alloc > mem_static) {
+    mem_dyn = mem_alloc - mem_static;
+    }
+  else {
+    mem_dyn = 0;
+    }
 
   // First determine if calculation is possible at all (i.e., if ni=1 possible)
 
