@@ -37,6 +37,7 @@
 #include <chemistry/qc/mbpt/mbpt.h>
 
 using namespace std;
+using namespace sc;
 
 /////////////////////////////////////////////////////////////////
 // Function dquicksort performs a quick sort (smaller -> larger) 
@@ -85,7 +86,7 @@ dquicksort(double *item,int *index,int n)
 // MBPT2
 
 static ClassDesc MBPT2_cd(
-  typeid(MBPT2),"MBPT2",7,"public Wavefunction",
+  typeid(MBPT2),"MBPT2",8,"public Wavefunction",
   0, create<MBPT2>, create<MBPT2>);
 
 MBPT2::MBPT2(StateIn& s):
@@ -95,7 +96,16 @@ MBPT2::MBPT2(StateIn& s):
   reference_ << SavableState::restore_state(s);
   s.get(nfzc);
   s.get(nfzv);
-  s.get(mem_alloc);
+  if (s.version(::class_desc<MBPT2>()) >= 8) {
+      double dmem_alloc;
+      s.get(dmem_alloc);
+      mem_alloc = size_t(dmem_alloc);
+    }
+  else {
+      unsigned int imem_alloc;
+      s.get(imem_alloc);
+      mem_alloc = imem_alloc;
+    }
   s.getstring(method_);
   s.getstring(algorithm_);
 
@@ -160,7 +170,7 @@ MBPT2::MBPT2(const Ref<KeyVal>& keyval):
 {
   reference_ << keyval->describedclassvalue("reference");
   if (reference_.null()) {
-      ExEnv::err() << node0 << "MBPT2::MBPT2: no reference wavefunction" << endl;
+      ExEnv::err0() << "MBPT2::MBPT2: no reference wavefunction" << endl;
       abort();
     }
   copy_orthog_info(reference_);
@@ -168,31 +178,28 @@ MBPT2::MBPT2(const Ref<KeyVal>& keyval):
   char *nfzc_charval = keyval->pcharvalue("nfzc");
   if (nfzc_charval && !strcmp(nfzc_charval, "auto")) {
       if (molecule()->max_z() > 30) {
-          ExEnv::err() << node0
+          ExEnv::err0()
                << "MBPT2: cannot use \"nfzc = auto\" for Z > 30" << endl;
           abort();
         }
       nfzc = molecule()->n_core_electrons()/2;
-      ExEnv::out() << node0 << indent
+      ExEnv::out0() << indent
            << "MBPT2: auto-freezing " << nfzc << " core orbitals" << endl;
     }
   delete[] nfzc_charval;
   nfzv = keyval->intvalue("nfzv");
-  mem_alloc = keyval->intvalue("memory");
+  mem_alloc = keyval->sizevalue("memory");
   if (keyval->error() != KeyVal::OK) {
       // by default, take half of the memory
       mem_alloc = ExEnv::memory()/2;
       if (mem_alloc == 0) {
-          mem_alloc = 8000000;
+          mem_alloc = DEFAULT_SC_MEMORY;
         }
     }
   mem << keyval->describedclassvalue("memorygrp");
   if (mem.null()) {
       mem = MemoryGrp::get_default_memorygrp();
     }
-  if (mem.null()) {
-      mem = MemoryGrp::initial_memorygrp();
-    }
   msg_ = MessageGrp::get_default_messagegrp();
   thr_ = ThreadGrp::get_default_threadgrp();
 
@@ -237,7 +244,8 @@ MBPT2::save_data_state(StateOut& s)
   SavableState::save_state(reference_.pointer(),s);
   s.put(nfzc);
   s.put(nfzv);
-  s.put(mem_alloc);
+  double dmem_alloc = mem_alloc;
+  s.put(dmem_alloc);
   s.putstring(method_);
   s.putstring(algorithm_);
   s.put(do_d1_);
@@ -250,11 +258,11 @@ MBPT2::save_data_state(StateOut& s)
 void
 MBPT2::print(ostream&o) const
 {
-  o << node0 << indent << "MBPT2:" << endl;
+  o << indent << "MBPT2:" << endl;
   o << incindent;
   Wavefunction::print(o);
-  o << node0 << indent << "Reference Wavefunction:" << endl;
-  o << incindent; reference_->print(o); o << decindent << node0 << endl;
+  o << indent << "Reference Wavefunction:" << endl;
+  o << incindent; reference_->print(o); o << decindent << endl;
   o << decindent;
 }
 
@@ -283,14 +291,14 @@ MBPT2::compute()
                                          / ref_to_mp2_acc);
   if (gradient_needed()) {
       if (nsocc) {
-          ExEnv::err() << "MBPT2: cannot compute open shell gradients" << endl;
+          ExEnv::errn() << "MBPT2: cannot compute open shell gradients" << endl;
           abort();
         }
       compute_cs_grad();
     }
   else {
       if (nsocc && algorithm_ && !strcmp(algorithm_,"memgrp")) {
-          ExEnv::err() << "MBPT2: memgrp algorithm cannot compute open shell energy"
+          ExEnv::errn() << "MBPT2: memgrp algorithm cannot compute open shell energy"
                << endl;
           abort();
         }
@@ -308,7 +316,7 @@ MBPT2::compute()
           compute_hsos_v2_lb();
         }
       else {
-          ExEnv::err() << "MBPT2: unknown algorithm: " << algorithm_ << endl;
+          ExEnv::errn() << "MBPT2: unknown algorithm: " << algorithm_ << endl;
           abort();
         }
     }
@@ -358,7 +366,7 @@ MBPT2::eigen(RefDiagSCMatrix &vals, RefSCMatrix &vecs, RefDiagSCMatrix &occs)
   int i, j;
   if (nsocc) {
       if (reference_->n_fock_matrices() != 2) {
-          ExEnv::err() << "MBPT2: given open reference with"
+          ExEnv::errn() << "MBPT2: given open reference with"
                << " wrong number of Fock matrices" << endl;
           abort();
         }
@@ -443,7 +451,7 @@ MBPT2::eigen(RefDiagSCMatrix &vals, RefSCMatrix &vecs, RefDiagSCMatrix &occs)
       vecs = vecs_mo1_mo2.t() * vecs_so_mo1.t() * so_ao;
     }
   else {
-      if (debug_) ExEnv::out() << node0 << indent << "getting fock matrix" << endl;
+      if (debug_) ExEnv::out0() << indent << "getting fock matrix" << endl;
       // get the closed shell AO fock matrices
       RefSymmSCMatrix fock_c_so = reference_->fock(0);
 
@@ -456,12 +464,12 @@ MBPT2::eigen(RefDiagSCMatrix &vals, RefSCMatrix &vecs, RefDiagSCMatrix &occs)
       fock_c_mo1.accumulate_transform(vecs_so_mo1.t(), fock_c_so);
       fock_c_so = 0;
 
-      if (debug_) ExEnv::out() << node0 << indent << "diagonalizing" << endl;
+      if (debug_) ExEnv::out0() << indent << "diagonalizing" << endl;
       // diagonalize the fock matrix
       vals = fock_c_mo1.eigvals();
 
       // compute the AO to new MO scf vector
-      if (debug_) ExEnv::out() << node0 << indent << "AO to MO" << endl;
+      if (debug_) ExEnv::out0() << indent << "AO to MO" << endl;
       RefSCMatrix so_ao = reference_->integral()->petite_list()->sotoao();
       vecs = vecs_so_mo1.t() * so_ao;
     }
@@ -481,7 +489,7 @@ MBPT2::eigen(RefDiagSCMatrix &vals, RefSCMatrix &vecs, RefDiagSCMatrix &occs)
       RefDiagSCMatrix valsi = bvals->block(i);
       for (j=1; j<valsi.n(); j++) {
           if (fabs(valsi(j)-valsi(j-1)) < 1.0e-7) {
-              ExEnv::out() << node0 << indent
+              ExEnv::out0() << indent
                    << "NOTE: There are degenerate orbitals within an irrep."
                    << "  This will make"
                    << endl
@@ -497,7 +505,7 @@ MBPT2::eigen(RefDiagSCMatrix &vals, RefSCMatrix &vecs, RefDiagSCMatrix &occs)
     }
   // sort the eigenvectors and values if symmetry is not c1
   if (molecule()->point_group()->char_table().order() != 1) {
-      if (debug_) ExEnv::out() << node0 << indent << "sorting eigenvectors" << endl;
+      if (debug_) ExEnv::out0() << indent << "sorting eigenvectors" << endl;
       double *evals = new double[noso];
       vals->convert(evals);
       int *indices = new int[noso];
@@ -541,7 +549,7 @@ MBPT2::eigen(RefDiagSCMatrix &vals, RefSCMatrix &vecs, RefDiagSCMatrix &occs)
     }
   else {
       // compute orbital symmetry information for c1
-      for (i=0; i<nbasis; i++) {
+      for (i=0; i<noso; i++) {
           symorb_irrep_[i] = 0;
           symorb_num_[i] = i;
         }
@@ -550,7 +558,7 @@ MBPT2::eigen(RefDiagSCMatrix &vals, RefSCMatrix &vecs, RefDiagSCMatrix &occs)
   if (nfzc && nfzc < noso) {
       double split = vals(nfzc) - vals(nfzc-1);
       if (split < 0.2) {
-          ExEnv::out() << node0 << endl
+          ExEnv::out0() << endl
                << indent << "WARNING: "
                << "MBPT2: gap between frozen and active occupied orbitals is "
                << split << " au" << endl << endl;
@@ -559,13 +567,13 @@ MBPT2::eigen(RefDiagSCMatrix &vals, RefSCMatrix &vecs, RefDiagSCMatrix &occs)
   if (nfzv && noso-nfzv-1 >= 0) {
       double split = vals(nbasis-nfzv) - vals(nbasis-nfzv-1);
       if (split < 0.2) {
-          ExEnv::out() << node0 << endl
+          ExEnv::out0() << endl
                << indent << "WARNING: "
                << "MBPT2: gap between frozen and active virtual orbitals is "
                << split << " au" << endl << endl;
         }
     }
-  if (debug_) ExEnv::out() << node0 << indent << "eigen done" << endl;
+  if (debug_) ExEnv::out0() << indent << "eigen done" << endl;
 }
 
 /////////////////////////////////////////////////////////////////////////////
@@ -576,7 +584,7 @@ MBPT2::init_variables()
   nbasis = so_dimension()->n();
   noso = oso_dimension()->n();
 //    if (nbasis != noso) {
-//        ExEnv::out() << "MBPT2: Noso != Nbasis: MBPT2 not checked for this case" << endl;
+//        ExEnv::outn() << "MBPT2: Noso != Nbasis: MBPT2 not checked for this case" << endl;
 //        abort();
 //      }
   nocc = nvir = nsocc = 0;
@@ -609,8 +617,7 @@ MBPT2::nelectron()
 double
 MBPT2::ref_energy()
 {
-  energy();
-  return hf_energy_;
+  return reference_->energy();
 }
 
 /////////////////////////////////////////////////////////////////////////////
@@ -618,8 +625,7 @@ MBPT2::ref_energy()
 double
 MBPT2::corr_energy()
 {
-  energy();
-  return energy() - hf_energy_;
+  return energy() - reference_->energy();
 }
 
 /////////////////////////////////////////////////////////////////////////////
