@@ -1,5 +1,5 @@
 #include <chemistry/qc/oint3/build.h>
-int BuildIntV3::i1312(){
+int sc::BuildIntV3::i1312(){
 /* the cost is 1528 */
 double t1;
 double t2;
@@ -170,12 +170,12 @@ double t166;
 double t167;
 double t168;
 t1=int_v_W0-int_v_p120;
-double***int_v_list0=int_v_list(0);
-double**int_v_list00=int_v_list0[0];
-double*int_v_list003=int_v_list00[3];
+double***restrictxx int_v_list0=int_v_list(0);
+double**restrictxx int_v_list00=int_v_list0[0];
+double*restrictxx int_v_list003=int_v_list00[3];
 t2=t1*int_v_list003[0];
 t3=int_v_p120-int_v_r10;
-double*int_v_list002=int_v_list00[2];
+double*restrictxx int_v_list002=int_v_list00[2];
 t4=t3*int_v_list002[0];
 t5=t4+t2;
 t2=0.5*int_v_ooze;
@@ -191,13 +191,13 @@ t7=(-1)*t9;
 t9=t7*t10;
 t11=t9+t4;
 t12=t6*int_v_list002[0];
-double*int_v_list001=int_v_list00[1];
+double*restrictxx int_v_list001=int_v_list00[1];
 t13=t8*int_v_list001[0];
 t14=t13+t12;
 t12=int_v_oo2zeta12*t14;
 t13=t12+t11;
 t11=t2*int_v_list003[0];
-double*int_v_list004=int_v_list00[4];
+double*restrictxx int_v_list004=int_v_list00[4];
 t15=t6*int_v_list004[0];
 t16=t8*int_v_list003[0];
 t17=t16+t15;
@@ -248,7 +248,7 @@ t15=t16*t14;
 t21=t1*t29;
 t30=t21+t15;
 t15=t23*int_v_list001[0];
-double*int_v_list000=int_v_list00[0];
+double*restrictxx int_v_list000=int_v_list00[0];
 t21=int_v_oo2zeta34*int_v_list000[0];
 t31=t21+t15;
 t15=t6*t14;
@@ -260,9 +260,9 @@ t15=t8*t33;
 t32=t15+t21;
 t15=t3*t32;
 t21=t15+t30;
-double***int_v_list1=int_v_list(1);
-double**int_v_list12=int_v_list1[2];
-double*int_v_list120=int_v_list12[0];
+double***restrictxx int_v_list1=int_v_list(1);
+double**restrictxx int_v_list12=int_v_list1[2];
+double*restrictxx int_v_list120=int_v_list12[0];
 int_v_list120[17]=t21;
 t15=int_v_oo2zeta12*2;
 t30=t15*t21;
@@ -276,7 +276,7 @@ t35=t16*t17;
 t37=t23*int_v_list004[0];
 t23=int_v_oo2zeta34*int_v_list003[0];
 t38=t23+t37;
-double*int_v_list005=int_v_list00[5];
+double*restrictxx int_v_list005=int_v_list00[5];
 t23=t6*int_v_list005[0];
 t37=t8*int_v_list004[0];
 t39=t37+t23;
@@ -303,15 +303,15 @@ t37=t1*t24;
 t41=t37+t40;
 t37=t3*t21;
 t40=t37+t41;
-double***int_v_list2=int_v_list(2);
-double**int_v_list22=int_v_list2[2];
-double*int_v_list220=int_v_list22[0];
+double***restrictxx int_v_list2=int_v_list(2);
+double**restrictxx int_v_list22=int_v_list2[2];
+double*restrictxx int_v_list220=int_v_list22[0];
 int_v_list220[35]=t40;
 t37=t3*t40;
 t41=t37+t23;
-double***int_v_list3=int_v_list(3);
-double**int_v_list32=int_v_list3[2];
-double*int_v_list320=int_v_list32[0];
+double***restrictxx int_v_list3=int_v_list(3);
+double**restrictxx int_v_list32=int_v_list3[2];
+double*restrictxx int_v_list320=int_v_list32[0];
 int_v_list320[59]=t41;
 t23=int_v_W2-int_v_p342;
 t37=t23*int_v_list003[0];
@@ -349,8 +349,8 @@ t56=t1*t14;
 t57=t56+t55;
 t56=t3*t33;
 t58=t56+t57;
-double**int_v_list11=int_v_list1[1];
-double*int_v_list110=int_v_list11[0];
+double**restrictxx int_v_list11=int_v_list1[1];
+double*restrictxx int_v_list110=int_v_list11[0];
 int_v_list110[8]=t58;
 t56=t42*t58;
 t57=t56+t48;
@@ -395,8 +395,8 @@ t70=t1*t20;
 t73=t70+t72;
 t70=t3*t58;
 t72=t70+t73;
-double**int_v_list21=int_v_list2[1];
-double*int_v_list210=int_v_list21[0];
+double**restrictxx int_v_list21=int_v_list2[1];
+double*restrictxx int_v_list210=int_v_list21[0];
 int_v_list210[17]=t72;
 t70=t42*t72;
 t73=t70+t56;
@@ -1026,8 +1026,8 @@ t102=t68+t71;
 int_v_list210[8]=t102;
 t68=t146*t102;
 t71=t68+t30;
-double**int_v_list31=int_v_list3[1];
-double*int_v_list310=int_v_list31[0];
+double**restrictxx int_v_list31=int_v_list3[1];
+double*restrictxx int_v_list310=int_v_list31[0];
 int_v_list310[11]=t71;
 t30=t42*t71;
 t68=t30+t39;
