@@ -31,7 +31,9 @@
 
 #include <math.h>
 #include <limits.h>
+#include <sys/types.h>
 #include <sys/stat.h>
+#include <unistd.h>
 
 #include <util/misc/formio.h>
 #include <util/state/stateio.h>
@@ -48,12 +50,13 @@
 #include <chemistry/qc/scf/scf.h>
 
 using namespace std;
+using namespace sc;
 
 ///////////////////////////////////////////////////////////////////////////
 // SCF
 
 static ClassDesc SCF_cd(
-  typeid(SCF),"SCF",5,"public OneBodyWavefunction",
+  typeid(SCF),"SCF",6,"public OneBodyWavefunction",
   0, 0, 0);
 
 SCF::SCF(StateIn& s) :
@@ -67,7 +70,16 @@ SCF::SCF(StateIn& s) :
   s.get(dens_reset_freq_);
   s.get(reset_occ_);
   s.get(local_dens_);
-  s.get(storage_);
+  if (s.version(::class_desc<SCF>()) >= 3) {
+    double dstorage;
+    s.get(dstorage);
+    storage_ = size_t(dstorage);
+  }
+  else {
+    unsigned int istorage;
+    s.get(istorage);
+    storage_ = istorage;
+  }
   if (s.version(::class_desc<SCF>()) >= 2) {
     s.get(print_all_evals_);
     s.get(print_occ_evals_);
@@ -82,6 +94,10 @@ SCF::SCF(StateIn& s) :
     guess_wfn_ << SavableState::restore_state(s);
   }
   else keep_guess_wfn_ = 0;
+  if (s.version(::class_desc<SCF>()) >= 6) {
+    s.get(always_use_guess_wfn_);
+  }
+  else always_use_guess_wfn_ = 0;
 
   extrap_ << SavableState::restore_state(s);
   accumdih_ << SavableState::restore_state(s);
@@ -126,8 +142,8 @@ SCF::SCF(const Ref<KeyVal>& keyval) :
   if (accumddh_.null())
     accumddh_ = new AccumHNull;
   
-  KeyValValueint defaultmem(8000000);
-  storage_ = keyval->intvalue("memory",defaultmem);
+  KeyValValuesize defaultmem(DEFAULT_SC_MEMORY);
+  storage_ = keyval->sizevalue("memory",defaultmem);
   
   if (keyval->exists("local_density"))
     local_dens_ = keyval->booleanvalue("local_density");
@@ -140,10 +156,13 @@ SCF::SCF(const Ref<KeyVal>& keyval) :
   
   keep_guess_wfn_ = keyval->booleanvalue("keep_guess_wavefunction");
 
+  always_use_guess_wfn_
+    = keyval->booleanvalue("always_use_guess_wavefunction");
+
   // first see if guess_wavefunction is a wavefunction, then check to
   // see if it's a string.
   if (keyval->exists("guess_wavefunction")) {
-    ExEnv::out() << incindent << incindent;
+    ExEnv::out0() << incindent << incindent;
     guess_wfn_ << keyval->describedclassvalue("guess_wavefunction");
     compute_guess_=1;
     if (guess_wfn_.null()) {
@@ -165,7 +184,7 @@ SCF::SCF(const Ref<KeyVal>& keyval) :
         delete[] path;
       }
     }
-    ExEnv::out() << decindent << decindent;
+    ExEnv::out0() << decindent << decindent;
   }
 }
 
@@ -181,12 +200,14 @@ SCF::save_data_state(StateOut& s)
   s.put(dens_reset_freq_);
   s.put(reset_occ_);
   s.put(local_dens_);
-  s.put(storage_);
+  double dstorage = storage_;
+  s.put(dstorage);
   s.put(print_all_evals_);
   s.put(print_occ_evals_);
   s.put(level_shift_);
   s.put(keep_guess_wfn_);
   SavableState::save_state(guess_wfn_.pointer(),s);
+  s.put(always_use_guess_wfn_);
   SavableState::save_state(extrap_.pointer(),s);
   SavableState::save_state(accumdih_.pointer(),s);
   SavableState::save_state(accumddh_.pointer(),s);
@@ -223,10 +244,10 @@ void
 SCF::print(ostream&o) const
 {
   OneBodyWavefunction::print(o);
-  o << node0 << indent << "SCF Parameters:\n" << incindent
+  o << indent << "SCF Parameters:\n" << incindent
     << indent << "maxiter = " << maxiter_ << endl
     << indent << "density_reset_frequency = " << dens_reset_freq_ << endl
-    << indent << scprintf("level_shift = %f\n",level_shift_)
+    << indent << scprintf("level_shift = %f\n",level_shift_) 
     << decindent << endl;
 }
 
@@ -248,7 +269,7 @@ SCF::compute()
 
   double delta;
   if (value_needed()) {
-    ExEnv::out() << node0 << endl << indent
+    ExEnv::out0() << endl << indent
          << scprintf("SCF::compute: energy accuracy = %10.7e\n",
                      desired_value_accuracy())
          << endl;
@@ -260,7 +281,7 @@ SCF::compute()
     double nucrep = molecule()->nuclear_repulsion_energy();
     double eother = 0.0;
     if (accumddh_.nonnull()) eother = accumddh_->e();
-    ExEnv::out() << node0 << endl << indent
+    ExEnv::out0() << endl << indent
          << scprintf("total scf energy = %15.10f", eelec+eother+nucrep)
          << endl;
 
@@ -274,7 +295,7 @@ SCF::compute()
   if (gradient_needed()) {
     RefSCVector gradient = matrixkit()->vector(moldim());
 
-    ExEnv::out() << node0 << endl << indent
+    ExEnv::out0() << endl << indent
          << scprintf("SCF::compute: gradient accuracy = %10.7e\n",
                      desired_gradient_accuracy())
          << endl;
@@ -289,7 +310,7 @@ SCF::compute()
   if (hessian_needed()) {
     RefSymmSCMatrix hessian = matrixkit()->symmmatrix(moldim());
     
-    ExEnv::out() << node0 << endl << indent
+    ExEnv::out0() << endl << indent
          << scprintf("SCF::compute: hessian accuracy = %10.7e\n",
                      desired_hessian_accuracy())
          << endl;
@@ -378,18 +399,19 @@ void
 SCF::initial_vector(int needv)
 {
   if (need_vec_) {
-    if (oso_eigenvectors_.result_noupdate().null()) {
+    if (always_use_guess_wfn_ || oso_eigenvectors_.result_noupdate().null()) {
       // if guess_wfn_ is non-null then try to get a guess vector from it.
       // First check that the same basis is used...if not, then project the
       // guess vector into the present basis.
       if (guess_wfn_.nonnull()) {
         if (basis()->equiv(guess_wfn_->basis())
-            &&orthog_method() == guess_wfn_->orthog_method()) {
-          ExEnv::out() << node0 << indent
+            &&orthog_method() == guess_wfn_->orthog_method()
+            &&oso_dimension()->equiv(guess_wfn_->oso_dimension().pointer())) {
+          ExEnv::out0() << indent
                << "Using guess wavefunction as starting vector" << endl;
 
           // indent output of eigenvectors() call if there is any
-          ExEnv::out() << incindent << incindent;
+          ExEnv::out0() << incindent << incindent;
           SCF *g = dynamic_cast<SCF*>(guess_wfn_.pointer());
           if (!g || compute_guess_) {
             oso_eigenvectors_ = guess_wfn_->oso_eigenvectors().copy();
@@ -398,27 +420,27 @@ SCF::initial_vector(int needv)
             oso_eigenvectors_ = g->oso_eigenvectors_.result_noupdate().copy();
             eigenvalues_ = g->eigenvalues_.result_noupdate().copy();
           }
-          ExEnv::out() << decindent << decindent;
+          ExEnv::out0() << decindent << decindent;
         } else {
-          ExEnv::out() << node0 << indent
+          ExEnv::out0() << indent
                << "Projecting guess wavefunction into the present basis set"
                << endl;
 
           // indent output of projected_eigenvectors() call if there is any
-          ExEnv::out() << incindent << incindent;
+          ExEnv::out0() << incindent << incindent;
           oso_eigenvectors_ = projected_eigenvectors(guess_wfn_);
           eigenvalues_ = projected_eigenvalues(guess_wfn_);
-          ExEnv::out() << decindent << decindent;
+          ExEnv::out0() << decindent << decindent;
         }
 
         // we should only have to do this once, so free up memory used
         // for the old wavefunction, unless told otherwise
         if (!keep_guess_wfn_) guess_wfn_=0;
 
-        ExEnv::out() << node0 << endl;
+        ExEnv::out0() << endl;
       
       } else {
-        ExEnv::out() << node0 << indent << "Starting from core Hamiltonian guess\n"
+        ExEnv::out0() << indent << "Starting from core Hamiltonian guess\n"
              << endl;
         oso_eigenvectors_ = hcore_guess(eigenvalues_.result_noupdate());
       }
@@ -442,7 +464,7 @@ SCF::init_mem(int nm)
     return;
   }
   
-  int nmem = i_offset(basis()->nbasis())*nm*sizeof(double);
+  size_t nmem = i_offset(basis()->nbasis())*nm*sizeof(double);
 
   // if we're actually using local matrices, then there's no choice
   if (dynamic_cast<LocalSCMatrixKit*>(basis()->matrixkit().pointer())
@@ -605,7 +627,7 @@ SCF::so_density(const RefSymmSCMatrix& d, double occ, int alp)
 
     // for now quit
     else {
-      ExEnv::err() << node0 << indent
+      ExEnv::err0() << indent
            << "Cannot yet use anything but Local matrices"
            << endl;
       abort();
@@ -613,7 +635,7 @@ SCF::so_density(const RefSymmSCMatrix& d, double occ, int alp)
   }
 
   if (debug_ > 0) {
-    ExEnv::out() << node0 << indent
+    ExEnv::out0() << indent
          << "Nelectron = " << 2.0 * (d * overlap()).trace() << endl;
   }
 
@@ -632,12 +654,12 @@ SCF::so_density(const RefSymmSCMatrix& d, double occ, int alp)
     d2.accumulate_transform(vector, occ);
     if (debug_ > 2) {
       d2.print("d2 density");
-      ExEnv::out() << node0 << indent << "d2 Nelectron = "
+      ExEnv::out0() << indent << "d2 Nelectron = "
                    << 2.0 * (d2 * overlap()).trace() << endl;
     }
     if (use_alternate_density) {
       d.assign(d2);
-      ExEnv::out() << node0 << indent
+      ExEnv::out0() << indent
                    << "using alternate density algorithm" << endl;
     }
   }
@@ -675,7 +697,7 @@ SCF::one_body_energy()
 void
 SCF::two_body_energy(double &ec, double &ex)
 {
-  ExEnv::err() << class_name() << ": two_body_energy not implemented" << endl;
+  ExEnv::errn() << class_name() << ": two_body_energy not implemented" << endl;
 }
 
 /////////////////////////////////////////////////////////////////////////////
@@ -684,7 +706,7 @@ void
 SCF::init_threads()
 {
   int nthread = threadgrp_->nthread();
-  int int_store = integral()->storage_unused()/nthread;
+  size_t int_store = integral()->storage_unused()/nthread;
   
   // initialize the two electron integral classes
   tbis_ = new Ref<TwoBodyInt>[nthread];
@@ -709,7 +731,7 @@ SCF::read_occ(const Ref<KeyVal> &keyval, const char *name, int nirrep)
   int *occ = 0;
   if (keyval->exists(name)) {
     if (keyval->count(name) != nirrep) {
-      ExEnv::err() << node0 << indent
+      ExEnv::err0() << indent
                    << "ERROR: SCF: have " << nirrep << " irreps but "
                    << name << " vector is length " << keyval->count(name)
                    << endl;
@@ -723,6 +745,13 @@ SCF::read_occ(const Ref<KeyVal> &keyval, const char *name, int nirrep)
   return occ;
 }
 
+void
+SCF::obsolete()
+{
+  OneBodyWavefunction::obsolete();
+  if (guess_wfn_.nonnull()) guess_wfn_->obsolete();
+}
+
 /////////////////////////////////////////////////////////////////////////////
 
 // Local Variables:
