@@ -31,7 +31,9 @@
 
 #include <math.h>
 #include <limits.h>
+#include <sys/types.h>
 #include <sys/stat.h>
+#include <unistd.h>
 
 #include <util/state/stateio.h>
 
@@ -57,6 +59,9 @@
 #include <chemistry/qc/scf/uhftmpl.h>
 
 using namespace std;
+using namespace sc;
+
+namespace sc {
 
 ///////////////////////////////////////////////////////////////////////////
 // UnrestrictedSCF
@@ -151,7 +156,7 @@ UnrestrictedSCF::UnrestrictedSCF(const Ref<KeyVal>& keyval) :
   if (keyval->exists("multiplicity")) {
     int mult = keyval->intvalue("multiplicity");
     if (mult < 1) {
-      ExEnv::err() << node0 << endl << indent
+      ExEnv::err0() << endl << indent
            << "USCF::init: bad value for multiplicity: " << mult << endl
            << indent << "assuming singlet" << endl;
       mult=1;
@@ -160,7 +165,7 @@ UnrestrictedSCF::UnrestrictedSCF(const Ref<KeyVal>& keyval) :
     // for singlet, triplet, etc. we need an even number of electrons
     // for doublet, quartet, etc. we need an odd number of electrons
     if ((mult%2 && nelectrons%2) || (!(mult%2) && !(nelectrons%2))) {
-      ExEnv::err() << node0 << endl << indent
+      ExEnv::err0() << endl << indent
            << "USCF::init: Warning, there's a leftover electron..."
            << " I'm going to get rid of it" << endl
            << incindent << indent << "total_charge = " << charge << endl
@@ -181,7 +186,7 @@ UnrestrictedSCF::UnrestrictedSCF(const Ref<KeyVal>& keyval) :
 
   tnbeta_ = nelectrons-tnalpha_;
   
-  ExEnv::out() << node0 << endl << indent
+  ExEnv::out0() << endl << indent
        << "USCF::init: total charge = " << Znuc-tnalpha_-tnbeta_
        << endl << endl;
 
@@ -203,7 +208,7 @@ UnrestrictedSCF::UnrestrictedSCF(const Ref<KeyVal>& keyval) :
     memcpy(initial_nbeta_, nbeta_, sizeof(int)*nirrep_);
   }
   else if (nalpha_ && !nbeta_ || !nalpha_ && nbeta_) {
-    ExEnv::out() << "ERROR: USCF: only one of alpha and beta specified: "
+    ExEnv::out0() << "ERROR: USCF: only one of alpha and beta specified: "
                  << "give both or none" << endl;
     abort();
   }
@@ -216,15 +221,15 @@ UnrestrictedSCF::UnrestrictedSCF(const Ref<KeyVal>& keyval) :
     set_occupations(0,0);
   }
 
-  ExEnv::out() << node0 << indent << "alpha = [";
+  ExEnv::out0() << indent << "alpha = [";
   for (i=0; i < nirrep_; i++)
-    ExEnv::out() << node0 << " " << nalpha_[i];
-  ExEnv::out() << node0 << " ]\n";
+    ExEnv::out0() << " " << nalpha_[i];
+  ExEnv::out0() << " ]\n";
 
-  ExEnv::out() << node0 << indent << "beta  = [";
+  ExEnv::out0() << indent << "beta  = [";
   for (i=0; i < nirrep_; i++)
-    ExEnv::out() << node0 << " " << nbeta_[i];
-  ExEnv::out() << node0 << " ]\n";
+    ExEnv::out0() << " " << nbeta_[i];
+  ExEnv::out0() << " ]\n";
 
   // check to see if this was done in SCF(keyval)
   if (!keyval->exists("maxiter"))
@@ -369,7 +374,7 @@ RefSymmSCMatrix
 UnrestrictedSCF::fock(int n)
 {
   if (n > 1) {
-    ExEnv::err() << node0 << indent
+    ExEnv::err0() << indent
          << "USCF::fock: there are only two fock matrices, "
          << scprintf("but fock(%d) was requested\n",n);
     abort();
@@ -387,7 +392,7 @@ UnrestrictedSCF::print(ostream&o) const
   int i;
 
   SCF::print(o);
-  o << node0 << indent << "UnrestrictedSCF Parameters:\n" << incindent
+  o << indent << "UnrestrictedSCF Parameters:\n" << incindent
     << indent << "charge = " << molecule()->nuclear_charge()
                                 - tnalpha_ - tnbeta_ << endl
     << indent << "nalpha = " << tnalpha_ << endl
@@ -395,13 +400,13 @@ UnrestrictedSCF::print(ostream&o) const
     << indent << "alpha = [";
 
   for (i=0; i < nirrep_; i++)
-    o << node0 << " " << nalpha_[i];
-  o << node0 << " ]" << endl;
+    o << " " << nalpha_[i];
+  o << " ]" << endl;
 
-  o << node0 << indent << "beta  = [";
+  o << indent << "beta  = [";
   for (i=0; i < nirrep_; i++)
-    o << node0 << " " << nbeta_[i];
-  o << node0 << " ]" << endl << decindent << endl;
+    o << " " << nbeta_[i];
+  o << " ]" << endl << decindent << endl;
 }
 
 //////////////////////////////////////////////////////////////////////////////
@@ -410,7 +415,7 @@ void
 UnrestrictedSCF::initial_vector(int needv)
 {
   if (need_vec_) {
-    if (oso_eigenvectors_.result_noupdate().null()) {
+    if (always_use_guess_wfn_ || oso_eigenvectors_.result_noupdate().null()) {
       // if guess_wfn_ is non-null then try to get a guess vector from it.
       // First check that the same basis is used...if not, then project the
       // guess vector into the present basis.
@@ -418,11 +423,11 @@ UnrestrictedSCF::initial_vector(int needv)
       // GaussianBasisSet
       if (guess_wfn_.nonnull()) {
         if (guess_wfn_->basis()->nbasis() == basis()->nbasis()) {
-          ExEnv::out() << node0 << indent
+          ExEnv::out0() << indent
                << "Using guess wavefunction as starting vector" << endl;
 
           // indent output of eigenvectors() call if there is any
-          ExEnv::out() << incindent << incindent;
+          ExEnv::out0() << incindent << incindent;
           UnrestrictedSCF *ug =
             dynamic_cast<UnrestrictedSCF*>(guess_wfn_.pointer());
           if (!ug || compute_guess_) {
@@ -437,29 +442,29 @@ UnrestrictedSCF::initial_vector(int needv)
               = ug->oso_eigenvectors_beta_.result_noupdate().copy();
             eigenvalues_beta_ = ug->eigenvalues_beta_.result_noupdate().copy();
           }
-          ExEnv::out() << decindent << decindent;
+          ExEnv::out0() << decindent << decindent;
         } else {
-          ExEnv::out() << node0 << indent
+          ExEnv::out0() << indent
                << "Projecting guess wavefunction into the present basis set"
                << endl;
 
           // indent output of projected_eigenvectors() call if there is any
-          ExEnv::out() << incindent << incindent;
+          ExEnv::out0() << incindent << incindent;
           oso_eigenvectors_ = projected_eigenvectors(guess_wfn_, 1);
           eigenvalues_ = projected_eigenvalues(guess_wfn_, 1);
           oso_eigenvectors_beta_ = projected_eigenvectors(guess_wfn_, 0);
           eigenvalues_beta_ = projected_eigenvalues(guess_wfn_, 0);
-          ExEnv::out() << decindent << decindent;
+          ExEnv::out0() << decindent << decindent;
         }
 
         // we should only have to do this once, so free up memory used
         // for the old wavefunction, unless told otherwise
         if (!keep_guess_wfn_) guess_wfn_=0;
 
-        ExEnv::out() << node0 << endl;
+        ExEnv::out0() << endl;
       
       } else {
-        ExEnv::out() << node0 << indent << "Starting from core Hamiltonian guess\n"
+        ExEnv::out0() << indent << "Starting from core Hamiltonian guess\n"
              << endl;
         oso_eigenvectors_ = hcore_guess(eigenvalues_.result_noupdate());
         oso_eigenvectors_beta_ = oso_eigenvectors_.result_noupdate().copy();
@@ -491,7 +496,7 @@ UnrestrictedSCF::set_occupations(const RefDiagSCMatrix& eva,
       most_recent_pg_ = new PointGroup(molecule()->point_group());
       return;
     }
-    ExEnv::out() << node0 << indent
+    ExEnv::out0() << indent
          << "UnrestrictedSCF: WARNING: reforming occupation vector from scratch" << endl;
   }
   
@@ -616,7 +621,7 @@ UnrestrictedSCF::set_occupations(const RefDiagSCMatrix& eva,
     // test to see if newocc is different from nalpha_
     for (i=0; i < nirrep_; i++) {
       if (nalpha_[i] != newalpha[i]) {
-        ExEnv::err() << node0 << indent << "UnrestrictedSCF::set_occupations:  WARNING!!!!\n"
+        ExEnv::err0() << indent << "UnrestrictedSCF::set_occupations:  WARNING!!!!\n"
              << incindent << indent
              << scprintf("occupations for irrep %d have changed\n",i+1)
              << indent
@@ -624,7 +629,7 @@ UnrestrictedSCF::set_occupations(const RefDiagSCMatrix& eva,
              << endl << decindent;
       }
       if (nbeta_[i] != newbeta[i]) {
-        ExEnv::err() << node0 << indent << "UnrestrictedSCF::set_occupations:  WARNING!!!!\n"
+        ExEnv::err0() << indent << "UnrestrictedSCF::set_occupations:  WARNING!!!!\n"
              << incindent << indent
              << scprintf("occupations for irrep %d have changed\n",i+1)
              << indent
@@ -941,7 +946,7 @@ UnrestrictedSCF::compute_vector(double& eelec)
   tim_enter("vector");
   int i;
 
-  // reinitialize the extrapolation object
+    // reinitialize the extrapolation object
   extrap_->reinitialize();
   
   // create level shifter
@@ -961,7 +966,7 @@ UnrestrictedSCF::compute_vector(double& eelec)
   
   // calculate the nuclear repulsion energy
   double nucrep = molecule()->nuclear_repulsion_energy();
-  ExEnv::out() << node0 << indent
+  ExEnv::out0() << indent
        << scprintf("nuclear repulsion energy = %15.10f", nucrep)
        << endl << endl;
 
@@ -970,6 +975,7 @@ UnrestrictedSCF::compute_vector(double& eelec)
 
   double delta = 1.0;
   int iter;
+  
   for (iter=0; iter < maxiter_; iter++) {
     // form the density from the current vector 
     tim_enter("density");
@@ -993,7 +999,7 @@ UnrestrictedSCF::compute_vector(double& eelec)
 
     // calculate the electronic energy
     eelec = scf_energy();
-    ExEnv::out() << node0 << indent
+    ExEnv::out0() << indent
          << scprintf("iter %5d energy = %15.10f delta = %10.5e",
                      iter+1, eelec+nucrep, delta)
          << endl;
@@ -1059,7 +1065,8 @@ UnrestrictedSCF::compute_vector(double& eelec)
     if (reset_occ_)
       set_occupations(evalsa, evalsb);
 
-  }
+    savestate_iter(iter);
+    }
       
   eigenvalues_ = evalsa;
   eigenvalues_.computed() = 1;
@@ -1102,7 +1109,7 @@ UnrestrictedSCF::compute_vector(double& eelec)
     S2real = S2real*(S2real+1);
     double S2 = S2real + tnbeta_ - s2;
 
-    ExEnv::out() << node0 << endl
+    ExEnv::out0() << endl
          << indent << scprintf("<S^2>exact = %f", S2real) << endl
          << indent << scprintf("<S^2>      = %f", S2) << endl;
   }
@@ -1263,7 +1270,7 @@ UnrestrictedSCF::two_body_deriv_hf(double * tbgrad, double exchange_fraction)
 
     if (threadgrp_->start_threads() < 0
         ||threadgrp_->wait_threads() < 0) {
-      ExEnv::err() << node0 << indent
+      ExEnv::err0() << indent
            << "USCF: error running threads" << endl;
       abort();
     }
@@ -1281,7 +1288,7 @@ UnrestrictedSCF::two_body_deriv_hf(double * tbgrad, double exchange_fraction)
 
   // for now quit
   else {
-    ExEnv::err() << node0 << indent
+    ExEnv::err0() << indent
          << "USCF::two_body_deriv_hf: can't do gradient yet\n";
     abort();
   }
@@ -1289,6 +1296,8 @@ UnrestrictedSCF::two_body_deriv_hf(double * tbgrad, double exchange_fraction)
 
 //////////////////////////////////////////////////////////////////////////////
 
+}
+
 // Local Variables:
 // mode: c++
 // c-file-style: "ETS"
