@@ -33,10 +33,16 @@
 #include <chemistry/qc/wfn/density.h>
 #include <chemistry/qc/wfn/orbital.h>
 #include <chemistry/qc/wfn/solvent.h>
+#include <chemistry/qc/wfn/eht.h>
+
+namespace sc {
 
 static ForceLink<ElectronDensity> wfn_force_link_a_;
 static ForceLink<Orbital> wfn_force_link_b_;
 static ForceLink<BEMSolventH> wfn_force_link_c_;
+static ForceLink<ExtendedHuckelWfn> wfn_force_link_d_;
+
+}
 
 #endif /* __PIC__ */
 
