@@ -37,6 +37,7 @@
 #include <math/isosurf/shape.h>
 
 using namespace std;
+using namespace sc;
 
 static const double shape_infinity = 1.0e23;
 
@@ -89,7 +90,7 @@ Shape::compute()
   get_x(r);
   if (gradient_needed()) {
       if (!gradient_implemented()) {
-          ExEnv::err() << "Shape::compute: gradient not implemented" << endl;
+          ExEnv::errn() << "Shape::compute: gradient not implemented" << endl;
           abort();
         }
       SCVector3 v;
@@ -103,7 +104,7 @@ Shape::compute()
       set_actual_value_accuracy(desired_value_accuracy());
     }
   if (hessian_needed()) {
-      ExEnv::err() << "Shape::compute(): can't do hessian yet" << endl;
+      ExEnv::errn() << "Shape::compute(): can't do hessian yet" << endl;
       abort();
     }
 }
@@ -208,7 +209,7 @@ SphereShape::SphereShape(const SphereShape&s):
 }
 
 SphereShape::SphereShape(const Ref<KeyVal>& keyval):
-  _origin(new PrefixKeyVal("origin",keyval)),
+  _origin(new PrefixKeyVal(keyval,"origin")),
   _radius(keyval->doublevalue("radius"))
 {
 }
@@ -361,9 +362,9 @@ UncappedTorusHoleShape::in_plane_sphere(
     }
 
   U_perp.normalize();
-  //ExEnv::out() << "A: "; A.print();
-  //ExEnv::out() << "U_perp: "; U_perp.print();
-  //ExEnv::out() << "R_AB: "; R_AB.print();
+  //ExEnv::outn() << "A: "; A.print();
+  //ExEnv::outn() << "U_perp: "; U_perp.print();
+  //ExEnv::outn() << "R_AB: "; R_AB.print();
 
   double r_AB = sqrt(R_AB.dot(R_AB));
   double r_A = _s1.radius();
@@ -374,12 +375,12 @@ UncappedTorusHoleShape::in_plane_sphere(
   double a = ((r_Ar*r_Ar - r_Br*r_Br)/(2.0*r_AB*r_AB)) + 0.5;
   double b = sqrt(r_Ar*r_Ar - a*a*r_AB*r_AB);
 
-  //ExEnv::out() << scprintf("r_Ar = %f, r_AB = %f\n",r_Ar,r_AB);
-  //ExEnv::out() << scprintf("a = %f, b = %f\n",a,b);
+  //ExEnv::outn() << scprintf("r_Ar = %f, r_AB = %f\n",r_Ar,r_AB);
+  //ExEnv::outn() << scprintf("a = %f, b = %f\n",a,b);
 
   P = A + a * R_AB + b * U_perp;
-  //ExEnv::out() << "a*R_AB: "; (a*R_AB).print();
-  //ExEnv::out() << "b*U_perp: "; (b*U_perp).print();
+  //ExEnv::outn() << "a*R_AB: "; (a*R_AB).print();
+  //ExEnv::outn() << "b*U_perp: "; (b*U_perp).print();
 }
 
 void
@@ -487,7 +488,7 @@ ReentrantUncappedTorusHoleShape::ReentrantUncappedTorusHoleShape(double r,
       sb2m4ac = 0.0;
     }
   else {
-      ExEnv::err() << "ReentrantUncappedTorusHoleShape:: imaginary point" << endl;
+      ExEnv::errn() << "ReentrantUncappedTorusHoleShape:: imaginary point" << endl;
       abort();
     }
   double zA = (minus_b - sb2m4ac)/(2.0*a);
@@ -695,13 +696,13 @@ Uncapped5SphereExclusionShape::
   double h = sqrt(h2);
   if (h<r()) {
       _reentrant = 1;
-      //ExEnv::out() << "WARNING: throwing out reentrant shape" << endl;
+      //ExEnv::outn() << "WARNING: throwing out reentrant shape" << endl;
       //_solution_exists = 0;
       //return;
     }
   else {
       _reentrant = 0;
-      //ExEnv::out() << "WARNING: throwing out nonreentrant shape" << endl;
+      //ExEnv::outn() << "WARNING: throwing out nonreentrant shape" << endl;
       //_solution_exists = 0;
       //return;
     }
@@ -737,7 +738,7 @@ Uncapped5SphereExclusionShape::
     }
   else _folded = 0;
   
-  //ExEnv::out() << scprintf("r = %14.8f, h = %14.8f\n",r(),h);
+  //ExEnv::outn() << scprintf("r = %14.8f, h = %14.8f\n",r(),h);
   //M.print();
   //D[0].print();
   //D[1].print();
@@ -840,7 +841,7 @@ Uncapped5SphereExclusionShape::
     }
 
 #if 0 // test code
-  ExEnv::out() << "Uncapped5SphereExclusionShape: running some tests" << endl;
+  ExEnv::outn() << "Uncapped5SphereExclusionShape: running some tests" << endl;
   verbose = 1;
 
   FILE* testout = fopen("testout.vect", "w");
@@ -872,14 +873,14 @@ Uncapped5SphereExclusionShape::
   for (ii = 0; ii<nvert; ii++) {
       SCVector3 position = (D[0] - middle) * scalefactor + middle;
       double d = distance_to_surface(position);
-      ExEnv::out() << scprintf("d = %f\n", d);
+      ExEnv::outn() << scprintf("d = %f\n", d);
       if (d<0.0) fprintf(testout,"1.0 0.0 0.0 0.5\n");
       else fprintf(testout,"0.0 0.0 1.0 0.5\n");
       scalefactor += scalefactor_inc;
     }
 
   fclose(testout);
-  ExEnv::out() << "testout.vect written" << endl;
+  ExEnv::outn() << "testout.vect written" << endl;
 
   verbose = 0;
 #endif // test code
@@ -890,7 +891,7 @@ Uncapped5SphereExclusionShape::is_outside(const SCVector3&X) const
 {
   SCVector3 Xv(X);
 
-  if (verbose) ExEnv::out() << scprintf("point %14.8f %14.8f %14.8f\n",X(0),X(1),X(2));
+  if (verbose) ExEnv::outn() << scprintf("point %14.8f %14.8f %14.8f\n",X(0),X(1),X(2));
 
   // The folded case isn't handled correctly here, so use
   // the less efficient distance_to_surface routine.
@@ -910,7 +911,7 @@ Uncapped5SphereExclusionShape::is_outside(const SCVector3&X) const
       if (w <= 0.0) return 1;
     }
 
-  if (verbose) ExEnv::out() << "is_inside" << endl;
+  if (verbose) ExEnv::outn() << "is_inside" << endl;
 
   return 0;
 }
@@ -944,25 +945,25 @@ Uncapped5SphereExclusionShape::
   else side = 0;
 
   if (verbose) {
-      ExEnv::out() << scprintf("distance_to_surface: folded = %d, side = %d\n",
+      ExEnv::outn() << scprintf("distance_to_surface: folded = %d, side = %d\n",
                        _folded, side);
-      ExEnv::out() << "XM = "; XM.print();
-      ExEnv::out() << "MD[0] = "; MD[0].print();
-      ExEnv::out() << "MD[0].dot(XM) = " << MD[0].dot(XM) << endl;
+      ExEnv::outn() << "XM = "; XM.print();
+      ExEnv::outn() << "MD[0] = "; MD[0].print();
+      ExEnv::outn() << "MD[0].dot(XM) = " << MD[0].dot(XM) << endl;
     }
 
   SCVector3 XD = Xv - D[side];
   double u = BDxCD[side].dot(XD)/BDxCDdotAD[side];
-  if (verbose) ExEnv::out() << scprintf("u = %14.8f\n", u);
+  if (verbose) ExEnv::outn() << scprintf("u = %14.8f\n", u);
   if (u <= 0.0) return shape_infinity;
   double v = CDxAD[side].dot(XD)/CDxADdotBD[side];
-  if (verbose) ExEnv::out() << scprintf("v = %14.8f\n", v);
+  if (verbose) ExEnv::outn() << scprintf("v = %14.8f\n", v);
   if (v <= 0.0) return shape_infinity;
   double w = ADxBD[side].dot(XD)/ADxBDdotCD[side];
-  if (verbose) ExEnv::out() << scprintf("w = %14.8f\n", w);
+  if (verbose) ExEnv::outn() << scprintf("w = %14.8f\n", w);
   if (w <= 0.0) return shape_infinity;
   double rXD = XD.norm();
-  if (verbose) ExEnv::out() << scprintf("r() - rXD = %14.8f\n", r() - rXD);
+  if (verbose) ExEnv::outn() << scprintf("r() - rXD = %14.8f\n", r() - rXD);
   if (rXD <= r()) {
       if (!_reentrant) return r() - rXD;
       // this shape is reentrant
@@ -983,10 +984,10 @@ Uncapped5SphereExclusionShape::
                                                   MD[side],
                                                   IABD[side][0],
                                                   IABD[side][1])) {
-              //ExEnv::out() << scprintf("XD: "); XD.print();
-              //ExEnv::out() << scprintf("MD[%d]: ",i); MD[i].print();
-              //ExEnv::out() << scprintf("IABD[%d][0]: ",i); IABD[i][0].print();
-              //ExEnv::out() << scprintf("IABD[%d][1]: ",i); IABD[i][1].print();
+              //ExEnv::outn() << scprintf("XD: "); XD.print();
+              //ExEnv::outn() << scprintf("MD[%d]: ",i); MD[i].print();
+              //ExEnv::outn() << scprintf("IABD[%d][0]: ",i); IABD[i][0].print();
+              //ExEnv::outn() << scprintf("IABD[%d][1]: ",i); IABD[i][1].print();
               return closest_distance(XD,(SCVector3*)IABD[side],2,grad);
             }
           if (_intersects_BC
@@ -1043,7 +1044,7 @@ Uncapped5SphereExclusionShape::
         }
     }
 
-  if (verbose) ExEnv::out() << "returning -1.0" << endl;
+  if (verbose) ExEnv::outn() << "returning -1.0" << endl;
   return -1.0;
 }
 
@@ -1106,10 +1107,10 @@ UnionShape::add_shape(Ref<Shape> s)
 double
 UnionShape::distance_to_surface(const SCVector3&p,SCVector3* grad) const
 {
-  AVLSet<Ref<Shape> >::iterator imin = _shapes.begin();
+  std::set<Ref<Shape> >::const_iterator imin = _shapes.begin();
   if (imin == _shapes.end()) return 0.0;
   double min = (*imin)->distance_to_surface(p);
-  for (AVLSet<Ref<Shape> >::iterator i=imin; i!=_shapes.end(); i++) {
+  for (std::set<Ref<Shape> >::const_iterator i=imin; i!=_shapes.end(); i++) {
       double d = (*i)->distance_to_surface(p);
       if (min <= 0.0) {
           if (d < 0.0 && d > min) { min = d; imin = i; }
@@ -1128,7 +1129,8 @@ UnionShape::distance_to_surface(const SCVector3&p,SCVector3* grad) const
 int
 UnionShape::is_outside(const SCVector3&p) const
 {
-  for (AVLSet<Ref<Shape> >::iterator i=_shapes.begin(); i!=_shapes.end(); i++) {
+  for (std::set<Ref<Shape> >::const_iterator i=_shapes.begin();
+       i!=_shapes.end(); i++) {
       if (!(*i)->is_outside(p)) return 0;
     }
 
@@ -1148,7 +1150,7 @@ UnionShape::boundingbox(double valuemin, double valuemax,
   SCVector3 pt1;
   SCVector3 pt2;
   
-  AVLSet<Ref<Shape> >::iterator j = _shapes.begin();
+  std::set<Ref<Shape> >::iterator j = _shapes.begin();
   int i;
   (*j)->boundingbox(valuemin,valuemax,p1,p2);
   for (j++; j!=_shapes.end(); j++) {
@@ -1163,7 +1165,8 @@ UnionShape::boundingbox(double valuemin, double valuemax,
 int
 UnionShape::gradient_implemented() const
 {
-  for (AVLSet<Ref<Shape> >::iterator j=_shapes.begin(); j!=_shapes.end(); j++) {
+  for (std::set<Ref<Shape> >::const_iterator j=_shapes.begin();
+       j!=_shapes.end(); j++) {
       if (!(*j)->gradient_implemented()) return 0;
     }
   return 1;
