@@ -37,6 +37,7 @@
 #include <math/scmat/elemop.h>
 
 using namespace std;
+using namespace sc;
 
 /////////////////////////////////////////////////////////////////////////////
 // SCMatrixBlock member functions
@@ -71,7 +72,7 @@ SCMatrixBlock::~SCMatrixBlock()
 SCMatrixBlock *
 SCMatrixBlock::deepcopy() const
 {
-  ExEnv::err() << "SCMatrixBlock of type " << class_name()
+  ExEnv::errn() << "SCMatrixBlock of type " << class_name()
        << " cannot be deep copied" << endl;
   abort();
   return 0;
@@ -80,7 +81,7 @@ SCMatrixBlock::deepcopy() const
 double *
 SCMatrixBlock::dat()
 {
-  ExEnv::err() << "SCMatrixBlock of type " << class_name()
+  ExEnv::errn() << "SCMatrixBlock of type " << class_name()
        << " cannot provide internal data" << endl;
   abort();
   return 0;
@@ -89,7 +90,7 @@ SCMatrixBlock::dat()
 int
 SCMatrixBlock::ndat() const
 {
-  ExEnv::err() << "SCMatrixBlock of type " << class_name()
+  ExEnv::errn() << "SCMatrixBlock of type " << class_name()
        << " cannot provide size of internal data" << endl;
   abort();
   return 0;
@@ -964,7 +965,7 @@ SCMatrixCompositeSubblockIter::SCMatrixCompositeSubblockIter(
   if (niters_) access_ = iters_[0]->access();
   for (int i=0; i<niters_; i++) {
       if (iters_[i]->access() != access_) {
-          ExEnv::err() << "SCMatrixCompositeSubblockIter: access not compatible"
+          ExEnv::errn() << "SCMatrixCompositeSubblockIter: access not compatible"
                << endl;
           abort();
         }
@@ -991,7 +992,7 @@ SCMatrixCompositeSubblockIter::set_iter(int i,
 {
   iters_[i] = iter;
   if (iters_[i]->access() != access_) {
-      ExEnv::err() << "SCMatrixCompositeSubblockIter: access not compatible"
+      ExEnv::errn() << "SCMatrixCompositeSubblockIter: access not compatible"
            << endl;
       abort();
     }
@@ -1089,7 +1090,7 @@ SCMatrixJointSubblockIter::ready()
   else if (!nready)
     return 0;
 
-  ExEnv::err() << "SCMatrixJointSubblockIter: incompatible iterators" << endl;
+  ExEnv::errn() << "SCMatrixJointSubblockIter: incompatible iterators" << endl;
   abort();
   return 0;
 }
