@@ -3,7 +3,6 @@
 
 #include <math.h>
 
-#include <util/misc/libmisc.h>
 #include <util/group/message.h>
 
 #include <math/scmat/disthql.h>
@@ -12,6 +11,7 @@
 #include <math/scmat/f77sym.h>
 
 using namespace std;
+using namespace sc;
 
 extern "C" {
   void F77_PDSTEQR(int *n, double *d, double *e,
@@ -19,6 +19,8 @@ extern "C" {
                 int *info);
 }
 
+namespace sc {
+
 static void dist_diagonalize_(int n, int m, double *a, double *d, double *e,
                               double *sigma, double *z, double *v, double *w,
                               int *ind, const Ref<MessageGrp>&);
@@ -109,7 +111,7 @@ dist_diagonalize_(int n, int m, double *a, double *d, double *e,
 #if 0
   pimtql2_(d,e,&n,z,&m,&info);
   if (info != 0) {
-      ExEnv::out() << "dist_diagonalize: node "
+      ExEnv::outn() << "dist_diagonalize: node "
            << grp->me() << ": nonzero ierr from pimtql2" << endl;
       abort();
     }
@@ -658,3 +660,5 @@ ptred_parallel(double *a, int *lda, int *n, int *m, int *p, int *id,
   grp->sum(d, sn, work);
   grp->sum(e, sn, work);
   }
+
+}
