@@ -29,6 +29,8 @@
 #pragma implementation
 #endif
 
+#include <stdexcept>
+
 #include <stdlib.h>
 #include <math.h>
 
@@ -39,6 +41,8 @@
 #include <math/scmat/elemop.h>
 #include <math/scmat/abstract.h>
 
+using namespace sc;
+
 /////////////////////////////////////////////////////////////////////////////
 // SCElementOp member functions
 
@@ -76,6 +80,31 @@ SCElementOp::collect(const Ref<MessageGrp>&)
 {
 }
 
+bool
+SCElementOp::threadsafe()
+{
+  return false;
+}
+
+bool
+SCElementOp::cloneable()
+{
+  return false;
+}
+
+Ref<SCElementOp>
+SCElementOp::clone()
+{
+  throw std::runtime_error("SCElementOp::clone: not implemented");
+}
+
+void
+SCElementOp::collect(const Ref<SCElementOp> &)
+{
+  throw std::runtime_error("SCElementOp::collect(const Ref<SCElementOp> &): "
+                           "not implemented");
+}
+
 void
 SCElementOp::process_base(SCMatrixBlock* a)
 {
@@ -893,14 +922,14 @@ SCElementDot::SCElementDot(double**a, double**b, int n):
 
 SCElementDot::SCElementDot(StateIn&s)
 {
-  ExEnv::err() << indent << "SCElementDot does not permit StateIn CTOR\n";
+  ExEnv::errn() << indent << "SCElementDot does not permit StateIn CTOR\n";
   abort();
 }
 
 void
 SCElementDot::save_data_state(StateOut&s)
 {
-  ExEnv::err() << indent << "SCElementDot does not permit save_data_state\n";
+  ExEnv::errn() << indent << "SCElementDot does not permit save_data_state\n";
   abort();
 }
 
