@@ -32,10 +32,11 @@
 #endif
 
 #include <iostream>
-#include <util/container/array.h>
 
 #include <math/scmat/abstract.h>
 
+namespace sc {
+
 class SCVectordouble;
 class SCMatrixdouble;
 class SymmSCMatrixdouble;
@@ -119,7 +120,7 @@ class RefSCVector: public Ref<SCVector> {
                     const RefSCVector&) const;
     void print(std::ostream&out) const;
     void print(const char*title=0,
-               std::ostream&out=ExEnv::out(), int precision=10) const;
+               std::ostream&out=ExEnv::out0(), int precision=10) const;
     void save(StateOut&);
     void restore(StateIn&);
 };
@@ -222,7 +223,7 @@ class RefSCMatrix: public Ref<SCMatrix> {
     double get_element(int,int) const;
     void print(std::ostream&) const;
     void print(const char*title=0,
-               std::ostream&out=ExEnv::out(), int =10) const;
+               std::ostream&out=ExEnv::out0(), int =10) const;
     double trace() const;
     void save(StateOut&);
     void restore(StateIn&);
@@ -240,6 +241,15 @@ class RefSCMatrix: public Ref<SCMatrix> {
     double determ() const;
     /// Assign and examine matrix elements.
     SCMatrixdouble operator()(int i,int j) const;
+
+    /** If this matrix is blocked return the number of blocks.
+     * Otherwise return 1.
+     */
+    int nblock() const;
+    /** If this matrix is blocked return block i.
+     * Otherwise return this as block 0.
+     */
+    RefSCMatrix block(int i) const;
 };
 /// Allow multiplication with a scalar on the left.
 RefSCMatrix operator*(double,const RefSCMatrix&);
@@ -331,7 +341,7 @@ class RefSymmSCMatrix: public Ref<SymmSCMatrix> {
     Ref<SCMatrixKit> kit() const;
     void print(std::ostream&) const;
     void print(const char*title=0,
-               std::ostream&out=ExEnv::out(), int =10) const;
+               std::ostream&out=ExEnv::out0(), int =10) const;
     void save(StateOut&);
     void restore(StateIn&);
 
@@ -349,6 +359,14 @@ class RefSymmSCMatrix: public Ref<SymmSCMatrix> {
                      const RefSCMatrix& eigvecs) const;
     /// Assign and examine matrix elements.
     SymmSCMatrixdouble operator()(int i,int j) const;
+    /** If this matrix is blocked return the number of blocks.
+     * Otherwise return 1.
+     */
+    int nblock() const;
+    /** If this matrix is blocked return block i.
+     * Otherwise return this as block 0.
+     */
+    RefSymmSCMatrix block(int i) const;
 };
 /// Allow multiplication with a scalar on the left.
 RefSymmSCMatrix operator*(double,const RefSymmSCMatrix&);
@@ -412,13 +430,21 @@ class RefDiagSCMatrix: public Ref<DiagSCMatrix> {
     double trace() const;
     void print(std::ostream&) const;
     void print(const char*title=0,
-               std::ostream&out=ExEnv::out(), int =10) const;
+               std::ostream&out=ExEnv::out0(), int =10) const;
     void save(StateOut&);
     void restore(StateIn&);
     /// Returns the determinant of the referenced matrix.
     double determ() const;
     /// Assign and examine matrix elements.
     DiagSCMatrixdouble operator()(int i) const;
+    /** If this matrix is blocked return the number of blocks.
+     * Otherwise return 1.
+     */
+    int nblock() const;
+    /** If this matrix is blocked return block i.
+     * Otherwise return this as block 0.
+     */
+    RefDiagSCMatrix block(int i) const;
 };
 /// Allow multiplication with a scalar on the left.
 RefDiagSCMatrix operator*(double,const RefDiagSCMatrix&);
@@ -490,6 +516,8 @@ class DiagSCMatrixdouble {
     double val() const;
 };
 
+}
+
 #ifdef INLINE_FUNCTIONS
 #include <math/scmat/matrix_i.h>
 #endif
