@@ -39,15 +39,17 @@ class SSBArray2: public Array2<Type> {
     SSBArray2(Type* data,int size0,int size1): Array2<Type>(data,size0,size1){}
     SSBArray2(int size0,int size1): Array2<Type>(size0,size1) {}
     SSBArray2(StateIn&s) {
-        s.get(_length0);
-        s.get(_length1);
-        if (_length0&&_length1) s.get(_array);
-        _managed=1;
+        s.get(this->_length0);
+        s.get(this->_length1);
+        if (this->_length0&&this->_length1) s.get(this->_array);
+        this->_managed=1;
       }
     void save_object_state(StateOut&s) {
-        s.put(_length0);
-        s.put(_length1);
-        if (_length0&&_length1) s.put(_array,_length0*_length1);
+        s.put(this->_length0);
+        s.put(this->_length1);
+        if (this->_length0&&this->_length1) {
+            s.put(this->_array,this->_length0*this->_length1);
+          }
       }
 };
 
