@@ -32,37 +32,17 @@
 #endif
 
 #include <iostream>
+#include <string>
+#include <map>
+
 #include <string.h>
 #include <stdlib.h>
 #include <stdarg.h>
 
-#include <util/container/avlmap.h>
 #include <util/class/class.h>
 #include <util/keyval/keyvalval.h>
 
-class KeyValKeyword {
-  private:
-    char* keyword_;
-  public:
-    KeyValKeyword();
-    KeyValKeyword(const char* name);
-    KeyValKeyword(const KeyValKeyword&);
-    ~KeyValKeyword();
-    KeyValKeyword& operator=(const KeyValKeyword&);
-    int operator==(const KeyValKeyword& ck) const;
-    int operator<(const KeyValKeyword& ck) const;
-    int hash() const;
-    inline int cmp(const KeyValKeyword&ck) const
-    {
-      if (!keyword_) {
-          if (!ck.keyword_) return 0;
-          return -1;
-        }
-      if (!ck.keyword_) return 1;
-      return strcmp(keyword_,ck.keyword_);
-    }
-    inline const char* name() const {return keyword_;}
-  };
+namespace sc {
 
 /**
  The KeyVal class is designed to simplify the process of allowing
@@ -126,8 +106,13 @@ class KeyVal: public RefCount {
     virtual char   key_charvalue(const char* key,const KeyValValue& def);
     /// Ultimately called by intvalue.
     virtual int    key_intvalue(const char* key,const KeyValValue& def);
+    /// Ultimately called by sizevalue.
+    virtual size_t key_sizevalue(const char* key,const KeyValValue& def);
     /// Ultimately called by pcharvalue.
     virtual char*  key_pcharvalue(const char* key,const KeyValValue& def);
+    /// Ultimately called by stringvalue.
+    virtual std::string key_stringvalue(const char* key,
+                                        const KeyValValue& def);
     /// Ultimately called by describedclassvalue.
     virtual Ref<DescribedClass> key_describedclassvalue(const char* key,
                                                       const KeyValValue& def);
@@ -165,29 +150,45 @@ class KeyVal: public RefCount {
     /// Returns the int value of key.
     int    intvalue(const char* key = 0,
                     const KeyValValue& def=KeyValValueint());
+    /// Returns the size_t value of key.
+    size_t sizevalue(const char* key = 0,
+                     const KeyValValue& def=KeyValValuesize());
     /** Returns a copy of the string representation of the key's
         value. Storage for the copy is obtained with new. */
     char*  pcharvalue(const char* key = 0,
                       const KeyValValue& def=KeyValValuepchar());
+    /** Returns a string representation of the key's value. */
+    std::string stringvalue(const char* key = 0,
+                            const KeyValValue& def=KeyValValuestring());
     /// Returns a reference to an object of type DescribedClass.
     Ref<DescribedClass> describedclassvalue(const char* key = 0,
                      const KeyValValue& def=KeyValValueRefDescribedClass());
 
-    // For vectors:
-    int    exists(const char*,int);
-    int    count(const char*,int);
-    int    booleanvalue(const char*,int,
+    /** These members correspond to the above members, but take
+        an additional integer argument, i, which is a vector index.
+        This is equivalent to getting a value for a keyword named
+        "<i>key</i>:<i>i</i>".  The routines that do not take
+        key arguments get the value for the keyword named "<i>i</i>".
+     */
+    //@{
+    int    exists(const char* key,int i);
+    int    count(const char* key,int i);
+    int    booleanvalue(const char* key,int i,
                         const KeyValValue& def=KeyValValueboolean());
-    double doublevalue(const char* key,int,
+    double doublevalue(const char* key,int i,
                        const KeyValValue& def=KeyValValuedouble());
-    float  floatvalue(const char* key,int,
+    float  floatvalue(const char* key,int i,
                       const KeyValValue& def=KeyValValuefloat());
-    char   charvalue(const char* key,int,
+    char   charvalue(const char* key,int i,
                      const KeyValValue& def=KeyValValuechar());
-    int    intvalue(const char* key,int,
+    int    intvalue(const char* key,int i,
                     const KeyValValue& def=KeyValValueint());
-    char*  pcharvalue(const char* key,int,
+    size_t sizevalue(const char* key,int i,
+                     const KeyValValue& def=KeyValValuesize());
+    char*  pcharvalue(const char* key,int i,
                       const KeyValValue& def=KeyValValuepchar());
+    std::string stringvalue(const char* key,int i,
+                            const KeyValValue& def=KeyValValuestring());
     Ref<DescribedClass> describedclassvalue(const char* key,int,
                      const KeyValValue& def=KeyValValueRefDescribedClass());
 
@@ -203,12 +204,22 @@ class KeyVal: public RefCount {
                      const KeyValValue& def=KeyValValuechar());
     int    intvalue(int i,
                     const KeyValValue& def=KeyValValueint());
+    size_t sizevalue(int i,
+                     const KeyValValue& def=KeyValValuesize());
     char*  pcharvalue(int i,
                       const KeyValValue& def=KeyValValuepchar());
+    std::string stringvalue(int i,
+                            const KeyValValue& def=KeyValValuestring());
     Ref<DescribedClass> describedclassvalue(int i,
                      const KeyValValue& def=KeyValValueRefDescribedClass());
+    //@}
 
-    // For arrays:
+    /** These members correspond to the above members, but take additional
+        integer arguments, i and j, which is an array index.  This is
+        equivalent to getting a value for a keyword named
+        "<i>key</i>:<i>i</i>:<i>j</i>".  The routines that do not take key
+        arguments get the value for the keyword named "<i>i</i>:<i>j</i>".  */
+    //@{
     int    exists(const char*,int,int);
     int    count(const char*,int,int);
     int    booleanvalue(const char*,int,int,
@@ -221,8 +232,12 @@ class KeyVal: public RefCount {
                      const KeyValValue& def=KeyValValuechar());
     int    intvalue(const char* key,int,int,
                     const KeyValValue& def=KeyValValueint());
+    size_t sizevalue(const char* key,int,int,
+                     const KeyValValue& def=KeyValValuesize());
     char*  pcharvalue(const char* key,int,int,
                       const KeyValValue& def=KeyValValuepchar());
+    std::string stringvalue(const char* key,int,int,
+                            const KeyValValue& def=KeyValValuestring());
     Ref<DescribedClass> describedclassvalue(const char* key,int,int,
                      const KeyValValue& def=KeyValValueRefDescribedClass());
 
@@ -238,21 +253,33 @@ class KeyVal: public RefCount {
                      const KeyValValue& def=KeyValValuechar());
     int    intvalue(int i,int j,
                     const KeyValValue& def=KeyValValueint());
+    size_t sizevalue(int i,int j,
+                     const KeyValValue& def=KeyValValuesize());
     char*  pcharvalue(int i,int j,
                       const KeyValValue& def=KeyValValuepchar());
+    std::string stringvalue(int i,int j,
+                            const KeyValValue& def=KeyValValuestring());
     Ref<DescribedClass> describedclassvalue(int i,int j,
                      const KeyValValue& def=KeyValValueRefDescribedClass());
+    //@}
 
-    // For all else:
-    int    Va_exists(const char*,int,...);
-    int    Va_count(const char*,int,...);
-    int    Va_booleanvalue(const char*,int,...);
-    double Va_doublevalue(const char* key,int,...);
-    float  Va_floatvalue(const char* key,int,...);
-    char   Va_charvalue(const char* key,int,...);
-    int    Va_intvalue(const char* key,int,...);
-    char*  Va_pcharvalue(const char* key,int,...);
-    Ref<DescribedClass> Va_describedclassvalue(const char* key,int,...);
+    /** These members correspond to the above members, but can be used
+        to read in arrays with more than two dimensions.  The nindex
+        argument is the number of indices in the array.  It is followed
+        by an int giving the value of each index.  */
+    //@{
+    int    Va_exists(const char* key,int nindex,...);
+    int    Va_count(const char* key,int nindex,...);
+    int    Va_booleanvalue(const char* key,int nindex,...);
+    double Va_doublevalue(const char* key,int nindex,...);
+    float  Va_floatvalue(const char* key,int nindex,...);
+    char   Va_charvalue(const char* key,int nindex,...);
+    int    Va_intvalue(const char* key,int nindex,...);
+    size_t Va_sizevalue(const char* key,int nindex,...);
+    char*  Va_pcharvalue(const char* key,int nindex,...);
+    std::string Va_stringvalue(const char* key,int nindex,...);
+    Ref<DescribedClass> Va_describedclassvalue(const char* key,int nindex,...);
+    //@}
 
     /// Return the current error condition.
     KeyValError error();
@@ -260,12 +287,13 @@ class KeyVal: public RefCount {
     const char*  errormsg(KeyValError err);
     /// Return a textual representation of the current error.
     const char*  errormsg();
-
-    virtual void errortrace(std::ostream&fp=ExEnv::err());
-    virtual void dump(std::ostream&fp=ExEnv::err());
+    /// Write a message to fp describing the error.
+    virtual void errortrace(std::ostream&fp=ExEnv::err0());
+    /// Write a message to fp describing the error.
+    virtual void dump(std::ostream&fp=ExEnv::err0());
 
     /// Print keywords that were never looked at, if possible.
-    virtual void print_unseen(std::ostream&fp=ExEnv::out());
+    virtual void print_unseen(std::ostream&fp=ExEnv::out0());
     /** Return 1 if there were unseen keywords, 0 if there are
         none, or -1 this keyval doesn't keep track of unseen
         keywords. */
@@ -279,11 +307,11 @@ class KeyVal: public RefCount {
 
 
 
-// this class allows keyval associations to be set up by the program,
-// rather than determined by an external file
+/** This class allows keyval associations to be set up by the program,
+    rather than determined by an external file. */
 class AssignedKeyVal: public KeyVal {
   private:
-    AVLMap<KeyValKeyword,Ref<KeyValValue> > _map;
+    std::map<std::string,Ref<KeyValValue> > _map;
     // do not allow a copy constructor or assignment
     AssignedKeyVal(const AssignedKeyVal&);
     void operator=(const AssignedKeyVal&);
@@ -295,25 +323,33 @@ class AssignedKeyVal: public KeyVal {
     AssignedKeyVal();
     ~AssignedKeyVal();
 
-    void assign(const char*, const Ref<KeyValValue>&);
-    void assign(const char*, double);
-    void assignboolean(const char*, int);
-    void assign(const char*, float);
-    void assign(const char*, char);
-    void assign(const char*, int);
-    void assign(const char*, const char*);
-    void assign(const char*, const Ref<DescribedClass>&);
+    /** Each of this routines assigns key to val.  */
+    //@{
+    void assign(const char* key, const Ref<KeyValValue>& val);
+    void assign(const char* key, double val);
+    void assignboolean(const char* key, int val);
+    void assign(const char* key, float val);
+    void assign(const char* key, char val);
+    void assign(const char* key, int val);
+    void assign(const char* key, const char* val);
+    void assign(const char* key, const Ref<DescribedClass>& val);
+    //@}
 
+    /// Erase all of the stored assignments.
     void clear();
 };
 
 
 
+/** StringKeyVal is a base class for KeyVal implementations
+    that store all values in a string format.  These are
+    converted to other data types through KeyValValue.
+*/
 class StringKeyVal: public KeyVal {
   private:
     // once a described class is found it is kept here so
     // multiple references to it return the same instance
-    AVLMap<KeyValKeyword,Ref<KeyValValue> > _map;
+    std::map<std::string,Ref<KeyValValue> > _map;
     // do not allow a copy constructor or assignment
     StringKeyVal(const StringKeyVal&);
     void operator=(const StringKeyVal&);
@@ -324,18 +360,27 @@ class StringKeyVal: public KeyVal {
                              const KeyValValue& def);
   public:
     virtual ~StringKeyVal();
-    virtual const char* stringvalue(const char *) = 0;
-    // returns the name of the exact class the object at the keyword
+    /// Returns the string representation of the value assigned to key.
+    virtual const char* stringrep(const char *key) = 0;
+    /** Returns the name of the exact class of the object at the keyword.
+        If no classname is assigned then 0 is returned. */
     virtual const char* classname(const char*);
-    // returns a string which is the actual keyword if some sort
-    // of variable substitution takes place (needed to make multiple
-    // references to the same object work in input files)
+    /** Returns a string which is the actual keyword if some sort
+        of variable substitution takes place (needed to make multiple
+        references to the same object work in input files). */
     virtual const char* truekeyword(const char*);
 
-    virtual void errortrace(std::ostream&fp=ExEnv::err());
-    virtual void dump(std::ostream&fp=ExEnv::err());
+    /// See the parent class documentation for descriptions of these functions.
+    //@{
+    virtual void errortrace(std::ostream&fp=ExEnv::err0());
+    virtual void dump(std::ostream&fp=ExEnv::err0());
+    //@}
 };
 
+/** This takes several KeyVal objects and makes them look like
+    one KeyVal object.  When a key is sought first KeyVal, then
+    the next, and so on is searched until the keyword is found.
+*/
 class AggregateKeyVal : public KeyVal {
   private:
     enum { MaxKeyVal = 4 };
@@ -349,16 +394,64 @@ class AggregateKeyVal : public KeyVal {
     Ref<KeyValValue> key_value(const char*,
                              const KeyValValue& def);
   public:
-    AggregateKeyVal(const Ref<KeyVal>&);
-    AggregateKeyVal(const Ref<KeyVal>&,const Ref<KeyVal>&);
-    AggregateKeyVal(const Ref<KeyVal>&,const Ref<KeyVal>&,const Ref<KeyVal>&);
-    AggregateKeyVal(const Ref<KeyVal>&,const Ref<KeyVal>&,const Ref<KeyVal>&,
-                    const Ref<KeyVal>&);
+    /** These contructors create an AggregateKeyVal that is formed from
+        several other KeyVal objects.  The search order is keyval1,
+        keyval2, and so on. */
+    //@{
+    AggregateKeyVal(const Ref<KeyVal>& keyval1);
+    AggregateKeyVal(const Ref<KeyVal>& keyval1,const Ref<KeyVal>& keyval2);
+    AggregateKeyVal(const Ref<KeyVal>& keyval1,const Ref<KeyVal>& keyval2,
+                    const Ref<KeyVal>& keyval3);
+    AggregateKeyVal(const Ref<KeyVal>& keyval1,const Ref<KeyVal>& keyval2,
+                    const Ref<KeyVal>& keyval3, const Ref<KeyVal>& keyval4);
+    //@}
     ~AggregateKeyVal();
-    void errortrace(std::ostream&fp=ExEnv::err());
-    void dump(std::ostream&fp=ExEnv::err());
+    void errortrace(std::ostream&fp=ExEnv::err0());
+    void dump(std::ostream&fp=ExEnv::err0());
 };
 
+/** PrefixKeyVal is a KeyVal that searches a different KeyVal using
+    modified keys.  This is convenient for reading keys grouped together
+    with a common prefix.  Consider the following code:
+    <pre>
+    sc::Ref<sc::KeyVal> keyval = new sc::PrefixKeyVal("A",original_keyval);
+    int r = keyval->intvalue("x");
+    </pre>
+    This code will assign to r the value associated with "x" in keyval.
+    keyval will search for "x" by searching for "A::x" in original_keyval.
+
+    This class is important for implementing constructors that take
+    KeyVal arguments.  When an object is being constructed from a KeyVal,
+    it may contain another object that must be constructed from a KeyVal.
+    In order to let the sub-object read the correct keywords from the
+    KeyVal, without knowledge of the containing objects keyword prefix,
+    a PrefixKeyVal can be constructed.  For example, the code
+    <pre>
+    class A: public DescribedClass {
+       double f0_;
+      public:
+       A(const Ref<KeyVal> &keyval): f0_(keyval->doublevalue("f0")) {}
+    }
+    class B: public DescribedClass {
+       double f1_;
+       Ref<A> a_;
+      public:
+       B(const Ref<KeyVal> &keyval):
+         f1_(keyval->doublevalue("f1")),
+         a_(new PrefixKeyVal(keyval,"a"))
+       {}
+    };
+    </pre>
+    can be used to read ParsedKeyVal input that looks like
+    <pre>
+    b<B>: (
+      f1 = 1.0
+      a<A>: (
+        f0 = 2.0
+      )
+    )
+    </pre>
+ */
 class PrefixKeyVal : public KeyVal {
   private:
     char* prefix;
@@ -372,24 +465,29 @@ class PrefixKeyVal : public KeyVal {
     Ref<KeyValValue> key_value(const char*,
                              const KeyValValue& def);
   public:
-    PrefixKeyVal(const Ref<KeyVal>&,int);
-    PrefixKeyVal(const Ref<KeyVal>&,int,int);
-    PrefixKeyVal(const Ref<KeyVal>&,int,int,int);
-    PrefixKeyVal(const Ref<KeyVal>&,int,int,int,int);
-    PrefixKeyVal(const Ref<KeyVal>&,const char*);
-    PrefixKeyVal(const Ref<KeyVal>&,const char*,int);
-    PrefixKeyVal(const Ref<KeyVal>&,const char*,int,int);
-    PrefixKeyVal(const Ref<KeyVal>&,const char*,int,int,int);
-    PrefixKeyVal(const Ref<KeyVal>&,const char*,int,int,int,int);
-    // old CTOR syntax (use the above instead)
+    /** Construct a PrefixKeyVal, using the given prefix and indices. */
+    //@{
+    PrefixKeyVal(const Ref<KeyVal>&,int i);
+    PrefixKeyVal(const Ref<KeyVal>&,int i,int j);
+    PrefixKeyVal(const Ref<KeyVal>&,int i,int j,int k);
+    PrefixKeyVal(const Ref<KeyVal>&,int i,int j,int k,int l);
+    PrefixKeyVal(const Ref<KeyVal>&,const char*prefix);
+    PrefixKeyVal(const Ref<KeyVal>&,const char*prefix,int i);
+    PrefixKeyVal(const Ref<KeyVal>&,const char*prefix,int i,int j);
+    PrefixKeyVal(const Ref<KeyVal>&,const char*prefix,int i,int j,int k);
+    PrefixKeyVal(const Ref<KeyVal>&,const char*prefix,int i,int j,int k,int l);
+    //@}
+    /// These routines are deprecated and will be removed in a future release.
+    //@{
     PrefixKeyVal(const char*,const Ref<KeyVal>&);
     PrefixKeyVal(const char*,const Ref<KeyVal>&,int);
     PrefixKeyVal(const char*,const Ref<KeyVal>&,int,int);
     PrefixKeyVal(const char*,const Ref<KeyVal>&,int,int,int);
     PrefixKeyVal(const char*,const Ref<KeyVal>&,int,int,int,int);
+    //@}
     ~PrefixKeyVal();
-    void errortrace(std::ostream&fp=ExEnv::err());
-    void dump(std::ostream&fp=ExEnv::err());
+    void errortrace(std::ostream&fp=ExEnv::err0());
+    void dump(std::ostream&fp=ExEnv::err0());
 };
 
 class IPV2;
@@ -435,17 +533,19 @@ class ParsedKeyVal : public StringKeyVal {
     /// Read input data from the given string.
     void parse_string(const char *);
 
-    // Overrides of parent members.
-    const char* stringvalue(const char*);
+    /// Overrides of parent members.
+    //@{
+    const char* stringrep(const char*);
     const char* classname(const char*);
     const char* truekeyword(const char*);
-    void errortrace(std::ostream&fp=ExEnv::err());
-    void dump(std::ostream&fp=ExEnv::err());
-    void print_unseen(std::ostream&fp=ExEnv::out());
+    void errortrace(std::ostream&fp=ExEnv::err0());
+    void dump(std::ostream&fp=ExEnv::err0());
+    void print_unseen(std::ostream&fp=ExEnv::out0());
     int have_unseen();
+    //@}
 };
 
-
+}
 
 #endif /* _KeyVal_h */
 
