@@ -37,8 +37,6 @@
 #include <iostream>
 #include <iomanip>
 
-using namespace std;
-
 // getrusage and gettimeofday don't exit under SUNMOS
 // so if NX is being used call dclock() instead.
 #ifdef HAVE_NX
@@ -88,6 +86,11 @@ int getrusage (
 #include <util/misc/regtime.h>
 #include <util/misc/timer.h>
 
+using namespace std;
+using namespace sc;
+
+namespace sc {
+
 class TimedRegion {
   private:
     char *name_;
@@ -427,7 +430,7 @@ void
 RegionTimer::exit(const char *name)
 {
   if (!current_ || (name && strcmp(name, current_->name()))) {
-      ExEnv::err() << "TimeRegion::exit(\"" << name << "\"):"
+      ExEnv::errn() << "TimeRegion::exit(\"" << name << "\"):"
            << " current region"
            << " (\"" << current_->name() << "\")"
            << " doesn't match name"
@@ -438,7 +441,7 @@ RegionTimer::exit(const char *name)
   if (wall_time_) current_->wall_exit(get_wall_time());
   if (flops_) current_->flops_exit(get_flops());
   if (! current_->up()) {
-      ExEnv::err() << "RegionTimer::exit: already at top level" << endl;
+      ExEnv::errn() << "RegionTimer::exit: already at top level" << endl;
       abort();
     }
   current_ = current_->up();
@@ -507,7 +510,7 @@ void
 RegionTimer::change(const char *newname, const char *oldname)
 {
   if (!current_ || (oldname && strcmp(oldname, current_->name()))) {
-      ExEnv::err() << "RegionTimer::change("
+      ExEnv::errn() << "RegionTimer::change("
            << "\"" << newname << "\","
            << "\"" << oldname << "\""
            << "):"
@@ -522,7 +525,7 @@ RegionTimer::change(const char *newname, const char *oldname)
   if (wall_time_) current_->wall_exit(wall = get_wall_time());
   if (flops_) current_->flops_exit(flops = get_flops());
   if (! current_->up()) {
-      ExEnv::err() << "RegionTimer::change: already at top level" << endl;
+      ExEnv::errn() << "RegionTimer::change: already at top level" << endl;
       abort();
     }
   current_ = current_->up();
@@ -696,7 +699,53 @@ RegionTimer::set_default_regiontimer(const Ref<RegionTimer>& t)
 }
 
 //////////////////////////////////////////////////////////////////////
-// C compatibility routines
+// Timer functions
+
+Timer::Timer(const char *name):
+  active_(false)
+{
+  timer_ = RegionTimer::default_regiontimer();
+  if (timer_.nonnull() && name != 0) {
+      name_ = name;
+      timer_->enter(name);
+      active_ = true;
+    }
+}
+
+Timer::Timer(const Ref<RegionTimer>&t, const char *name):
+  active_(false),
+  timer_(t)
+{
+  if (timer_.nonnull() && name != 0) {
+      name_ = name;
+      timer_->enter(name);
+      active_ = true;
+    }
+}
+
+Timer::~Timer()
+{
+  if (active_) {
+      timer_->exit(name_.c_str());
+    }
+}
+
+void
+Timer::reset(const char *name)
+{
+  if (active_) {
+      timer_->exit(name_.c_str());
+      active_ = false;
+    }
+  if (timer_.nonnull() && name) {
+      timer_->enter(name);
+      name_ = name;
+      active_ = true;
+    }
+}
+
+//////////////////////////////////////////////////////////////////////
+// Shorthand to manipulate the global region timer
 
 void
 tim_enter(const char *name) {
@@ -739,6 +788,8 @@ tim_print(int)
   if (default_regtimer.nonnull()) default_regtimer->print();
 }
 
+}
+
 /////////////////////////////////////////////////////////////////////////////
 
 // Local Variables:
