@@ -35,6 +35,7 @@
 #include <util/state/statein.h>
 
 using namespace std;
+using namespace sc;
 
 #define DEBUG 0
 
@@ -43,14 +44,14 @@ static ClassDesc StateIn_cd(
 
 StateIn::StateIn(const StateIn&)
 {
-  ExEnv::err() << "StateIn: private copy ctor called???" << endl;
+  ExEnv::errn() << "StateIn: private copy ctor called???" << endl;
   abort();
 }
 
 void
 StateIn::operator=(const StateIn&)
 {
-  ExEnv::err() << "StateIn: private assignment called???" << endl;
+  ExEnv::errn() << "StateIn: private assignment called???" << endl;
   abort();
 }
 
@@ -77,7 +78,7 @@ StateIn::push_key(const char *keyword)
 
   int length = strlen(keyword);
   if (keylength_ + length + 1 >= KeyVal::MaxKeywordLength) {
-      ExEnv::err() << "StateIn: KeyVal::MaxKeywordLength exceeded" << endl;
+      ExEnv::errn() << "StateIn: KeyVal::MaxKeywordLength exceeded" << endl;
       abort();
     }
   int old_keylength = keylength_;
@@ -151,7 +152,7 @@ StateIn::get(char&r, const char *keyword)
       int p = push_key(keyword);
       char roverride = override()->charvalue(key());
       if (override()->error() == KeyVal::OK) {
-          ExEnv::out() << node0 << indent << "overriding \"" << key()
+          ExEnv::out0() << indent << "overriding \"" << key()
                        << "\": " << r << " -> " << roverride << endl;
           r = roverride;
         }
@@ -168,7 +169,7 @@ StateIn::get(unsigned int&r, const char *keyword)
       int p = push_key(keyword);
       int roverride = override()->intvalue(key());
       if (override()->error() == KeyVal::OK) {
-          ExEnv::out() << node0 << indent << "overriding \"" << key()
+          ExEnv::out0() << indent << "overriding \"" << key()
                        << "\": " << r << " -> " << roverride << endl;
           r = roverride;
         }
@@ -185,7 +186,7 @@ StateIn::get(int&r, const char *keyword)
       int p = push_key(keyword);
       int roverride = override()->intvalue(key());
       if (override()->error() == KeyVal::OK) {
-          ExEnv::out() << node0 << indent << "overriding \"" << key()
+          ExEnv::out0() << indent << "overriding \"" << key()
                        << "\": " << r << " -> " << roverride << endl;
           r = roverride;
         }
@@ -202,7 +203,7 @@ StateIn::get(float&r, const char *keyword)
       int p = push_key(keyword);
       float roverride = override()->floatvalue(key());
       if (override()->error() == KeyVal::OK) {
-          ExEnv::out() << node0 << indent << "overriding \"" << key()
+          ExEnv::out0() << indent << "overriding \"" << key()
                        << "\": " << r << " -> " << roverride << endl;
           r = roverride;
         }
@@ -219,7 +220,7 @@ StateIn::get(double&r, const char *keyword)
       int p = push_key(keyword);
       double roverride = override()->doublevalue(key());
       if (override()->error() == KeyVal::OK) {
-          ExEnv::out() << node0 << indent << "overriding \"" << key()
+          ExEnv::out0() << indent << "overriding \"" << key()
                        << "\": " << r << " -> " << roverride << endl;
           r = roverride;
         }
@@ -231,7 +232,7 @@ StateIn::get(double&r, const char *keyword)
 int
 StateIn::get_array_void(void*p,int s)
 {
-  ExEnv::err() << "StateIn::get_array_void(void*p,int s) "
+  ExEnv::errn() << "StateIn::get_array_void(void*p,int s) "
        << "is a derived class responsiblility" << endl
        << "  exact type is \"" << class_name() << "\"" << endl;
   abort();
@@ -245,12 +246,12 @@ StateIn::get_directory()
 
   // read the type information
 #if DEBUG
-  ExEnv::out() << "Directory length location = " << tell() << endl;
+  ExEnv::outn() << "Directory length location = " << tell() << endl;
 #endif
   get(length);
 #if DEBUG
-  ExEnv::out() << "Directory length = " << length << endl;
-  ExEnv::out() << "Directory entries location = " << tell() << endl;
+  ExEnv::outn() << "Directory length = " << length << endl;
+  ExEnv::outn() << "Directory entries location = " << tell() << endl;
 #endif
   for (i=0; i<length; i++) {
       char *name;
@@ -259,7 +260,7 @@ StateIn::get_directory()
       get(version);
       get(classid);
 #if DEBUG
-      ExEnv::out() << "GET CLASS:"
+      ExEnv::outn() << "GET CLASS:"
                    << " NAME = " << name
                    << " VERSION = " << version
                    << " ID = " << classid << endl;
@@ -281,7 +282,7 @@ StateIn::get_directory()
       get(num.offset);
       get(num.size);
 #if DEBUG
-      ExEnv::out() << "GET OBJECT:"
+      ExEnv::outn() << "GET OBJECT:"
                    << " NUM=" << setw(2) << n
                    << " OFF=" << setw(5) << num.offset
                    << " SZ=" << setw(4) << num.size
@@ -301,7 +302,7 @@ StateIn::find_and_get_directory()
       int original_loc = tell();
       seek(directory_location());
 #if DEBUG
-      ExEnv::out() << "Getting directory from " << tell() << endl;
+      ExEnv::outn() << "Getting directory from " << tell() << endl;
 #endif
       get_directory();
       seek(original_loc);
@@ -314,15 +315,15 @@ StateIn::getstring(char*&s)
   int r=0;
   int size;
 #if DEBUG
-  ExEnv::out() << "String length location = " << tell() << endl;
+  ExEnv::outn() << "String length location = " << tell() << endl;
 #endif
   r += get(size);
 #if DEBUG
-  ExEnv::out() << "String length = " << size << endl;
+  ExEnv::outn() << "String length = " << size << endl;
 #endif
   if (size) {
 #if DEBUG
-      ExEnv::out() << "String location = " << tell() << endl;
+      ExEnv::outn() << "String location = " << tell() << endl;
 #endif
       s = new char[size];
       r += get_array_char(s,size-1);
@@ -334,6 +335,17 @@ StateIn::getstring(char*&s)
   return r;
 }
 
+int
+StateIn::get(std::string&s)
+{
+  char *cstr;
+  int r = getstring(cstr);
+  if (cstr) s = cstr;
+  else s = "";
+  delete[] cstr;
+  return r;
+}
+
 int
 StateIn::get(char*&s)
 {
@@ -450,8 +462,8 @@ StateIn::get(const ClassDesc**cd)
   int classid;
   r += get(classid);
 
-  if (!classdatamap_.contains(classid)) {
-      ExEnv::err() << "ERROR: StateIn: couldn't find class descriptor for classid "
+  if (classdatamap_.find(classid) == classdatamap_.end()) {
+      ExEnv::errn() << "ERROR: StateIn: couldn't find class descriptor for classid "
            << classid << endl;
       abort();
     }
@@ -467,9 +479,9 @@ StateIn::list_objects(ostream &o)
 {
   if (SCFormIO::getverbose(o)) {
       int ii = 1;
-      for (AVLMap<int,StateInData>::iterator i=ps_.begin(); i!=ps_.end();
+      for (std::map<int,StateInData>::iterator i=ps_.begin(); i!=ps_.end();
            i++,ii++) {
-          const StateInData &num(i.data());
+          const StateInData &num(i->second);
           const char *classname = classdatamap_[num.type].name;
           o << indent
             << "object " << ii
@@ -480,9 +492,9 @@ StateIn::list_objects(ostream &o)
     }
   else {
       int ntot = 0;
-      for (AVLMap<int,StateClassData>::iterator i=classdatamap_.begin();
+      for (std::map<int,StateClassData>::iterator i=classdatamap_.begin();
            i!=classdatamap_.end(); i++) {
-          StateClassData &dat = i.data();
+          StateClassData &dat = i->second;
           if (dat.ninstance > 0) {
               o << indent << dat.ninstance
                 << " "
@@ -503,12 +515,12 @@ StateIn::dir_getobject(Ref<SavableState> &p, const char *name)
   p = 0;
 
   if (!has_directory()) {
-      ExEnv::err() << "ERROR: StateIn: no directory to get object from" << endl;
+      ExEnv::errn() << "ERROR: StateIn: no directory to get object from" << endl;
       abort();
     }
 
   if (!seekable()) {
-      ExEnv::err() << "ERROR: StateIn: cannot get object because cannot seek" << endl;
+      ExEnv::errn() << "ERROR: StateIn: cannot get object because cannot seek" << endl;
       abort();
     }
 
@@ -530,7 +542,7 @@ StateIn::dir_getobject(Ref<SavableState> &p, const char *name)
   if (classname) {
       cd = ClassDesc::name_to_class_desc(classname);
       if (!cd) {
-          ExEnv::err() << "ERROR: StateIn: class " << classname << " unknown" << endl;
+          ExEnv::errn() << "ERROR: StateIn: class " << classname << " unknown" << endl;
           abort();
         }
       delete[] classname;
@@ -540,16 +552,16 @@ StateIn::dir_getobject(Ref<SavableState> &p, const char *name)
   if (cd) classid = classidmap_[(ClassDesc*)cd];
   else classid = -1;
 
-  AVLMap<int,StateInData>::iterator i;
+  std::map<int,StateInData>::iterator i;
   int nfound = 0;
   for (i=ps_.begin(); i!=ps_.end(); i++) {
-      if (classid == -1 || i.data().type == classid) nfound++;
+      if (classid == -1 || i->second.type == classid) nfound++;
       if (nfound == number) {
-          if (i.data().ptr.nonnull()) {
-              p = i.data().ptr;
+          if (i->second.ptr.nonnull()) {
+              p = i->second.ptr;
             }
           else {
-              seek(i.data().offset);
+              seek(i->second.offset);
               r += getobject(p);
             }
           return r;
@@ -572,41 +584,41 @@ StateIn::getobject(Ref<SavableState> &p)
   if (refnum == 0) {
       // reference to null
 #if DEBUG
-      ExEnv::out() << indent << "getting null object" << endl;
+      ExEnv::outn() << indent << "getting null object" << endl;
 #endif
       p = 0;
     }
   else {
 #if DEBUG
-      ExEnv::out() << indent << "getting object number " << setw(2)
+      ExEnv::outn() << indent << "getting object number " << setw(2)
                    << refnum << endl;
-      ExEnv::out() << incindent;
+      ExEnv::outn() << incindent;
 #endif
-      AVLMap<int,StateInData>::iterator ind = ps_.find(refnum);
+      std::map<int,StateInData>::iterator ind = ps_.find(refnum);
       if (ind == ps_.end() && use_dir) {
-          ExEnv::err() << "ERROR: StateIn: directory missing object number "
+          ExEnv::errn() << "ERROR: StateIn: directory missing object number "
                << refnum << endl;
           abort();
         }
-      if (ind == ps_.end() || ind.data().ptr.null()) {
+      if (ind == ps_.end() || ind->second.ptr.null()) {
 #if DEBUG
-          ExEnv::out() << indent << "reading object" << endl;
+          ExEnv::outn() << indent << "reading object" << endl;
 #endif
           // object has not yet been read in
           int need_seek = 0;
           if (use_dir) {
-              if (original_loc != ind.data().offset) {
+              if (original_loc != ind->second.offset) {
                   need_seek = 1;
                   original_loc = tell();
 #if DEBUG
-                  ExEnv::out() << indent << "seeking to"
-                       << setw(5) << ind.data().offset << endl;
+                  ExEnv::outn() << indent << "seeking to"
+                       << setw(5) << ind->second.offset << endl;
 #endif
-                  seek(ind.data().offset);
+                  seek(ind->second.offset);
                   int trefnum;
                   get(trefnum);
                   if (trefnum != refnum) {
-                      ExEnv::err() << "StateIn: didn't find expected reference"<<endl;
+                      ExEnv::errn() << "StateIn: didn't find expected reference"<<endl;
                       abort();
                     }
                 }
@@ -618,38 +630,38 @@ StateIn::getobject(Ref<SavableState> &p)
           DescribedClass *dc = cd->create(*this);
           p = dynamic_cast<SavableState*>(dc);
           if (use_dir) {
-              ind.data().ptr = p;
+              ind->second.ptr = p;
               if (need_seek) seek(original_loc);
             }
 #if DEBUG
-          ExEnv::out() << indent << "got object with type = "
+          ExEnv::outn() << indent << "got object with type = "
                << p->class_name() << endl;
 #endif
         }
       else {
           // object already exists
-          p = ind.data().ptr;
+          p = ind->second.ptr;
 #if DEBUG
-          ExEnv::out() << indent << "object already existed, type = "
+          ExEnv::outn() << indent << "object already existed, type = "
                << p->class_name() << endl;
-          ExEnv::out() << indent
+          ExEnv::outn() << indent
                << "  use_dir = " << use_dir
                << " tell() = " << setw(5) << tell()
-               << " offset = " << setw(5) << ind.data().offset
+               << " offset = " << setw(5) << ind->second.offset
                << " size_refnum = " << setw(1) << size_refnum
                << endl;
 #endif
-          if (use_dir && tell() - size_refnum == ind.data().offset) {
-              seek(tell() - size_refnum + ind.data().size);
+          if (use_dir && tell() - size_refnum == ind->second.offset) {
+              seek(tell() - size_refnum + ind->second.size);
 #if DEBUG
-              ExEnv::out() << indent << "  seeking to "
-                   << tell() - size_refnum + ind.data().offset
+              ExEnv::outn() << indent << "  seeking to "
+                   << tell() - size_refnum + ind->second.offset
                    << endl;
 #endif
             }
         }
 #if DEBUG
-      ExEnv::out() << decindent;
+      ExEnv::outn() << decindent;
 #endif
     }
   return r;
@@ -673,17 +685,17 @@ StateIn::haveobject(const Ref<SavableState> &p)
 void
 StateIn::haveobject(int objnum,const Ref<SavableState> &p)
 {
-  AVLMap<int,StateInData>::iterator ind = ps_.find(objnum);
+  std::map<int,StateInData>::iterator ind = ps_.find(objnum);
   if (ind == ps_.end()) {
       ps_[objnum].ptr = p;
 #if DEBUG
-      ExEnv::out() << indent << "have object adding number " << objnum << endl;
+      ExEnv::outn() << indent << "have object adding number " << objnum << endl;
 #endif
     }
   else {
-      ind.data().ptr = p;
+      ind->second.ptr = p;
 #if DEBUG
-      ExEnv::out() << indent << "have object updating number " << objnum
+      ExEnv::outn() << indent << "have object updating number " << objnum
                    << endl;
 #endif
     }
@@ -697,7 +709,7 @@ StateIn::get_header()
   get_array_char(tmp,6);
   tmp[6] = '\0';
   if (strcmp(tmp,magic)) {
-      ExEnv::err() << "StateIn: bad magic number" << endl;
+      ExEnv::errn() << "StateIn: bad magic number" << endl;
       abort();
     }
 
@@ -717,7 +729,7 @@ StateIn::get_header()
   // get the directory location
   get_array_int(&dir_loc_,1);
   if (dir_loc_ == -1) {
-      ExEnv::err() << "ERROR: StateIn: directory corrupted" << endl;
+      ExEnv::errn() << "ERROR: StateIn: directory corrupted" << endl;
       abort();
     }
 }
